@@ -69,7 +69,9 @@ void SKGProcessCreator::setXMLCondition(const QString& iXML)
     // Remove all existing lines
     for (int i = 0; ui.propertyLinesLayout->count(); ++i) {
         QLayoutItem* line = ui.propertyLinesLayout->takeAt(i);
-        if (line) line->widget()->deleteLater();
+        if (line) {
+            line->widget()->deleteLater();
+        }
     }
     QDomNode l = root.firstChild();
     while (!l.isNull()) {
@@ -93,7 +95,9 @@ void SKGProcessCreator::setXMLCondition(const QString& iXML)
                     root2.setAttribute("att2", element.attribute("att2"));
                     root2.setAttribute("att2s", element.attribute("att2s"));
                     QString xml = doc2.toString();
-                    if (line) line->setXMLCondition(SKGPredicatCreator::getTextFromXml(xml));
+                    if (line) {
+                        line->setXMLCondition(SKGPredicatCreator::getTextFromXml(xml));
+                    }
                 }
                 n = n.nextSibling();
             }
