@@ -67,7 +67,9 @@ void SKGPropertyEditor::setParameters(SKGDocument* iDocument, const QString& iTa
         SKGServices::SKGAttributesList attributes;
         m_document->getAttributesDescription(m_table, attributes);
         foreach(const SKGServices::SKGAttributeInfo & att, attributes) {
-            if (iEditableAttribute.count() == 0 || iEditableAttribute.contains(att.name)) m_listAtts.push_back(att);
+            if (iEditableAttribute.count() == 0 || iEditableAttribute.contains(att.name)) {
+                m_listAtts.push_back(att);
+            }
         }
 
 
@@ -80,7 +82,9 @@ void SKGPropertyEditor::setParameters(SKGDocument* iDocument, const QString& iTa
         SKGServices::SKGAttributesList otherAttributes;
         m_document->getAttributesDescription(m_table, otherAttributes);
         foreach(const SKGServices::SKGAttributeInfo & att, otherAttributes) {
-            if (iOtherAttributes.count() == 0 || iOtherAttributes.contains(att.name)) m_listOtherAtts.push_back(att);
+            if (iOtherAttributes.count() == 0 || iOtherAttributes.contains(att.name)) {
+                m_listOtherAtts.push_back(att);
+            }
         }
 
 
@@ -105,7 +109,9 @@ void SKGPropertyEditor::setupWidgets()
 
     ui.valueSelect->setVisible(attributeType == SKGServices::TEXT && operationIndex == 0);
     QStringList attributeValues;
-    if (m_document) m_document->getDistinctValues(m_table, m_listAtts.at(attributeIndex).name, attributeValues);
+    if (m_document) {
+        m_document->getDistinctValues(m_table, m_listAtts.at(attributeIndex).name, attributeValues);
+    }
     ui.valueSelect->clear();
     ui.valueSelect->addItem("");
 
