@@ -37,7 +37,7 @@
 SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Advices")), m_maxAdvice(7), m_refreshNeeded(true), m_refresh(NULL)
 {
-    SKGTRACEIN(10, "SKGAdviceBoardWidget::SKGAdviceBoardWidget");
+    SKGTRACEINFUNC(10);
 
     // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
@@ -74,7 +74,7 @@ SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
 
 SKGAdviceBoardWidget::~SKGAdviceBoardWidget()
 {
-    SKGTRACEIN(10, "SKGAdviceBoardWidget::~SKGAdviceBoardWidget");
+    SKGTRACEINFUNC(10);
     m_menuAuto = NULL;
     m_refresh = NULL;
 }
@@ -96,11 +96,15 @@ void SKGAdviceBoardWidget::setState(const QString& iState)
     QDomElement root = doc.documentElement();
 
     QString maxAdviceS = root.attribute("maxAdvice");
-    if (maxAdviceS.isEmpty()) maxAdviceS = '7';
+    if (maxAdviceS.isEmpty()) {
+        maxAdviceS = '7';
+    }
     m_maxAdvice = SKGServices::stringToInt(maxAdviceS);
 
     QString automatic = root.attribute("automatic");
-    if (automatic.isEmpty()) automatic = 'Y';
+    if (automatic.isEmpty()) {
+        automatic = 'Y';
+    }
 
     if (m_menuAuto) {
         bool previous = m_menuAuto->blockSignals(true);
@@ -113,7 +117,9 @@ void SKGAdviceBoardWidget::setState(const QString& iState)
 
 void SKGAdviceBoardWidget::pageChanged()
 {
-    if (m_refreshNeeded) dataModified();
+    if (m_refreshNeeded) {
+        dataModified();
+    }
 }
 
 void SKGAdviceBoardWidget::dataModifiedForce()
@@ -123,11 +129,13 @@ void SKGAdviceBoardWidget::dataModifiedForce()
 
 void SKGAdviceBoardWidget::dataModified(bool iForce)
 {
-    SKGTRACEIN(10, "SKGAdviceBoardWidget::dataModified");
+    SKGTRACEINFUNC(10);
     SKGTabPage* page = SKGTabPage::parentTabPage(this);
     if (!iForce && ((page != NULL && page != SKGMainPanel::getMainPanel()->currentPage()) || !m_menuAuto->isChecked())) {
         m_refreshNeeded = true;
-        if (m_refresh) m_refresh->show();
+        if (m_refresh) {
+            m_refresh->show();
+        }
         return;
     }
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -304,7 +312,9 @@ void SKGAdviceBoardWidget::adviceClicked()
                     QString currentMonth = QDate::currentDate().toString("yyyy-MM");
 
                     // Create dismiss
-                    if (solution == -1 || solution == -2) uuid = SKGServices::splitCSVLine(uuid, '|').at(0);
+                    if (solution == -1 || solution == -2) {
+                        uuid = SKGServices::splitCSVLine(uuid, '|').at(0);
+                    }
                     err = getDocument()->setParameter(uuid, solution == -2 || solution == -4 ? "I" : QString("I_" % currentMonth), QVariant(), "advice");
 
                     // Delete useless dismiss
@@ -341,7 +351,9 @@ void SKGAdviceBoardWidget::adviceClicked()
                 int next = getDocument()->getTransactionToProcess();
 
                 // If this is the same transaction, it means that an action has been done outside the document ==> a refresh is needed
-                if (next == previous) emit refreshNeeded();
+                if (next == previous) {
+                    emit refreshNeeded();
+                }
 
                 QApplication::restoreOverrideCursor();
             }
