@@ -45,8 +45,10 @@
 SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument), m_flowLayout(NULL), m_menu(NULL), m_addMenu(NULL), m_plasmadashboard(NULL)
 {
-    SKGTRACEIN(1, "SKGDashboardPluginWidget::SKGDashboardPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -59,7 +61,9 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
     if (PLASMA) {
         // Load the plasma kpart
         KService::Ptr service = KService::serviceByDesktopPath("plasma-kpart.desktop");
-        if (service)  m_plasmadashboard = service->createInstance<KParts::ReadOnlyPart> (this);
+        if (service) {
+            m_plasmadashboard = service->createInstance<KParts::ReadOnlyPart> (this);
+        }
         if (m_plasmadashboard) {
             QVBoxLayout* l = new QVBoxLayout(ui.kContent);
             l->addWidget(m_plasmadashboard->widget());
@@ -130,7 +134,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(SKGDocument* iDocument)
 
 SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
 {
-    SKGTRACEIN(1, "SKGDashboardPluginWidget::~SKGDashboardPluginWidget");
+    SKGTRACEINFUNC(1);
     m_menu = NULL;
     m_addMenu = NULL;
     m_flowLayout = NULL;
@@ -139,7 +143,7 @@ SKGDashboardPluginWidget::~SKGDashboardPluginWidget()
 
 QString SKGDashboardPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGDashboardPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -168,7 +172,7 @@ QString SKGDashboardPluginWidget::getState()
 
 void SKGDashboardPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGDashboardPluginWidget::setState");
+    SKGTRACEINFUNC(10);
 
     QDomDocument doc("SKGML");
     doc.setContent(iState);
@@ -191,7 +195,9 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
         }
 
         QString zoomPositionS = root.attribute("zoomPosition");
-        if (zoomPositionS.isEmpty()) zoomPositionS = '0';
+        if (zoomPositionS.isEmpty()) {
+            zoomPositionS = '0';
+        }
         setZoomPosition(SKGServices::stringToInt(zoomPositionS));
 
         int index = 1;
@@ -200,10 +206,16 @@ void SKGDashboardPluginWidget::setState(const QString& iState)
             if (!element.isNull()) {
                 SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(element.attribute("name"));
                 QString indexString = element.attribute("index");
-                if (indexString.isEmpty()) indexString = '0';
+                if (indexString.isEmpty()) {
+                    indexString = '0';
+                }
                 QString zoom = element.attribute("zoom");
-                if (zoom.isEmpty()) zoom = '0';
-                if (plugin) addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute("state"));
+                if (zoom.isEmpty()) {
+                    zoom = '0';
+                }
+                if (plugin) {
+                    addItem(plugin, SKGServices::stringToInt(indexString), SKGServices::stringToInt(zoom), element.attribute("state"));
+                }
             } else {
                 index = -1;
             }
@@ -236,12 +248,14 @@ QString SKGDashboardPluginWidget::getDefaultStateAttribute()
 
 void SKGDashboardPluginWidget::refresh()
 {
-    SKGTRACEIN(1, "SKGDashboardPluginWidget::refresh");
+    SKGTRACEINFUNC(1);
 }
 
 QWidget* SKGDashboardPluginWidget::zoomableWidget()
 {
-    if (PLASMA) return NULL;
+    if (PLASMA) {
+        return NULL;
+    }
     return SKGTabPage::zoomableWidget();
 }
 
@@ -317,8 +331,9 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
                 QDragMoveEvent* devent = static_cast<QDragMoveEvent*>(iEvent);
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     int oldPos = SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
-                    if (oldPos != toMoveIndex) devent->accept();
-                    else {
+                    if (oldPos != toMoveIndex) {
+                        devent->accept();
+                    } else {
                         devent->ignore();
                     }
 
@@ -330,10 +345,14 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
                 if (devent->mimeData()->hasFormat("application/x-skgdashboardpluginwidget")) {
                     int oldPos = SKGServices::stringToInt(devent->mimeData()->data("application/x-skgdashboardpluginwidget"));
 
-                    if (oldPos + 1 == toMoveIndex) ++toMoveIndex;
+                    if (oldPos + 1 == toMoveIndex) {
+                        ++toMoveIndex;
+                    }
 
                     // Move item
-                    if (toMoveIndex > oldPos) --toMoveIndex;
+                    if (toMoveIndex > oldPos) {
+                        --toMoveIndex;
+                    }
                     moveItem(oldPos, toMoveIndex);
 
                     return true;
@@ -347,7 +366,9 @@ bool SKGDashboardPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 void SKGDashboardPluginWidget::showHeaderMenu(const QPoint& iPos)
 {
     // Display menu
-    if (m_menu) m_menu->popup(mapToGlobal(iPos));
+    if (m_menu) {
+        m_menu->popup(mapToGlobal(iPos));
+    }
 }
 
 void SKGDashboardPluginWidget::onAddWidget()
@@ -358,7 +379,9 @@ void SKGDashboardPluginWidget::onAddWidget()
         QStringList param = SKGServices::splitCSVLine(id, '-');
 
         SKGInterfacePlugin* db = SKGMainPanel::getMainPanel()->getPluginByName(param.at(0));
-        if (db) addItem(db, SKGServices::stringToInt(param.at(1)));
+        if (db) {
+            addItem(db, SKGServices::stringToInt(param.at(1)));
+        }
     }
 }
 
@@ -411,7 +434,9 @@ SKGBoardWidget* SKGDashboardPluginWidget::parentBoardWidget(QWidget* iWidget)
     SKGBoardWidget* output = qobject_cast< SKGBoardWidget* >(iWidget);
     if (!output && iWidget) {
         QWidget* iParent = iWidget->parentWidget();
-        if (iParent)  output = SKGDashboardPluginWidget::parentBoardWidget(iParent);
+        if (iParent) {
+            output = SKGDashboardPluginWidget::parentBoardWidget(iParent);
+        }
     }
 
     return output;
@@ -421,7 +446,9 @@ void SKGDashboardPluginWidget::onRemoveWidget()
 {
     int p = -1;
     QWidget* send = qobject_cast<QWidget*>(this->sender());
-    if (send) p = m_itemsPointers.indexOf(parentBoardWidget(send));
+    if (send) {
+        p = m_itemsPointers.indexOf(parentBoardWidget(send));
+    }
     if (p >= 0) {
         // Get item
         SKGBoardWidget* wgt = m_itemsPointers.at(p);
