@@ -57,7 +57,7 @@ SKGFilePlugin::SKGFilePlugin(QWidget* iWidget, QObject* iParent, const QVariantL
     m_saveAction(NULL), m_saveAsAction(NULL), m_passwordAction(NULL), m_recentFiles(NULL), m_currentDocument(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGFilePlugin::SKGFilePlugin");
+    SKGTRACEINFUNC(10);
 
     // Set save on close mode
     SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
@@ -65,8 +65,10 @@ SKGFilePlugin::SKGFilePlugin(QWidget* iWidget, QObject* iParent, const QVariantL
 
 SKGFilePlugin::~SKGFilePlugin()
 {
-    SKGTRACEIN(10, "SKGFilePlugin::~SKGFilePlugin");
-    if (m_recentFiles) m_recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
+    SKGTRACEINFUNC(10);
+    if (m_recentFiles) {
+        m_recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
+    }
 
     m_currentDocument = NULL;
     m_recentFiles = NULL;
@@ -77,10 +79,12 @@ SKGFilePlugin::~SKGFilePlugin()
 
 bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGFilePlugin::setupActions");
+    SKGTRACEINFUNC(10);
 
     m_currentDocument = iDocument;
-    if (m_currentDocument == NULL) return false;
+    if (m_currentDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skg_file/skg_file.rc");
@@ -105,7 +109,9 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
 
     // Recent file
     m_recentFiles = KStandardAction::openRecent(this, SLOT(onOpen(KUrl)), actionCollection());
-    if (m_recentFiles) m_recentFiles->loadEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
+    if (m_recentFiles) {
+        m_recentFiles->loadEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
+    }
 
     // Get last argument
     connect(this, SIGNAL(loadFile(KUrl)), this, SLOT(onOpen(KUrl)), Qt::QueuedConnection);
@@ -127,12 +133,14 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
         // Read Setting
         bool openlastfile = skgfile_settings::openlastfile();
         if (openMode == 1 && openlastfile) {
-            SKGTRACEIN(10, "SKGFilePlugin::openlastfile");
+            SKGTRACEINFUNC(10);
             QString lastOpenedFile = skgfile_settings::lastfilepath();
             if (!lastOpenedFile.isEmpty() && QFile(lastOpenedFile).exists()) {
                 if (SKGMainPanel::getMainPanel()) {
                     KSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
-                    if (splashScreen) splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));          // krazy:exclude=qmethods
+                    if (splashScreen) {
+                        splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
+                    }
                 }
                 Q_EMIT loadFile(lastOpenedFile);
             } else {
@@ -153,7 +161,7 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
 
 bool SKGFilePlugin::processArguments(const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGFilePlugin::processArguments");
+    SKGTRACEINFUNC(10);
     bool output = false;
     int nbArg = iArgument.count();
     if (nbArg && m_currentDocument) {
@@ -163,7 +171,9 @@ bool SKGFilePlugin::processArguments(const QStringList& iArgument)
         if (QFile(filename).exists() && extension == extensionDocument) {
             if (SKGMainPanel::getMainPanel()) {
                 KSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
-                if (splashScreen) splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));          // krazy:exclude=qmethods
+                if (splashScreen) {
+                    splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
+                }
             }
             Q_EMIT loadFile(filename);
             output = true;
@@ -174,7 +184,7 @@ bool SKGFilePlugin::processArguments(const QStringList& iArgument)
 
 QWidget* SKGFilePlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGFilePlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
 
@@ -220,14 +230,20 @@ SKGError SKGFilePlugin::savePreferences() const
 
 void SKGFilePlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGFilePlugin::refresh");
+    SKGTRACEINFUNC(10);
 
     // Refresh action status
     if (m_currentDocument) {
         bool test = (m_currentDocument->getDatabase() != NULL);
-        if (m_saveAction) m_saveAction->setEnabled(m_currentDocument->isFileModified());
-        if (m_saveAsAction) m_saveAsAction->setEnabled(test);
-        if (m_passwordAction) m_passwordAction->setEnabled(test);
+        if (m_saveAction) {
+            m_saveAction->setEnabled(m_currentDocument->isFileModified());
+        }
+        if (m_saveAsAction) {
+            m_saveAsAction->setEnabled(test);
+        }
+        if (m_passwordAction) {
+            m_passwordAction->setEnabled(test);
+        }
     }
 }
 
@@ -263,7 +279,7 @@ int SKGFilePlugin::getOrder() const
 void SKGFilePlugin::onNew()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::onNew", err);
+    SKGTRACEINFUNCRC(10, err);
     if (SKGMainPanel::getMainPanel() && m_currentDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -289,10 +305,11 @@ void SKGFilePlugin::onNew()
 void SKGFilePlugin::onSave()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::onSave", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
-        if (m_currentDocument->getCurrentFileName().isEmpty()) onSaveAs();
-        else {
+        if (m_currentDocument->getCurrentFileName().isEmpty()) {
+            onSaveAs();
+        } else {
             QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
             err = m_currentDocument->save();
             QApplication::restoreOverrideCursor();
@@ -315,12 +332,14 @@ void SKGFilePlugin::onSave()
 void SKGFilePlugin::onSaveAs()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::onSaveAs", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///" % m_currentDocument->objectName(),
                            "*." % m_currentDocument->getFileExtension() % '|' % i18nc("Associated with the file extension : for example, .csv --> CSV document", "%1 document", KCmdLineArgs::aboutData()->programName()) ,
                            SKGMainPanel::getMainPanel());
-        if (fileName.isEmpty()) return;
+        if (fileName.isEmpty()) {
+            return;
+        }
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         err = m_currentDocument->saveAs(fileName, true);
@@ -364,7 +383,7 @@ void SKGFilePlugin::onReOpen()
 void SKGFilePlugin::onOpen(const KUrl& iUrl)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::onOpen", err);
+    SKGTRACEINFUNCRC(10, err);
     if (SKGMainPanel::getMainPanel() && m_currentDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
         bool useKWallet = skgfile_settings::storeInKdeWallet();
         QString pwd;
@@ -408,19 +427,24 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
 
                     // Get password
                     if (useKWallet) {
-                        SKGTRACEINRC(10, "SKGFilePlugin::onOpen-get kwallet passport", err);
                         // Use KWallet
                         QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
-                        if (walletName.isEmpty()) walletName = "kdewallet";
+                        if (walletName.isEmpty()) {
+                            walletName = "kdewallet";
+                        }
                         KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
                         if (w) {
                             // Change folder
-                            if (!w->hasFolder(programName)) w->createFolder(programName);
+                            if (!w->hasFolder(programName)) {
+                                w->createFolder(programName);
+                            }
                             w->setFolder(programName);
 
                             // Read password
                             w->readPassword(fileName, pwd);
-                            if (pwd.isEmpty()) useKWallet = false;
+                            if (pwd.isEmpty()) {
+                                useKWallet = false;
+                            }
 
                             delete w;
                             w = NULL;
@@ -431,14 +455,18 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                         // Use password dialog
                         QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
                         dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
-                        if (dlg->exec() == QDialog::Accepted) pwd = dlg->password();
+                        if (dlg->exec() == QDialog::Accepted) {
+                            pwd = dlg->password();
+                        }
                         delete dlg;
                     }
 
                     // Load file
                     if (!pwd.isEmpty()) {
                         KSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
-                        if (splashScreen) splashScreen->hide();
+                        if (splashScreen) {
+                            splashScreen->hide();
+                        }
 
                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                         err = m_currentDocument->load(fileName, pwd, restoreTmpFile);
@@ -454,7 +482,9 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                         }
                         QApplication::restoreOverrideCursor();
 
-                        if (splashScreen) splashScreen->show();
+                        if (splashScreen) {
+                            splashScreen->show();
+                        }
                     }
                 } while (err);
             }
@@ -479,7 +509,9 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
                 if (skgfile_settings::storeInKdeWallet() && !useKWallet) {
                     // Use KWallet
                     QString walletName = KWallet::Wallet::walletList().value(SKGServices::stringToInt(skgfile_settings::selectedWallet()));
-                    if (walletName.isEmpty()) walletName = "kdewallet";
+                    if (walletName.isEmpty()) {
+                        walletName = "kdewallet";
+                    }
                     KWallet::Wallet* w = KWallet::Wallet::openWallet(walletName, SKGMainPanel::getMainPanel()->winId());
                     if (w) {
                         // Change folder
@@ -517,7 +549,7 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
 void SKGFilePlugin::onRecover()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::onRecover", err);
+    SKGTRACEINFUNCRC(10, err);
     QAction* act = qobject_cast< QAction* >(sender());
     if (act && m_currentDocument && SKGMainPanel::getMainPanel()) {
         QStringList params = SKGServices::splitCSVLine(act->data().toString());
@@ -543,12 +575,13 @@ void SKGFilePlugin::onRecover()
 void SKGFilePlugin::onChangePassword()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGFilePlugin::onChangePassword", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QPointer<KNewPasswordDialog> dlg = new KNewPasswordDialog(SKGMainPanel::getMainPanel());
         dlg->setPrompt(i18n("Take care, if you lose your <b>password</b> then it will be <u><b>impossible</b></u> to open your document."));
-        if (!dlg->exec()) err = SKGError(0, i18nc("Successfully changed the document password", "Changing password was canceled."));
-        else {
+        if (!dlg->exec()) {
+            err = SKGError(0, i18nc("Successfully changed the document password", "Changing password was canceled."));
+        } else {
             SKGBEGINLIGHTTRANSACTION(*m_currentDocument, i18nc("Action allowing user to change the document password", "Change password"), err);
             err = m_currentDocument->changePassword(dlg->password());
 
@@ -567,7 +600,7 @@ void SKGFilePlugin::onChangePassword()
 
 SKGAdviceList SKGFilePlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGFilePlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Backup
