@@ -50,12 +50,12 @@ SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* iWidget, QObject* iParent, const Q
     m_undoSaveAction(NULL), m_undoAction(NULL), m_redoAction(NULL), m_undoMenu(NULL), m_redoMenu(NULL), m_currentDocument(NULL), m_dockWidget(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::SKGUndoRedoPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGUndoRedoPlugin::~SKGUndoRedoPlugin()
 {
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::~SKGUndoRedoPlugin");
+    SKGTRACEINFUNC(10);
     m_currentDocument = NULL;
     m_dockWidget = NULL;
     m_undoSaveAction = NULL;
@@ -67,7 +67,7 @@ SKGUndoRedoPlugin::~SKGUndoRedoPlugin()
 
 bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
 
     m_currentDocument = iDocument;
@@ -129,32 +129,46 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
 void SKGUndoRedoPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::refresh");
+    SKGTRACEINFUNC(10);
 
     if (m_currentDocument) {
         bool undoPossible = (m_currentDocument->getNbTransaction(SKGDocument::UNDO) > 0);
-        if (m_undoSaveAction) m_undoSaveAction->setEnabled(undoPossible);
-        if (m_undoAction) m_undoAction->setEnabled(undoPossible);
-        if (m_redoAction) m_redoAction->setEnabled(m_currentDocument->getNbTransaction(SKGDocument::REDO) > 0);
+        if (m_undoSaveAction) {
+            m_undoSaveAction->setEnabled(undoPossible);
+        }
+        if (m_undoAction) {
+            m_undoAction->setEnabled(undoPossible);
+        }
+        if (m_redoAction) {
+            m_redoAction->setEnabled(m_currentDocument->getNbTransaction(SKGDocument::REDO) > 0);
+        }
 
         // Refresh undo redo
         QString name;
         m_currentDocument->getTransactionToProcess(SKGDocument::UNDO, &name);
         QString message = i18nc("Verb",  "Undo operation '%1'.", name);
-        if (name.isEmpty()) message = "";
-        if (m_undoAction) m_undoAction->setStatusTip(message);
+        if (name.isEmpty()) {
+            message = "";
+        }
+        if (m_undoAction) {
+            m_undoAction->setStatusTip(message);
+        }
 
         m_currentDocument->getTransactionToProcess(SKGDocument::REDO, &name);
         message = i18nc("Verb",  "Redo operation '%1'.", name);
-        if (name.isEmpty()) message = "";
-        if (m_redoAction) m_redoAction->setStatusTip(message);
+        if (name.isEmpty()) {
+            message = "";
+        }
+        if (m_redoAction) {
+            m_redoAction->setStatusTip(message);
+        }
     }
 }
 
 
 QWidget* SKGUndoRedoPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     // Read Setting
     if (m_currentDocument) {
         KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -183,8 +197,12 @@ SKGError SKGUndoRedoPlugin::savePreferences() const
         QString clean = (skgundoredo_settings::cleanHistoryOnSave() ? "Y" : "N");
 
         // Save setting in document
-        if (max != m_currentDocument->getParameter("SKG_UNDO_MAX_DEPTH")) err = m_currentDocument->setParameter("SKG_UNDO_MAX_DEPTH", max);
-        if (clean != m_currentDocument->getParameter("SKG_UNDO_CLEAN_AFTER_SAVE")) err = m_currentDocument->setParameter("SKG_UNDO_CLEAN_AFTER_SAVE", clean);
+        if (max != m_currentDocument->getParameter("SKG_UNDO_MAX_DEPTH")) {
+            err = m_currentDocument->setParameter("SKG_UNDO_MAX_DEPTH", max);
+        }
+        if (clean != m_currentDocument->getParameter("SKG_UNDO_CLEAN_AFTER_SAVE")) {
+            err = m_currentDocument->setParameter("SKG_UNDO_CLEAN_AFTER_SAVE", clean);
+        }
     }
     return err;
 }
@@ -219,7 +237,7 @@ int SKGUndoRedoPlugin::getOrder() const
 
 SKGAdviceList SKGUndoRedoPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGUndoRedoPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
     if (!iIgnoredAdvice.contains("skgundoredoplugin_too_big")) {
         // Get nb transaction
@@ -255,7 +273,7 @@ SKGError SKGUndoRedoPlugin::executeAdviceCorrection(const QString& iAdviceIdenti
 void SKGUndoRedoPlugin::onClearHistory()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUndoRedoPlugin::onUndoSave", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         err = m_currentDocument->removeAllTransactions();
@@ -275,7 +293,7 @@ void SKGUndoRedoPlugin::onClearHistory()
 void SKGUndoRedoPlugin::onUndoSave()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUndoRedoPlugin::onUndoSave", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDOLASTSAVE);
@@ -295,12 +313,13 @@ void SKGUndoRedoPlugin::onUndoSave()
 void SKGUndoRedoPlugin::onUndo()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUndoRedoPlugin::onUndo", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         int pos = static_cast<QAction*>(sender())->data().toInt();
-        for (int i = 1 ; !err && i <= pos; ++i)
+        for (int i = 1 ; !err && i <= pos; ++i) {
             err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDO);
+        }
         QApplication::restoreOverrideCursor();
 
         // status bar
@@ -335,12 +354,13 @@ void SKGUndoRedoPlugin::onShowUndoMenu()
 void SKGUndoRedoPlugin::onRedo()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUndoRedoPlugin::onRedo", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_currentDocument && SKGMainPanel::getMainPanel()) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         int pos = static_cast<QAction*>(sender())->data().toInt();
-        for (int i = 1 ; !err && i <= pos; ++i)
+        for (int i = 1 ; !err && i <= pos; ++i) {
             err = m_currentDocument->undoRedoTransaction(SKGDocument::REDO);
+        }
         QApplication::restoreOverrideCursor();
 
         // status bar
