@@ -32,8 +32,10 @@
 SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
     : SKGWidget(iDocument)
 {
-    SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -61,12 +63,12 @@ SKGUndoRedoPluginDockWidget::SKGUndoRedoPluginDockWidget(SKGDocument* iDocument)
 
 SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget()
 {
-    SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::~SKGUndoRedoPluginDockWidget");
+    SKGTRACEINFUNC(1);
 }
 
 void SKGUndoRedoPluginDockWidget::onClearHistory()
 {
-    SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::onClearHistory");
+    SKGTRACEINFUNC(1);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     SKGError err = getDocument()->removeAllTransactions();
     QApplication::restoreOverrideCursor();
@@ -83,7 +85,7 @@ void SKGUndoRedoPluginDockWidget::onClearHistory()
 
 void SKGUndoRedoPluginDockWidget::onUndoRedo(const QModelIndex& index)
 {
-    SKGTRACEIN(1, "SKGUndoRedoPluginDockWidget::onUndoRedo");
+    SKGTRACEINFUNC(1);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     // Get Selection
