@@ -47,7 +47,7 @@ SKGImportPluginCsv::SKGImportPluginCsv(QObject* iImporter, const QVariantList& i
     : SKGImportPlugin(iImporter),
       m_csvSeparator(';'), m_csvHeaderIndex(-1)
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::SKGImportPluginCsv");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 
     m_parameters["mapping_date"] = "^date";
@@ -99,7 +99,7 @@ void SKGImportPluginCsv::setImportParameters(const QMap< QString, QString >& iPa
 
 bool SKGImportPluginCsv::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::isImportPossible");
+    SKGTRACEINFUNC(10);
     return isExportPossible();
 }
 
@@ -111,6 +111,19 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
     // Split first line
     QStringList csvAttributes = SKGServices::splitCSVLine(line, ';', true, &m_csvSeparator);
     int nb = csvAttributes.count();
+
+    // If the split fails, we try with an other separator
+    if (nb == 1)  {
+        csvAttributes = SKGServices::splitCSVLine(line, ',', true, &m_csvSeparator);
+        nb = csvAttributes.count();
+
+        // If the split fails, we try with an other separator
+        if (nb == 1)  {
+            csvAttributes = SKGServices::splitCSVLine(line, '\t', true, &m_csvSeparator);
+            nb = csvAttributes.count();
+        }
+    }
+
     for (int i = 0; i < nb; ++i) {
         QString att = csvAttributes[i].toLower();
 
@@ -143,7 +156,9 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
             found = true;
         }
 
-        if (!found) output.push_back("");      // To ignore this column
+        if (!found) {
+            output.push_back("");    // To ignore this column
+        }
     }
     return output;
 }
@@ -151,7 +166,7 @@ QStringList SKGImportPluginCsv::getCSVMappingFromLine(const QString& iLine)
 SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportPluginCsv::setCSVMapping", err);
+    SKGTRACEINFUNCRC(10, err);
 
     m_csvMapping.clear();
 
@@ -159,19 +174,24 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
         // Automatic build
         // Open file
         QFile file(m_importer->getLocalFileName());
-        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-        else {
+        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        } else {
             QTextStream stream(&file);
-            if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+            if (!m_importer->getCodec().isEmpty()) {
+                stream.setCodec(m_importer->getCodec().toAscii().constData());
+            }
 
             // Ignore useless lines
             int headerIndex = getCSVHeaderIndex();
-            for (int i = 1; i < headerIndex; ++i)
+            for (int i = 1; i < headerIndex; ++i) {
                 stream.readLine();
+            }
 
             // Get mapping
-            if (!stream.atEnd()) m_csvMapping = getCSVMappingFromLine(stream.readLine());
-            else {
+            if (!stream.atEnd()) {
+                m_csvMapping = getCSVMappingFromLine(stream.readLine());
+            } else {
                 err.setReturnCode(ERR_INVALIDARG);
             }
 
@@ -185,8 +205,9 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
 
     IFOK(err) {
         // Check if mandatory attributes have been found
-        if (!m_csvMapping.contains("date") || !m_csvMapping.contains("amount"))
+        if (!m_csvMapping.contains("date") || !m_csvMapping.contains("amount")) {
             err = SKGError(ERR_FAIL, i18nc("Error message",  "Columns date and amount not found. Set import parameters in settings."));
+        }
     }
 
     return err;
@@ -194,30 +215,35 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
 
 QStringList SKGImportPluginCsv::getCSVMapping() const
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::getCSVMapping");
+    SKGTRACEINFUNC(10);
     return m_csvMapping;
 }
 
 SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportPluginCsv::setCSVHeaderIndex", err);
+    SKGTRACEINFUNCRC(10, err);
 
     if (iIndex == -1) {
         // Automatic build
         // Open file
         QFile file(m_importer->getLocalFileName());
-        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-        else {
+        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        } else {
             QTextStream stream(&file);
-            if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+            if (!m_importer->getCodec().isEmpty()) {
+                stream.setCodec(m_importer->getCodec().toAscii().constData());
+            }
 
             int i = 1;
             m_csvHeaderIndex = -1;
             while (!stream.atEnd() && m_csvHeaderIndex == -1) {
                 // Read line
                 QStringList map = getCSVMappingFromLine(stream.readLine());
-                if (map.contains("date") && map.contains("amount")) m_csvHeaderIndex = i;
+                if (map.contains("date") && map.contains("amount")) {
+                    m_csvHeaderIndex = i;
+                }
 
                 ++i;
             }
@@ -235,24 +261,30 @@ SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
 
 int SKGImportPluginCsv::getCSVHeaderIndex()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::getCSVHeaderIndex");
-    if (m_csvHeaderIndex == -1) setCSVHeaderIndex(-1);
+    SKGTRACEINFUNC(10);
+    if (m_csvHeaderIndex == -1) {
+        setCSVHeaderIndex(-1);
+    }
     return m_csvHeaderIndex;
 }
 
 QChar SKGImportPluginCsv::getCSVSeparator()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::getCSVSeparator");
+    SKGTRACEINFUNC(10);
     return m_csvSeparator;
 }
 
 SKGError SKGImportPluginCsv::importFile()
 {
-    if (m_parameters["mode_csv_unit"] == "Y") return importCSVUnit();
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (m_parameters["mode_csv_unit"] == "Y") {
+        return importCSVUnit();
+    }
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
 
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginCsv::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
     // Begin transaction
     err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "CSV"), 3);
     IFOK(err) {
@@ -273,22 +305,30 @@ SKGError SKGImportPluginCsv::importFile()
         // Open file
         IFOK(err) {
             QFile file(m_importer->getLocalFileName());
-            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-            else {
+            if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+            } else {
                 QTextStream stream(&file);
-                if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+                if (!m_importer->getCodec().isEmpty()) {
+                    stream.setCodec(m_importer->getCodec().toAscii().constData());
+                }
 
                 // Ignore useless lines
                 int headerIndex = getCSVHeaderIndex();
-                if (headerIndex == -1) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Header not found in CSV file"));
+                if (headerIndex == -1) {
+                    err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Header not found in CSV file"));
+                }
 
-                for (int i = 1; i <= headerIndex; ++i)
+                for (int i = 1; i <= headerIndex; ++i) {
                     stream.readLine();
+                }
 
                 QList<int> amountIndexes;
                 int nb = getCSVMapping().count();
                 for (int i = 0; i < nb; ++i) {
-                    if (getCSVMapping()[i] == "amount") amountIndexes.push_back(i);
+                    if (getCSVMapping()[i] == "amount") {
+                        amountIndexes.push_back(i);
+                    }
                 }
                 int nbAmount = amountIndexes.count();
 
@@ -314,13 +354,17 @@ SKGError SKGImportPluginCsv::importFile()
                                     lines.push_back(currentLine);
                                     currentLine.clear();
 
-                                    if (posdate < field.count()) dates.push_back(field.at(posdate).trimmed());
+                                    if (posdate < field.count()) {
+                                        dates.push_back(field.at(posdate).trimmed());
+                                    }
 
                                     // Check if all amounts are positive
                                     if (modeAutoCreditDebit) {
                                         for (int i = 0; modeAutoCreditDebit && i < nbAmount; ++i) {
                                             QString s = field.at(amountIndexes.at(i)).trimmed();
-                                            if (!s.isEmpty() && SKGServices::stringToDouble(s) < 0) modeAutoCreditDebit = false;
+                                            if (!s.isEmpty() && SKGServices::stringToDouble(s) < 0) {
+                                                modeAutoCreditDebit = false;
+                                            }
                                         }
                                     }
                                 }
@@ -334,8 +378,12 @@ SKGError SKGImportPluginCsv::importFile()
 
                 // Select dateformat
                 QString dateFormat = m_parameters["date_format"];
-                if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates);  // Automatic detection
-                if (!err && dateFormat.isEmpty())err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+                if (dateFormat.isEmpty()) {
+                    dateFormat = SKGServices::getDateFormat(dates);    // Automatic detection
+                }
+                if (!err && dateFormat.isEmpty()) {
+                    err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+                }
                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
                 // Step 2 done
@@ -350,7 +398,9 @@ SKGError SKGImportPluginCsv::importFile()
                     QString mappingDesc;
                     int nbMap = getCSVMapping().count();
                     for (int i = 0; i < nbMap; ++i) {
-                        if (i) mappingDesc += '|';
+                        if (i) {
+                            mappingDesc += '|';
+                        }
                         mappingDesc += getCSVMapping().at(i);
                     }
                     IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_CSV_MAPPING_USED", mappingDesc))
@@ -369,12 +419,16 @@ SKGError SKGImportPluginCsv::importFile()
                         SKGSubOperationObject currentSubOperation(m_importer->getDocument());
 
                         // Valuate mandatory attribute with default value
-                        if (noUnitColumn && i == 0) err = m_importer->getDefaultUnit(defUnit);
+                        if (noUnitColumn && i == 0) {
+                            err = m_importer->getDefaultUnit(defUnit);
+                        }
                         IFOKDO(err, currentOperation.setUnit(defUnit))
 
                         if (!err && noAccountColumn) {
                             err = m_importer->getDefaultAccount(defAccount);
-                            if (i == 0) emptyAccount = (defAccount.getNbOperation() == 0);
+                            if (i == 0) {
+                                emptyAccount = (defAccount.getNbOperation() == 0);
+                            }
                             IFOKDO(err, currentOperation.setParentAccount(defAccount))
                         }
 
@@ -399,15 +453,22 @@ SKGError SKGImportPluginCsv::importFile()
                             QString col = getCSVMapping()[c];
                             if (!col.isEmpty()) {
                                 QString val;
-                                if (c >= 0 && c < atts.count()) val = atts.at(c).trimmed();
+                                if (c >= 0 && c < atts.count()) {
+                                    val = atts.at(c).trimmed();
+                                }
                                 if (col == "date") {
                                     err = currentOperation.setDate(SKGServices::stringToTime(SKGServices::dateToSqlString(val, dateFormat)).date());
-                                    if (val == "0000-00-00") initialBalance = true;
+                                    if (val == "0000-00-00") {
+                                        initialBalance = true;
+                                    }
                                 } else if (col == "number") {
-                                    if (!val.isEmpty()) err = currentOperation.setNumber(SKGServices::stringToInt(val));
+                                    if (!val.isEmpty()) {
+                                        err = currentOperation.setNumber(SKGServices::stringToInt(val));
+                                    }
                                 } else if (col == "mode") {
-                                    if (val == "1") val = i18nc("An operation mode", "Transfer");
-                                    else if (val == "2") {
+                                    if (val == "1") {
+                                        val = i18nc("An operation mode", "Transfer");
+                                    } else if (val == "2") {
                                         val = i18nc("An operation mode", "Direct debit");
                                     } else if (val == "3") {
                                         val = i18nc("An operation mode", "Check");
@@ -427,7 +488,9 @@ SKGError SKGImportPluginCsv::importFile()
                                     IFOKDO(err, currentOperation.setPayee(payeeObj))
                                 } else if (col == "comment") {
                                     QString comment = currentOperation.getComment();
-                                    if (!comment.isEmpty()) comment += ' ';
+                                    if (!comment.isEmpty()) {
+                                        comment += ' ';
+                                    }
                                     comment += val;
                                     err = currentOperation.setComment(comment);
                                     IFOKDO(err, currentSubOperation.setComment(comment))
@@ -449,14 +512,18 @@ SKGError SKGImportPluginCsv::importFile()
                                         } else {
                                             err = currentSubOperation.setQuantity(sign * SKGServices::stringToDouble(val));
                                         }
-                                    } else if (modeAutoCreditDebit) sign = 1.0;  // Next one will be considered as a credit
+                                    } else if (modeAutoCreditDebit) {
+                                        sign = 1.0;    // Next one will be considered as a credit
+                                    }
                                 } else if (col == "quantity") {
                                     err = currentSubOperation.setQuantity(SKGServices::stringToDouble(val));
                                 } else if (col == "sign") {
                                     if (QRegExp(m_parameters["mapping_debit"], Qt::CaseInsensitive).indexIn(val) != -1) {
                                         sign = -1;
                                         double cval = currentSubOperation.getQuantity();
-                                        if (cval > 0) err = currentSubOperation.setQuantity(-cval);
+                                        if (cval > 0) {
+                                            err = currentSubOperation.setQuantity(-cval);
+                                        }
                                     }
                                 } else if (col == "unit") {
                                     // Looking for unit
@@ -464,7 +531,9 @@ SKGError SKGImportPluginCsv::importFile()
                                     if (val != defUnit.getName()) {  // For performance
                                         err = unit.setName(val);
                                         IFOKDO(err, unit.setSymbol(val))
-                                        if (!err && unit.load().isFailed())  err = unit.save(false);    // Save only
+                                        if (!err && unit.load().isFailed()) {
+                                            err = unit.save(false);    // Save only
+                                        }
 
                                         // This unit is now the default one, it's better for performance
                                         defUnit = unit;
@@ -503,7 +572,9 @@ SKGError SKGImportPluginCsv::importFile()
                                             }
                                             IFOKDO(err, bank.addAccount(account))
                                             IFOKDO(err, account.setName(val))
-                                            if (!err && account.load().isFailed())  err = account.save(false);     // Save only
+                                            if (!err && account.load().isFailed()) {
+                                                err = account.save(false);    // Save only
+                                            }
                                         }
 
                                         // This account is now the default one, it's better for performance
@@ -519,7 +590,9 @@ SKGError SKGImportPluginCsv::importFile()
                                         val.replace(',', OBJECTSEPARATOR);
                                         val.replace(';', OBJECTSEPARATOR);
                                         // Get previous category
-                                        if (!currentCategory.isEmpty()) val = currentCategory % OBJECTSEPARATOR % val;
+                                        if (!currentCategory.isEmpty()) {
+                                            val = currentCategory % OBJECTSEPARATOR % val;
+                                        }
                                         currentCategory = val;
 
                                         // Create and set category
@@ -539,6 +612,7 @@ SKGError SKGImportPluginCsv::importFile()
                             // Specific values for initial balance
                             err = currentOperation.setStatus(SKGOperationObject::CHECKED);
                             IFOKDO(err, currentOperation.setAttribute("d_date", "0000-00-00"))
+                            IFOKDO(err, currentSubOperation.setAttribute("d_date", "0000-00-00"))
                         }
                         IFOKDO(err, currentOperation.setImportID(hash.toHex()))
                         IFOK(err) {
@@ -577,7 +651,9 @@ SKGError SKGImportPluginCsv::importFile()
                             err = currentOperation.setProperty(propertiesAtt.at(p) , propertiesVal.at(p));
                         }
 
-                        if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        if (!err && i % 500 == 0) {
+                            err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
@@ -616,22 +692,27 @@ SKGError SKGImportPluginCsv::importFile()
 
 bool SKGImportPluginCsv::isExportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "CSV");
 }
 
 SKGError SKGImportPluginCsv::exportFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportCsv::exportFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Open file
     KSaveFile file(m_importer->getLocalFileName(false));
-    if (!file.open())err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-    else {
+    if (!file.open()) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+    } else {
         QTextStream out(&file);
-        if (!m_importer->getCodec().isEmpty()) out.setCodec(m_importer->getCodec().toAscii().constData());
+        if (!m_importer->getCodec().isEmpty()) {
+            out.setCodec(m_importer->getCodec().toAscii().constData());
+        }
         err = m_importer->getDocument()->dumpSelectSqliteOrder(
                   "SELECT v.d_date as date, v.t_ACCOUNT as account, v.i_number as number, v.t_mode as mode, "
                   "v.t_PAYEE as payee, v.t_REALCOMMENT as comment, ROUND(v.f_REALQUANTITY, u.i_nbdecimal) as quantity, "
@@ -655,7 +736,7 @@ QString SKGImportPluginCsv::getMimeTypeFilter() const
 SKGError SKGImportPluginCsv::importCSVUnit()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginCsv::importCSVUnit", err);
+    SKGTRACEINFUNCRC(2, err);
 
     if (m_importer->getDocument()) {
         // Begin transaction
@@ -677,15 +758,19 @@ SKGError SKGImportPluginCsv::importCSVUnit()
             // Open file
             IFOK(err) {
                 QFile file(m_importer->getLocalFileName());
-                if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-                else {
+                if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                    err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+                } else {
                     QTextStream stream(&file);
-                    if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+                    if (!m_importer->getCodec().isEmpty()) {
+                        stream.setCodec(m_importer->getCodec().toAscii().constData());
+                    }
 
                     // Ignore useless lines
                     int headerIndex = getCSVHeaderIndex();
-                    for (int i = 1; i <= headerIndex; ++i)
+                    for (int i = 1; i <= headerIndex; ++i) {
                         stream.readLine();
+                    }
 
                     // Get data column
                     QStringList dates;
@@ -699,8 +784,10 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                                 lines.push_back(line);
 
                                 // Get date
-                                QStringList field = SKGServices::splitCSVLine(line);
-                                if (posdate < field.count()) dates.push_back(field.at(posdate));
+                                QStringList field = SKGServices::splitCSVLine(line, getCSVSeparator());
+                                if (posdate < field.count()) {
+                                    dates.push_back(field.at(posdate));
+                                }
                             }
                         }
                     }
@@ -710,7 +797,9 @@ SKGError SKGImportPluginCsv::importCSVUnit()
 
                     // Select dateformat
                     QString dateFormat = SKGServices::getDateFormat(dates);
-                    if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+                    if (dateFormat.isEmpty()) {
+                        err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+                    }
                     IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
                     // Step 2 done
@@ -725,7 +814,9 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                         QString mappingDesc;
                         int nbMap = m_csvMapping.count();
                         for (int i = 0; i < nbMap; ++i) {
-                            if (i) mappingDesc += '|';
+                            if (i) {
+                                mappingDesc += '|';
+                            }
                             mappingDesc += m_csvMapping.at(i);
                         }
                         IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_CSV_UNIT_MAPPING_USED", mappingDesc))
@@ -734,7 +825,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                         int posvalue = m_csvMapping.indexOf("amount");
                         if (posdate2 != -1 && posvalue != -1) {
                             for (int i = 0; !err && i < nb; ++i) {
-                                QStringList atts = SKGServices::splitCSVLine(lines.at(i));
+                                QStringList atts = SKGServices::splitCSVLine(lines.at(i), getCSVSeparator());
                                 err = m_importer->getDocument()->addOrModifyUnitValue(unitName,
                                         SKGServices::stringToTime(SKGServices::dateToSqlString(atts.at(posdate2), dateFormat)).date(),
                                         SKGServices::stringToDouble(atts.at(posvalue)));
