@@ -56,7 +56,7 @@ K_EXPORT_PLUGIN(SKGImportPluginGncFactory("skrooge_import_gnc", "skrooge_import_
 SKGImportPluginGnc::SKGImportPluginGnc(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginGnc::SKGImportPluginGnc");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -66,22 +66,27 @@ SKGImportPluginGnc::~SKGImportPluginGnc()
 
 bool SKGImportPluginGnc::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::isImportPossible");
-    if (!m_importer) return true;
+    SKGTRACEINFUNC(10);
+    if (!m_importer) {
+        return true;
+    }
     QString extension = m_importer->getFileNameExtension();
     return (extension == "UNCOMPRESSED" || extension == "GNUCASH" || extension == "GNC");
 }
 
 SKGError SKGImportPluginGnc::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginGnc::importFile(", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    else {
+    if (!file->open(QIODevice::ReadOnly)) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    } else {
         QDomDocument doc;
 
         // Set the file without uncompression
@@ -91,8 +96,9 @@ SKGError SKGImportPluginGnc::importFile()
         bool contentOK = doc.setContent(file->readAll(), &errorMsg, &errorLine, &errorCol);
         file->close();
 
-        if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        else {
+        if (!contentOK) {
+            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        } else {
             // Get root
             QDomElement docElem = doc.documentElement();
 
@@ -132,7 +138,9 @@ SKGError SKGImportPluginGnc::importFile()
                                     IFOKDO(err, unitObj.save())
                                 }
 
-                                if (!err && !defaultUnit.exist()) defaultUnit = unitObj;
+                                if (!err && !defaultUnit.exist()) {
+                                    defaultUnit = unitObj;
+                                }
 
                                 mapUnitIdUnit[unitName.text()] = unitObj;
                             }
@@ -183,8 +191,9 @@ SKGError SKGImportPluginGnc::importFile()
                                         QString fullName = realAccountName;
 
                                         QDomElement accountParent = account.firstChildElement("act:parent");
-                                        if (!err && !accountParent.isNull() && mapIdType[accountParent.text()] == 'C')
+                                        if (!err && !accountParent.isNull() && mapIdType[accountParent.text()] == 'C') {
                                             fullName = mapIdName[accountParent.text()] % OBJECTSEPARATOR % fullName;
+                                        }
 
                                         SKGCategoryObject catObj;
                                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), fullName, catObj);
@@ -212,19 +221,37 @@ SKGError SKGImportPluginGnc::importFile()
                                             realAccountName = accountName.text() % " (" % SKGServices::intToString(index) % ')';
                                             err = act.setName(realAccountName);
                                         }
-                                        if (!err && accountCode.isNull()) err = act.setNumber(accountCode.text());
+                                        if (!err && accountCode.isNull()) {
+                                            err = act.setNumber(accountCode.text());
+                                        }
                                         IFOKDO(err, act.setType(type == "ASSET" ? SKGAccountObject::ASSETS :
                                                                 type == "STOCK" || type == "MUTUAL" || type == "RECEIVABLE" || type == "PAYABLE" || type == "TRADING" ? SKGAccountObject::INVESTMENT :
                                                                 type == "CASH" ? SKGAccountObject::WALLET :
                                                                 type == "LIABILITY" ? SKGAccountObject::LOAN :
                                                                 type == "CREDIT" ? SKGAccountObject::CREDITCARD : SKGAccountObject::CURRENT))
                                         IFOKDO(err, act.save())
+                                        
+                                        // Change parent bank in case of ASSETS
+                                        if(act.getType() == SKGAccountObject::WALLET) {
+                                            // Get blank bank
+                                            SKGBankObject blankBank(m_importer->getDocument());
+                                            IFOKDO(err, blankBank.setName(""))
+                                            if (blankBank.exist()) {
+                                                err = blankBank.load();
+                                            } else {
+                                                err = blankBank.save();
+                                            }                                            
+                                            IFOKDO(err, act.setBank(blankBank))
+                                            IFOKDO(err, act.save())                                      
+                                        }
 
                                         mapIdAccount[accountId.text()] = act;
                                         mapIdType[accountId.text()] = 'A';  // Memorize an account
 
                                         QDomNodeList accountUnits = account.elementsByTagName("cmdty:id");
-                                        if (!err && accountUnits.count()) mapIdUnit[accountId.text()] = mapUnitIdUnit[accountUnits.at(0).toElement().text()];
+                                        if (!err && accountUnits.count()) {
+                                            mapIdUnit[accountId.text()] = mapUnitIdUnit[accountUnits.at(0).toElement().text()];
+                                        }
                                     } else if (type == "EQUITY") {
                                         mapIdType[accountId.text()] = 'E';  // Memorize an account
                                     } else {
@@ -264,7 +291,9 @@ SKGError SKGImportPluginGnc::importFile()
                                 // Format 2007-01-13 00:00:00 +0100
                                 err = operationObj.setDate(QDate::fromString(operationDate.text().left(10), "yyyy-MM-dd"));
                             }
-                            if (!err && !operationNumber.isNull()) err = operationObj.setNumber(SKGServices::stringToInt(operationNumber.text()));
+                            if (!err && !operationNumber.isNull()) {
+                                err = operationObj.setNumber(SKGServices::stringToInt(operationNumber.text()));
+                            }
                             if (!err && !operationPayee.isNull()) {
                                 SKGPayeeObject payeeObject;
                                 err = SKGPayeeObject::createPayee(m_importer->getDocument(), operationPayee.text(), payeeObject);
@@ -297,7 +326,6 @@ SKGError SKGImportPluginGnc::importFile()
 
                             // Get splits
                             bool parentSet = false;
-                            double quantity = 0;
                             QDomElement splits = operation.firstChildElement("trn:splits");
 
                             QList<SubOpInfo> suboperationsList;
@@ -391,8 +419,12 @@ SKGError SKGImportPluginGnc::importFile()
                                     QString val = suboperationReconciled.text();
                                     IFOKDO(err, operationObj.setStatus(val == "c" ? SKGOperationObject::POINTED : val == "y" ? SKGOperationObject::CHECKED : SKGOperationObject::NONE))
                                 }
-                                if (!err && !suboperationMemo.isNull() && operationObj.getComment().isEmpty()) err = operationObj.setComment(suboperationMemo.text());
-                                if (!err && !suboperationAction.isNull() && operationObj.getMode().isEmpty()) err = operationObj.setMode(suboperationAction.text());
+                                if (!err && !suboperationMemo.isNull() && operationObj.getComment().isEmpty()) {
+                                    err = operationObj.setComment(suboperationMemo.text());
+                                }
+                                if (!err && !suboperationAction.isNull() && operationObj.getMode().isEmpty()) {
+                                    err = operationObj.setMode(suboperationAction.text());
+                                }
                                 IFOKDO(err, operationObj.save())
 
                                 QChar accountType = mapIdType[suboperationInfo.account.text()];
@@ -401,16 +433,23 @@ SKGError SKGImportPluginGnc::importFile()
                                     SKGCategoryObject cat = mapIdCategory[suboperationInfo.account.text()];
 
                                     double q = -suboperationInfo.value;
-                                    if (!err && (!suboperationObj.exist() || suboperationObj.getQuantity() != q)) err = operationObj.addSubOperation(suboperationObj);
+                                    if (!err && (!suboperationObj.exist() || suboperationObj.getQuantity() != q)) {
+                                        err = operationObj.addSubOperation(suboperationObj);
+                                    }
                                     IFOKDO(err, suboperationObj.setQuantity(q))
                                     IFOKDO(err, suboperationObj.setCategory(cat))
-                                    if (!err && !suboperationMemo.isNull()) err = suboperationObj.setComment(suboperationMemo.text());
+                                    if (!err && !suboperationMemo.isNull()) {
+                                        err = suboperationObj.setComment(suboperationMemo.text());
+                                    }
                                     IFOKDO(err, suboperationObj.save())
                                 } else if (accountType == 'E') {
                                     // Set as initial balance
                                     IFOKDO(err, operationObj.setAttribute("d_date", "0000-00-00"))
                                     IFOKDO(err, operationObj.setStatus(SKGOperationObject::CHECKED))
                                     IFOKDO(err, operationObj.save())
+
+                                    IFOKDO(err, suboperationObj.setAttribute("d_date", "0000-00-00"))
+                                    IFOKDO(err, suboperationObj.save())
                                 } else if (accountType == 'A') {
                                     // It is a transfer of account
                                     SKGAccountObject act(m_importer->getDocument());
@@ -419,7 +458,7 @@ SKGError SKGImportPluginGnc::importFile()
 
                                     // Set Unit
                                     SKGUnitObject unitName = mapIdUnit[suboperationInfo.account.text()];
-
+                                    double quantity = 0;
                                     if (parentSet) {
                                         // If the parent is already set, it means that is a transfer
                                         SKGOperationObject operationObj2;
@@ -427,7 +466,9 @@ SKGError SKGImportPluginGnc::importFile()
                                         IFOKDO(err, operationObj2.setDate(operationObj.getDate()))
                                         IFOKDO(err, operationObj2.setNumber(operationObj.getNumber()))
                                         IFOKDO(err, operationObj2.setMode(operationObj.getMode()))
-                                        if (!err && !suboperationMemo.isNull()) err = operationObj2.setComment(suboperationMemo.text());
+                                        if (!err && !suboperationMemo.isNull()) {
+                                            err = operationObj2.setComment(suboperationMemo.text());
+                                        }
                                         SKGPayeeObject payeeObject;
                                         operationObj.getPayee(payeeObject);
                                         IFOKDO(err, operationObj2.setPayee(payeeObject))
@@ -438,7 +479,9 @@ SKGError SKGImportPluginGnc::importFile()
                                         IFOKDO(err, operationObj2.setImported(true))
                                         IFOKDO(err, operationObj2.setImportID(operationObj.getImportID()))
                                         IFOKDO(err, operationObj2.setTemplate(operationObj.isTemplate()))
-                                        if (!err && unitName.exist()) err = operationObj2.setUnit(unitName);
+                                        if (!err && unitName.exist()) {
+                                            err = operationObj2.setUnit(unitName);
+                                        }
                                         IFOKDO(err, operationObj2.save())
                                         IFOKDO(err, operationObj2.setGroupOperation(operationObj))
                                         IFOKDO(err, operationObj2.save())
@@ -451,12 +494,16 @@ SKGError SKGImportPluginGnc::importFile()
                                             quantity = suboperationInfo.value;
                                             err = suboperationObj2.setQuantity(suboperationInfo.value);
                                         }
-                                        if (!err && !suboperationMemo.isNull()) err = suboperationObj2.setComment(suboperationMemo.text());
+                                        if (!err && !suboperationMemo.isNull()) {
+                                            err = suboperationObj2.setComment(suboperationMemo.text());
+                                        }
                                         IFOKDO(err, suboperationObj2.save())
                                     } else {
                                         // We set the parent
                                         IFOKDO(err, operationObj.setParentAccount(act))
-                                        if (!err && unitName.exist()) err = operationObj.setUnit(unitName);
+                                        if (!err && unitName.exist()) {
+                                            err = operationObj.setUnit(unitName);
+                                        }
                                         IFOKDO(err, operationObj.save())
 
                                         // Compute quantity
@@ -467,7 +514,9 @@ SKGError SKGImportPluginGnc::importFile()
                                         if (fabs(quantity) > 10e-9) {
                                             IFOKDO(err, operationObj.addSubOperation(suboperationObj))
                                             IFOKDO(err, suboperationObj.setQuantity(quantity))
-                                            if (!err && !suboperationMemo.isNull()) err = suboperationObj.setComment(suboperationMemo.text());
+                                            if (!err && !suboperationMemo.isNull()) {
+                                                err = suboperationObj.setComment(suboperationMemo.text());
+                                            }
                                             IFOKDO(err, suboperationObj.save())
                                         }
 
@@ -476,7 +525,9 @@ SKGError SKGImportPluginGnc::importFile()
                                 }
                             }
 
-                            if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                            if (!err && i % 500 == 0) {
+                                err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                            }
 
                             IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                         }
@@ -500,7 +551,9 @@ SKGError SKGImportPluginGnc::importFile()
                             QDomElement scheduleOccur = schedule.firstChildElement("sx:num-occur");
                             QDomElement scheduleEnable = schedule.firstChildElement("sx:enabled");
                             QDomElement scheduleLast = schedule.firstChildElement("sx:last");
-                            if (scheduleLast.isNull()) scheduleLast = schedule.firstChildElement("sx:start");
+                            if (scheduleLast.isNull()) {
+                                scheduleLast = schedule.firstChildElement("sx:start");
+                            }
 
                             QDomElement scheduleMult;
                             QDomElement schedulePeriod;
@@ -523,10 +576,18 @@ SKGError SKGImportPluginGnc::importFile()
                                     err = recuOperation.timeLimit(true);
                                     IFOKDO(err, recuOperation.setTimeLimit(SKGServices::stringToInt(scheduleOccur.text())))
                                 }
-                                if (!err && !scheduleAutoCreate.isNull()) err = recuOperation.autoWriteEnabled(scheduleAutoCreate.text() == "y");
-                                if (!err && !scheduleAdvanceCreateDays.isNull()) err = recuOperation.setAutoWriteDays(SKGServices::stringToInt(scheduleAdvanceCreateDays.text()));
-                                if (!err && !scheduleAutoCreateNotify.isNull()) err = recuOperation.warnEnabled(scheduleAutoCreateNotify.text() == "y");
-                                if (!err && !scheduleAdvanceRemindDays.isNull()) err = recuOperation.setWarnDays(SKGServices::stringToInt(scheduleAdvanceRemindDays.text()));
+                                if (!err && !scheduleAutoCreate.isNull()) {
+                                    err = recuOperation.autoWriteEnabled(scheduleAutoCreate.text() == "y");
+                                }
+                                if (!err && !scheduleAdvanceCreateDays.isNull()) {
+                                    err = recuOperation.setAutoWriteDays(SKGServices::stringToInt(scheduleAdvanceCreateDays.text()));
+                                }
+                                if (!err && !scheduleAutoCreateNotify.isNull()) {
+                                    err = recuOperation.warnEnabled(scheduleAutoCreateNotify.text() == "y");
+                                }
+                                if (!err && !scheduleAdvanceRemindDays.isNull()) {
+                                    err = recuOperation.setWarnDays(SKGServices::stringToInt(scheduleAdvanceRemindDays.text()));
+                                }
 
                                 if (!err && !scheduleMult.isNull() && !schedulePeriod.isNull()) {
                                     int p = SKGServices::stringToInt(scheduleMult.text());
@@ -541,7 +602,9 @@ SKGError SKGImportPluginGnc::importFile()
                                     IFOKDO(err, recuOperation.setPeriodUnit(punit))
                                 }
 
-                                if (!err && !scheduleDate.isNull()) err = recuOperation.setDate(QDate::fromString(scheduleDate.text().left(10), "yyyy-MM-dd"));
+                                if (!err && !scheduleDate.isNull()) {
+                                    err = recuOperation.setDate(QDate::fromString(scheduleDate.text().left(10), "yyyy-MM-dd"));
+                                }
                                 IFOKDO(err, recuOperation.setDate(recuOperation.getNextDate()))
                                 if (!err && !scheduleEnable.isNull() && scheduleEnable.text() == "n") {
                                     err = recuOperation.autoWriteEnabled(false);
