@@ -47,7 +47,7 @@ K_EXPORT_PLUGIN(SKGImportPluginGsbFactory("skrooge_import_gsb", "skrooge_import_
 SKGImportPluginGsb::SKGImportPluginGsb(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginGsb::SKGImportPluginGsb");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -56,21 +56,24 @@ SKGImportPluginGsb::~SKGImportPluginGsb()
 
 bool SKGImportPluginGsb::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "GSB");
 }
 
 SKGError SKGImportPluginGsb::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginGsb::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Initialisation
     // Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    else {
+    if (!file->open(QIODevice::ReadOnly)) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    } else {
         QDomDocument doc;
 
         // Set the file without uncompression
@@ -83,8 +86,9 @@ SKGError SKGImportPluginGsb::importFile()
         // Get root
         QDomElement docElem = doc.documentElement();
 
-        if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
-        else {
+        if (!contentOK) {
+            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
+        } else {
             // Check version
             QDomElement general = docElem.firstChildElement("General");
             if (general.isNull()) {
@@ -93,8 +97,9 @@ SKGError SKGImportPluginGsb::importFile()
             }
         }
 
-        if (!contentOK) err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        else {
+        if (!contentOK) {
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        } else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "GSB"), 10);
 
             QMap<QString, SKGUnitObject> mapIdUnit;
@@ -172,7 +177,9 @@ SKGError SKGImportPluginGsb::importFile()
                     // Creation of the account
                     SKGAccountObject accountObj;
                     SKGBankObject bank = mapIdBank[getAttribute(account,  "Bank")];
-                    if (!bank.exist()) bank = bankDefault;
+                    if (!bank.exist()) {
+                        bank = bankDefault;
+                    }
                     IFOKDO(err, bank.addAccount(accountObj))
                     IFOKDO(err, accountObj.setName(getAttribute(account,  "Name")))
                     IFOKDO(err, accountObj.setNumber(getAttribute(account,  "Bank_account_number")))
@@ -344,15 +351,6 @@ SKGError SKGImportPluginGsb::importFile()
                         }
                     }
 
-                    // Fiscal year
-                    IFOK(err) {
-                        QString fiscalYear = getAttribute(transaction,  "Vo");
-                        if (!fiscalYear.isEmpty()) {
-                            err = opObj.setProperty(i18nc("Noun", "Fiscal year"), fiscalYear);
-                            IFOKDO(err, opObj.save())
-                        }
-                    }
-
                     if (getAttribute(transaction,  "Br") == "0") {
                         SKGSubOperationObject subObj;
                         IFOKDO(err, opObj.addSubOperation(subObj))
@@ -362,10 +360,23 @@ SKGError SKGImportPluginGsb::importFile()
                         IFOKDO(err, subObj.setQuantity(SKGServices::stringToDouble(getAttribute(transaction,  "Am"))))
                         IFOKDO(err, subObj.save())
                     }
+                    
+                    // Fiscal year
+                    IFOK(err) {
+                        QString fiscalYear = getAttribute(transaction,  "Vo");
+                        if (!fiscalYear.isEmpty()) {
+                            err = opObj.setProperty(i18nc("Noun", "Fiscal year"), fiscalYear);
+                            IFOKDO(err, opObj.save())
+                        }
+                    }                    
 
-                    mapIdOperation[getAttribute(transaction,  "Nb")] = opObj;
+                    if (parentOpId == "0") {
+                        mapIdOperation[getAttribute(transaction,  "Nb")] = opObj;
+                    }
 
-                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) {
+                        err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
@@ -459,8 +470,9 @@ SKGError SKGImportPluginGsb::importFile()
                             // text_frequency_user [] = { _("Days"), _("Weeks"), _("Months"), _("Years"), NULL };
                             occu = SKGServices::stringToInt(getAttribute(transaction,  "Pep"));
                             QString Pei = getAttribute(transaction,  "Pei");
-                            if (Pei == "0") period = SKGRecurrentOperationObject::DAY;
-                            else if (Pei == "1") {
+                            if (Pei == "0") {
+                                period = SKGRecurrentOperationObject::DAY;
+                            } else if (Pei == "1") {
                                 period = SKGRecurrentOperationObject::WEEK;
                             } else if (Pei == "2") {
                                 period = SKGRecurrentOperationObject::MONTH;
@@ -480,7 +492,9 @@ SKGError SKGImportPluginGsb::importFile()
                     }
                     IFOKDO(err, recuObj.save())
 
-                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) {
+                        err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
@@ -502,7 +516,9 @@ SKGError SKGImportPluginGsb::importFile()
 QString SKGImportPluginGsb::getAttribute(const QDomElement& iElement, const QString& iAttribute)
 {
     QString val = iElement.attribute(iAttribute);
-    if (val == "(null)") val = "";
+    if (val == "(null)") {
+        val = "";
+    }
     return val;
 }
 QString SKGImportPluginGsb::getMimeTypeFilter() const
