@@ -54,7 +54,7 @@ K_EXPORT_PLUGIN(SKGImportPluginMnyFactory("skrooge_import_kmy", "skrooge_import_
 SKGImportPluginMny::SKGImportPluginMny(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginMny::SKGImportPluginMny");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 
     m_parameters["password"] = "";
@@ -89,8 +89,10 @@ bool SKGImportPluginMny::removeDir(const QString& dirName)
 
 bool SKGImportPluginMny::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginMny::isImportPossible");
-    if (!m_importer) return true;
+    SKGTRACEINFUNC(10);
+    if (!m_importer) {
+        return true;
+    }
     QString extension = m_importer->getFileNameExtension();
     return (extension == "MNY");
 }
@@ -98,7 +100,7 @@ bool SKGImportPluginMny::isImportPossible()
 SKGError SKGImportPluginMny::readJsonFile(const QString& iFileName, QVariant& oVariant)
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginMny::readJsonFile", err);
+    SKGTRACEINFUNCRC(2, err);
     QJson::Parser parser;
     bool ok = false;
     QFile file(iFileName);
@@ -108,17 +110,27 @@ SKGError SKGImportPluginMny::readJsonFile(const QString& iFileName, QVariant& oV
         QByteArray json = file.readAll();
         file.close();
         oVariant = parser.parse(json, &ok);
-        if (!ok || json.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+        if (!ok || json.isEmpty()) {
+            err.setReturnCode(ERR_FAIL).setMessage(parser.errorString()).addError(ERR_FAIL, i18nc("Error message",  "Error during parsing of '%1'", file.fileName()));
+        }
     }
     return err;
 }
 
 SKGError SKGImportPluginMny::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
 
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginMny::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
+
+    // Check read access file
+    if (!QFileInfo(m_importer->getLocalFileName()).isReadable()) {
+        err.setReturnCode(ERR_READACCESS).setMessage(i18nc("Error message",  "The file %1 does not have read access rights", m_importer->getLocalFileName()));
+        return err;
+    }
 
     // Check install
     if (KStandardDirs::findExe("java").isEmpty()) {
@@ -153,12 +165,10 @@ SKGError SKGImportPluginMny::importFile()
     QDir::temp().mkdir(uniqueId);
     QDir temporaryDir(temporaryPath);
 
-    QString cmd = "java -cp " % sunriise_jar % " com/le/sunriise/export/ExportToJSON " % m_importer->getLocalFileName() % " " % m_parameters["password"] % " " % temporaryPath;
+    QString cmd = "java -cp \"" % sunriise_jar % "\" com/le/sunriise/export/ExportToJSON \"" % m_importer->getLocalFileName() % "\" \"" % m_parameters["password"] % "\" " % temporaryPath;
+    SKGTRACEL(10) << "Execution of :" << cmd << endl;
     QProcess p;
-    {
-        SKGTRACEINRC(10, "SKGImportPluginMny::importFile-SUNRIISE", err);
-        p.start(cmd);
-    }
+    p.start(cmd);
     if (p.waitForFinished(1000 * 60 * 5) && p.exitCode() == 0) {
         // Import
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "MNY"), 6);
@@ -175,7 +185,7 @@ SKGError SKGImportPluginMny::importFile()
             err = readJsonFile(temporaryPath % "/categories.json", var);
             QVariantList list = var.toList();
             IFOK(err) {
-                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-CATEGORY", err);
+                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-categories", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import categories"), nb);
                 // Create categories
@@ -192,7 +202,9 @@ SKGError SKGImportPluginMny::importFile()
                         if (level == t) {
                             SKGCategoryObject catObject(m_importer->getDocument());
                             err = catObject.setName(name);
-                            if (!err && !parentId.isEmpty()) err = catObject.setParentCategory(m_mapIdCategory[parentId]);
+                            if (!err && !parentId.isEmpty()) {
+                                err = catObject.setParentCategory(m_mapIdCategory[parentId]);
+                            }
                             IFOKDO(err, catObject.save())
 
                             m_mapIdCategory[id] = catObject;
@@ -214,7 +226,7 @@ SKGError SKGImportPluginMny::importFile()
             err = readJsonFile(temporaryPath % "/payees.json", var);
             QVariantList list = var.toList();
             IFOK(err) {
-                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-PAYEE", err);
+                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-payees", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import payees"), nb);
                 // Create categories
@@ -245,7 +257,7 @@ SKGError SKGImportPluginMny::importFile()
             err = readJsonFile(temporaryPath % "/securities.json", var);
             QVariantList list = var.toList();
             IFOK(err) {
-                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-UNITS", err);
+                SKGTRACEINRC(10, "SKGImportPluginMny::importFile-securities", err);
                 int nb = list.count();
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), nb);
                 // Create categories
@@ -255,7 +267,9 @@ SKGError SKGImportPluginMny::importFile()
                     QString id = unit["id"].toString();
                     QString name = unit["name"].toString();
                     QString symbol = unit["symbol"].toString();
-                    if (symbol.isEmpty()) symbol = name;
+                    if (symbol.isEmpty()) {
+                        symbol = name;
+                    }
 
                     // Is already created?
                     SKGUnitObject unitobject(m_importer->getDocument());
@@ -298,7 +312,7 @@ SKGError SKGImportPluginMny::importFile()
             }*/
             // List directories
             QStringList list = temporaryDir.entryList(QStringList() << "*.d", QDir::Dirs);
-            SKGTRACEINRC(10, "SKGImportPluginMny::importFile-ACCOUNTS", err);
+            SKGTRACEINFUNCRC(10, err);
             int nb = list.count();
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import accounts"), nb);
 
@@ -351,7 +365,7 @@ SKGError SKGImportPluginMny::importFile()
         IFOK(err) {
             // List directories
             QStringList list = temporaryDir.entryList(QStringList() << "*.d", QDir::Dirs);
-            SKGTRACEINRC(10, "SKGImportPluginMny::importFile-OPERATIONS", err);
+            SKGTRACEINFUNCRC(10, err);
             int nb = list.count();
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb);
 
@@ -399,7 +413,9 @@ SKGError SKGImportPluginMny::importFile()
                             IFOKDO(err, operationObj.setAttribute("t_imported", "T"))
                             IFOKDO(err, operationObj.setImportID("MNY-" % operation["id"].toString()))
                             QString payId = operation["payeeId"].toString();
-                            if (!payId.isEmpty() && !err) err = operationObj.setPayee(m_mapIdPayee[payId]);
+                            if (!payId.isEmpty() && !err) {
+                                err = operationObj.setPayee(m_mapIdPayee[payId]);
+                            }
                             IFOKDO(err, operationObj.setStatus(operation["reconciled"].toBool() ? SKGOperationObject::CHECKED :
                                                                operation["cleared"].toBool() ? SKGOperationObject::POINTED :
                                                                SKGOperationObject::NONE));
@@ -419,7 +435,9 @@ SKGError SKGImportPluginMny::importFile()
                                     SKGSubOperationObject subOperationObj;
                                     IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                     QString catId = transaction["categoryId"].toString();
-                                    if (!catId.isEmpty() && !err) err = subOperationObj.setCategory(m_mapIdCategory[catId]);
+                                    if (!catId.isEmpty() && !err) {
+                                        err = subOperationObj.setCategory(m_mapIdCategory[catId]);
+                                    }
                                     double splitAmount = transaction["amount"].toDouble();
                                     IFOKDO(err, subOperationObj.setQuantity(splitAmount))
                                     IFOKDO(err, subOperationObj.setComment(operation["memo"].toString()))
@@ -443,14 +461,18 @@ SKGError SKGImportPluginMny::importFile()
                                 SKGSubOperationObject subOperationObj;
                                 IFOKDO(err, operationObj.addSubOperation(subOperationObj))
                                 QString catId = operation["categoryId"].toString();
-                                if (!catId.isEmpty() && !err) err = subOperationObj.setCategory(m_mapIdCategory[catId]);
+                                if (!catId.isEmpty() && !err) {
+                                    err = subOperationObj.setCategory(m_mapIdCategory[catId]);
+                                }
                                 IFOKDO(err, subOperationObj.setQuantity(amount))
                                 IFOKDO(err, subOperationObj.setComment(operation["memo"].toString()))
                                 IFOKDO(err, subOperationObj.save(false, false))
                             }
                         }
 
-                        if (!err && index % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        if (!err && index % 500 == 0) {
+                            err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        }
                         ++index;
 
                         IFOKDO(err, m_importer->getDocument()->stepForward(j + 1))
@@ -477,8 +499,9 @@ SKGError SKGImportPluginMny::importFile()
 
         SKGENDTRANSACTION(m_importer->getDocument(),  err);
     } else {
-        if (p.exitCode() == 1) err.setReturnCode(ERR_ENCRYPTION).setMessage(i18nc("Error message",  "Invalid password"));
-        else {
+        if (p.exitCode() == 1) {
+            err.setReturnCode(ERR_ENCRYPTION).setMessage(i18nc("Error message",  "Invalid password"));
+        } else {
             err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The execution of '%1' failed", cmd)).addError(ERR_FAIL, i18nc("Error message",  "The extraction from the Microsoft Money document '%1' failed", m_importer->getFileName().prettyUrl()));
         }
     }
