@@ -51,7 +51,7 @@ K_EXPORT_PLUGIN(SKGImportPluginQifFactory("skrooge_import_qif", "skrooge_import_
 SKGImportPluginQif::SKGImportPluginQif(QObject* iImporter , const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginQif::SKGImportPluginQif");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 
     m_parameters["date_format"] = "";
@@ -63,16 +63,18 @@ SKGImportPluginQif::~SKGImportPluginQif()
 
 bool SKGImportPluginQif::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginQif::isImportPossible");
+    SKGTRACEINFUNC(10);
     return isExportPossible();
 }
 
 SKGError SKGImportPluginQif::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
 
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginQif::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Info for QIF format:
     // http://mb-net.net/Debian/src/gnucash/gnucash-2.2.6/src/import-export/qif-import/file-format.txt
@@ -90,10 +92,13 @@ SKGError SKGImportPluginQif::importFile()
 
         // Open file
         QFile file(m_importer->getLocalFileName());
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-        else {
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+        } else {
             QTextStream stream(&file);
-            if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+            if (!m_importer->getCodec().isEmpty()) {
+                stream.setCodec(m_importer->getCodec().toAscii().constData());
+            }
 
             // load file in memory
             QStringList lines;
@@ -137,8 +142,12 @@ SKGError SKGImportPluginQif::importFile()
 
             // Select dateformat
             QString dateFormat = m_parameters["date_format"];
-            if (dateFormat.isEmpty()) dateFormat = SKGServices::getDateFormat(dates);  // Automatic detection
-            if (dateFormat.isEmpty()) err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+            if (dateFormat.isEmpty()) {
+                dateFormat = SKGServices::getDateFormat(dates);    // Automatic detection
+            }
+            if (dateFormat.isEmpty()) {
+                err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "Date format not supported"));
+            }
             IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Import of '%1' with code '%2' and date format '%3'", m_importer->getFileName().prettyUrl(), m_importer->getCodec(), dateFormat)))
 
             // Step 2 done
@@ -173,7 +182,9 @@ SKGError SKGImportPluginQif::importFile()
                     QString line = lines.at(i);
                     QString val;
                     QChar op = line[0];
-                    if (line.length() > 1) val = line.right(line.length() - 1).trimmed();
+                    if (line.length() > 1) {
+                        val = line.right(line.length() - 1).trimmed();
+                    }
 
                     // Manage !Account section
                     if (QString::compare(line, "!type:bank", Qt::CaseInsensitive) == 0 ||
@@ -244,10 +255,14 @@ SKGError SKGImportPluginQif::importFile()
                                 // Create account
                                 SKGBankObject bank(m_importer->getDocument());
                                 err = bank.setName(i18nc("Noun",  "Bank for import %1", postFix));
-                                if (!err && bank.load().isFailed()) err = bank.save(false);
+                                if (!err && bank.load().isFailed()) {
+                                    err = bank.save(false);
+                                }
                                 IFOKDO(err, bank.addAccount(account2))
                                 IFOKDO(err, account2.setName(val))
-                                if (!err && account2.load().isFailed()) err = account2.save(false);     // Save only
+                                if (!err && account2.load().isFailed()) {
+                                    err = account2.save(false);    // Save only
+                                }
                             }
 
                             IFOK(err) {
@@ -255,13 +270,19 @@ SKGError SKGImportPluginQif::importFile()
                                 account = new SKGAccountObject(account2);
                             }
                         } else if (op == 'D') {
-                            if (account) err = account->setNumber(val);
+                            if (account) {
+                                err = account->setNumber(val);
+                            }
                         } else if (op == 'T') {
-                            if (account) err = account->setType(val == "Bank" ? SKGAccountObject::CURRENT : (val == "CCard" ? SKGAccountObject::CREDITCARD : (val == "Invst" ? SKGAccountObject::INVESTMENT : (val == "Oth A" ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER))));
+                            if (account) {
+                                err = account->setType(val == "Bank" ? SKGAccountObject::CURRENT : (val == "CCard" ? SKGAccountObject::CREDITCARD : (val == "Invst" ? SKGAccountObject::INVESTMENT : (val == "Oth A" ? SKGAccountObject::ASSETS : SKGAccountObject::OTHER))));
+                            }
                         } else if (op == '^') {
                             // ^     End of entry
                             // save
-                            if (account) err = account->save();
+                            if (account) {
+                                err = account->save();
+                            }
                         }
                     } else if (inSection == 'B') {
                         // Operation creation
@@ -340,7 +361,9 @@ SKGError SKGImportPluginQif::importFile()
                             IFOK(err) {
                                 // Create unit if needed
                                 // If an initial balance is existing for the account then we use the unit else we look for the most appropriate unit
-                                if (!unit.exist()) err = m_importer->getDefaultUnit(unit, &currentOperationDate);
+                                if (!unit.exist()) {
+                                    err = m_importer->getDefaultUnit(unit, &currentOperationDate);
+                                }
                                 IFOKDO(err, currentOperation.setUnit(unit))
                             }
 
@@ -363,7 +386,9 @@ SKGError SKGImportPluginQif::importFile()
                                 IFOKDO(err, currentOperation.setUnit(unit))
                             } else {
                                 // For dividend, if comment is empty, we set the security in comment
-                                if (currentOperation.getComment().isEmpty()) err = currentOperation.setComment(val);
+                                if (currentOperation.getComment().isEmpty()) {
+                                    err = currentOperation.setComment(val);
+                                }
                             }
                         } else if (op == 'O') {
                             // O     Commission
@@ -380,8 +405,9 @@ SKGError SKGImportPluginQif::importFile()
                             SKGSubOperationObject subcommission;
                             if (!payement.exist()) {
                                 // We have to create a new operation
-                                if (account != NULL) err = account->addOperation(payement, true);
-                                else {
+                                if (account != NULL) {
+                                    err = account->addOperation(payement, true);
+                                } else {
                                     SKGAccountObject defAccount;
                                     err = m_importer->getDefaultAccount(defAccount);
                                     IFOKDO(err, defAccount.addOperation(payement, true))
@@ -394,7 +420,9 @@ SKGError SKGImportPluginQif::importFile()
                                         double initBalance;
                                         account->getInitialBalance(initBalance, unit);
                                     }
-                                    if (!unit.exist()) err = m_importer->getDefaultUnit(unit, &currentOperationDate);
+                                    if (!unit.exist()) {
+                                        err = m_importer->getDefaultUnit(unit, &currentOperationDate);
+                                    }
                                     IFOKDO(err, payement.setUnit(unit))
                                 }
                                 IFOKDO(err, payement.save())
@@ -405,8 +433,9 @@ SKGError SKGImportPluginQif::importFile()
                         } else if (op == 'I') {
                             // I     Price
                             currentUnitPrice = SKGServices::stringToDouble(val);
-                            if (currentUnitPrice && !currentUnitForInvestment.isEmpty())
+                            if (currentUnitPrice && !currentUnitForInvestment.isEmpty()) {
                                 err = m_importer->getDocument()->addOrModifyUnitValue(currentUnitForInvestment, currentOperationDate, currentUnitPrice);
+                            }
                         } else if (op == 'N') {
                             if (investmentAccount) {
                                 // N     Action
@@ -505,8 +534,9 @@ SKGError SKGImportPluginQif::importFile()
                                 double previousQuantity = currentSubOperation.getQuantity();
                                 if (previousQuantity) {
                                     // We have to create a new operation
-                                    if (account != NULL) err = account->addOperation(payement, true);
-                                    else {
+                                    if (account != NULL) {
+                                        err = account->addOperation(payement, true);
+                                    } else {
                                         SKGAccountObject defAccount;
                                         err = m_importer->getDefaultAccount(defAccount);
                                         IFOKDO(err, defAccount.addOperation(payement, true))
@@ -520,7 +550,9 @@ SKGError SKGImportPluginQif::importFile()
                                             double initBalance;
                                             account->getInitialBalance(initBalance, unit);
                                         }
-                                        if (!unit.exist()) err = m_importer->getDefaultUnit(unit, &currentOperationDate);
+                                        if (!unit.exist()) {
+                                            err = m_importer->getDefaultUnit(unit, &currentOperationDate);
+                                        }
                                         IFOKDO(err, payement.setUnit(unit))
                                     }
                                     IFOKDO(err, payement.save())
@@ -569,7 +601,9 @@ SKGError SKGImportPluginQif::importFile()
                         } else if (op == 'A') {
                             // A      Address (up to 5 lines; 6th line is an optional message)
                             QString add = currentPayee.getAddress();
-                            if (!add.isEmpty()) add += ' ';
+                            if (!add.isEmpty()) {
+                                add += ' ';
+                            }
                             add += val;
                             err = currentPayee.setAddress(add);
                             IFOKDO(err, currentPayee.save())
@@ -590,7 +624,9 @@ SKGError SKGImportPluginQif::importFile()
                             if (!val.isEmpty()) {
                                 // Correction bug 216520 vvvv
                                 // If the operation is splitter, it is not a transfer
-                                if (op == 'S') transferAccount = "";
+                                if (op == 'S') {
+                                    transferAccount = "";
+                                }
                                 // Correction bug 216520 vvvv
 
                                 if (val[0] == '[') {
@@ -617,7 +653,9 @@ SKGError SKGImportPluginQif::importFile()
 
                                                     // We delete the previous account if empty
                                                     IFOK(err) {
-                                                        if (account->getNbOperation() == 0) err = account->remove();
+                                                        if (account->getNbOperation() == 0) {
+                                                            err = account->remove();
+                                                        }
                                                         delete account;
                                                         account = new SKGAccountObject(newAccount);
                                                     }
@@ -630,7 +668,9 @@ SKGError SKGImportPluginQif::importFile()
 //                                            if ( op=='L' && currentOperation.getPayee().compare ( "Opening Balance", Qt::CaseInsensitive ) !=0 && !investmentAccount)
                                         if (op == 'L' && !opening) {
                                             transferAccount = val.mid(1, pos - 1);
-                                            if (transferAccount == account->getName()) transferAccount = "";
+                                            if (transferAccount == account->getName()) {
+                                                transferAccount = "";
+                                            }
                                         }
                                         val = val.mid(pos + 2);
                                     }
@@ -662,12 +702,15 @@ SKGError SKGImportPluginQif::importFile()
                                     // Specific values for initial balance
                                     err = currentOperation.setStatus(SKGOperationObject::CHECKED);
                                     IFOKDO(err, currentOperation.setAttribute("d_date", "0000-00-00"))
+                                    IFOKDO(err, currentSubOperation.setAttribute("d_date", "0000-00-00"))
                                     openingbalancecreated = true;
                                 }
 
                                 IFOKDO(err, currentOperation.setImportID(hash.toHex()))
                                 IFOKDO(err, currentOperation.save())
-                                if (!latestSubCatMustBeRemoved && !err) err = currentSubOperation.save();
+                                if (!latestSubCatMustBeRemoved && !err) {
+                                    err = currentSubOperation.save();
+                                }
 
                                 // Create transfer is needed
                                 if (!err && !transferAccount.isEmpty()) {
@@ -767,7 +810,9 @@ SKGError SKGImportPluginQif::importFile()
                         }
                     }
 
-                    if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    if (!err && i % 500 == 0) {
+                        err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                    }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
@@ -785,26 +830,29 @@ SKGError SKGImportPluginQif::importFile()
     return err;
 }
 
-
-
 bool SKGImportPluginQif::isExportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginQif::isExportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "QIF");
 }
 
 SKGError SKGImportPluginQif::exportFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportQif::exportFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Open file
     KSaveFile file(m_importer->getLocalFileName(false));
-    if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
-    else {
+    if (!file.open()) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
+    } else {
         QTextStream stream(&file);
-        if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
+        if (!m_importer->getCodec().isEmpty()) {
+            stream.setCodec(m_importer->getCodec().toAscii().constData());
+        }
 
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "QIF"), 3);
         IFOK(err) {
@@ -867,11 +915,15 @@ SKGError SKGImportPluginQif::exportFile()
                         QString bnumber = account.getAgencyNumber();
                         QString cnumber = account.getNumber();
                         if (!bnumber.isEmpty()) {
-                            if (!number.isEmpty()) number += '-';
+                            if (!number.isEmpty()) {
+                                number += '-';
+                            }
                             number += bnumber;
                         }
                         if (!cnumber.isEmpty()) {
-                            if (!number.isEmpty()) number += '-';
+                            if (!number.isEmpty()) {
+                                number += '-';
+                            }
                             number += cnumber;
                         }
                         stream << 'D' << number << endl;
@@ -911,7 +963,9 @@ SKGError SKGImportPluginQif::exportFile()
                     operation.getUnit(unit);
                     bool investment = false;
                     bool unitExported = false;
-                    if (unit.getSymbol() != primaryUnit.Symbol && !primaryUnit.Symbol.isEmpty()) unitExported = true;
+                    if (unit.getSymbol() != primaryUnit.Symbol && !primaryUnit.Symbol.isEmpty()) {
+                        unitExported = true;
+                    }
                     if (unit.getType() == SKGUnitObject::SHARE) {
                         unitExported = true;
                         investment = true;
@@ -929,7 +983,9 @@ SKGError SKGImportPluginQif::exportFile()
 
                     if (!investment) {
                         int number = operation.getNumber();
-                        if (number) stream << 'N' << operation.getNumber() << endl;
+                        if (number) {
+                            stream << 'N' << operation.getNumber() << endl;
+                        }
                     } else {
                         stream << 'N' << (operation.getCurrentAmount() > 0 ? "Buy" : "Sell") << endl;
                     }
@@ -942,13 +998,21 @@ SKGError SKGImportPluginQif::exportFile()
                     operation.getPayee(payeeObj);
                     QString payee = payeeObj.getName();
                     QString address = payeeObj.getAddress();
-                    if (date == "0000-00-00") payee = OPENINGBALANCE;
-                    if (!payee.isEmpty()) stream << 'P' << payee << endl;
-                    if (!address.isEmpty()) stream << 'A' << address << endl;
+                    if (date == "0000-00-00") {
+                        payee = OPENINGBALANCE;
+                    }
+                    if (!payee.isEmpty()) {
+                        stream << 'P' << payee << endl;
+                    }
+                    if (!address.isEmpty()) {
+                        stream << 'A' << address << endl;
+                    }
 
                     QString memo = operation.getMode() % "  " % operation.getComment();
                     memo = memo.trimmed();
-                    if (!memo.isEmpty()) stream << 'M' << memo << endl;
+                    if (!memo.isEmpty()) {
+                        stream << 'M' << memo << endl;
+                    }
 
                     SKGOperationObject::OperationStatus status = operation.getStatus();
                     stream << 'C' << (status == SKGOperationObject::POINTED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << endl;
@@ -976,13 +1040,17 @@ SKGError SKGImportPluginQif::exportFile()
                         // Is it a transfer
                         SKGOperationObject transfer;
                         if (operation.isTransfer(transfer)) {
-                            if (!category.isEmpty()) category.prepend('/');
+                            if (!category.isEmpty()) {
+                                category.prepend('/');
+                            }
 
                             SKGAccountObject transferAccount;
                             err = transfer.getParentAccount(transferAccount);
                             IFOK(err) category.prepend('[' % transferAccount.getName() % ']');
                         }
-                        if (!category.isEmpty()) stream << 'L' << category << endl;
+                        if (!category.isEmpty()) {
+                            stream << 'L' << category << endl;
+                        }
 
                         if (nbSubOps > 1) {
                             // Split operation
@@ -992,10 +1060,14 @@ SKGError SKGImportPluginQif::exportFile()
                                 suboperation.getCategory(cat);
 
                                 QString category2 = cat.getFullName().replace(OBJECTSEPARATOR, ":");
-                                if (!category2.isEmpty()) stream << 'S' << category2 << endl;
+                                if (!category2.isEmpty()) {
+                                    stream << 'S' << category2 << endl;
+                                }
                                 QString memo2 = suboperation.getComment();
                                 memo2 = memo2.trimmed();
-                                if (!memo2.isEmpty()) stream << 'E' << memo2 << endl;
+                                if (!memo2.isEmpty()) {
+                                    stream << 'E' << memo2 << endl;
+                                }
                                 stream << '$' << SKGServices::doubleToString(suboperation.getQuantity()) << endl;
                             }
                         }
@@ -1023,7 +1095,9 @@ SKGError SKGImportPluginQif::exportFile()
                     IFOK(err) {
                         QStringList vals;
                         QString v = unit.getSymbol();
-                        if (v.isEmpty()) v = unit.getName();
+                        if (v.isEmpty()) {
+                            v = unit.getName();
+                        }
                         vals.push_back(v);
                         vals.push_back(SKGServices::doubleToString(unitVal.getQuantity()));
                         vals.push_back(SKGServices::dateToSqlString(QDateTime(unitVal.getDate())));
