@@ -47,7 +47,7 @@ K_EXPORT_PLUGIN(SKGImportPluginXhbFactory("skrooge_import_xhb", "skrooge_import_
 SKGImportPluginXhb::SKGImportPluginXhb(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
 {
-    SKGTRACEIN(10, "SKGImportPluginXhb::SKGImportPluginXhb");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArg);
 }
 
@@ -57,21 +57,24 @@ SKGImportPluginXhb::~SKGImportPluginXhb()
 
 bool SKGImportPluginXhb::isImportPossible()
 {
-    SKGTRACEIN(10, "SKGImportPluginXhb::isImportPossible");
+    SKGTRACEINFUNC(10);
     return (!m_importer ? true : m_importer->getFileNameExtension() == "XHB");
 }
 
 SKGError SKGImportPluginXhb::importFile()
 {
-    if (!m_importer) return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    if (!m_importer) {
+        return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
+    }
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportPluginXhb::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Initialisation
     // Open file
     QIODevice* file = KFilterDev::deviceForFile(m_importer->getLocalFileName(), "application/x-gzip");
-    if (!file->open(QIODevice::ReadOnly)) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
-    else {
+    if (!file->open(QIODevice::ReadOnly)) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", m_importer->getFileName().prettyUrl()));
+    } else {
         QDomDocument doc;
 
         // Set the file without uncompression
@@ -84,9 +87,12 @@ SKGError SKGImportPluginXhb::importFile()
         // Get root
         QDomElement docElem = doc.documentElement();
 
-        if (!contentOK) err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
-        if (!contentOK) err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
-        else {
+        if (!contentOK) {
+            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg));
+        }
+        if (!contentOK) {
+            err.addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", m_importer->getFileName().prettyUrl()));
+        } else {
             err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "XHB"), 4);
 
             QMap<QString, SKGAccountObject> mapIdAccount;
@@ -108,7 +114,9 @@ SKGError SKGImportPluginXhb::importFile()
                     // Create the bank
                     SKGBankObject bank(m_importer->getDocument());
                     QString bname = getAttribute(account,  "bankname");
-                    if (bname.isEmpty()) bname = "HOMEBANK";
+                    if (bname.isEmpty()) {
+                        bname = "HOMEBANK";
+                    }
                     IFOKDO(err, bank.setName(bname))
                     IFOKDO(err, bank.save())
 
@@ -126,6 +134,22 @@ SKGError SKGImportPluginXhb::importFile()
                         err = accountObj.setClosed(flags == "2" ||  flags == "3");
                     }
                     IFOKDO(err, accountObj.save())
+                    
+                    // Change parent bank in case of ASSETS
+                    if(accountObj.getType() == SKGAccountObject::WALLET) {
+                        // Get blank bank
+                        SKGBankObject blankBank(m_importer->getDocument());
+                        IFOKDO(err, blankBank.setName(""))
+                        if (blankBank.exist()) {
+                            err = blankBank.load();
+                        } else {
+                            err = blankBank.save();
+                        }                                            
+                        IFOKDO(err, accountObj.setBank(blankBank))
+                        IFOKDO(err, accountObj.save())                                      
+                    }   
+                    
+                    // Set initial balance
                     IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "initial")), unit))
 
                     mapIdAccount[getAttribute(account,  "key")] = accountObj;
@@ -170,6 +194,9 @@ SKGError SKGImportPluginXhb::importFile()
                         bool catCreated = false;
                         SKGCategoryObject catObj(m_importer->getDocument());
                         QString parent2 = getAttribute(category,  "parent");
+                        if(parent2.isEmpty()) {
+                            parent2 = "0";
+                        }
                         if (parent2 == "0" && j == 0) {
                             IFOKDO(err, catObj.setName(getAttribute(category,  "name")))
                             IFOKDO(err, catObj.save())
@@ -231,8 +258,9 @@ SKGError SKGImportPluginXhb::importFile()
                             SKGAccountObject account = mapIdAccount[idAccount];
                             QDate date = QDate(1, 1, 1).addDays(1 + SKGServices::stringToInt(getAttribute(transaction,  j == 1 ? "date" : "nextdate")));
                             QString mode = getAttribute(transaction,  "paymode");
-                            if (mode == "1") mode = i18nc("Noun: type of payement", "Credit card");
-                            else if (mode == "2") {
+                            if (mode == "1") {
+                                mode = i18nc("Noun: type of payement", "Credit card");
+                            } else if (mode == "2") {
                                 mode = i18nc("Noun: type of payement", "Check");
                             } else if (mode == "3") {
                                 mode = i18nc("Noun: type of payement", "Cash");
@@ -309,8 +337,9 @@ SKGError SKGImportPluginXhb::importFile()
                                 int punit = SKGServices::stringToInt(getAttribute(transaction,  "unit"));
                                 int pstep = SKGServices::stringToInt(getAttribute(transaction,  "every"));
                                 SKGRecurrentOperationObject::PeriodUnit p = SKGRecurrentOperationObject::MONTH;
-                                if (punit == 0) p = SKGRecurrentOperationObject::DAY;
-                                else if (punit == 1) {
+                                if (punit == 0) {
+                                    p = SKGRecurrentOperationObject::DAY;
+                                } else if (punit == 1) {
                                     p = SKGRecurrentOperationObject::WEEK;
                                 } else if (punit == 3) {
                                     p = SKGRecurrentOperationObject::YEAR;
@@ -331,7 +360,9 @@ SKGError SKGImportPluginXhb::importFile()
                             }
                         }
 
-                        if (!err && i % 500 == 0) err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        if (!err && i % 500 == 0) {
+                            err = m_importer->getDocument()->executeSqliteOrder("ANALYZE");
+                        }
                         IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                     }
 
@@ -357,7 +388,9 @@ SKGError SKGImportPluginXhb::importFile()
 QString SKGImportPluginXhb::getAttribute(const QDomElement& iElement, const QString& iAttribute)
 {
     QString val = iElement.attribute(iAttribute);
-    if (val == "(null)") val = "";
+    if (val == "(null)") {
+        val = "";
+    }
     return val;
 }
 
