@@ -45,8 +45,10 @@
 SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::SKGBankPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(10);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -173,7 +175,9 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
     // Search file list
     QString listIconFile = KStandardDirs::locate("data", "skrooge/images/logo/l10n/" % KGlobal::locale()->country() % "/list_bank.txt");
-    if (listIconFile.isEmpty()) listIconFile = KStandardDirs::locate("data", "skrooge/images/logo/list_bank.txt");
+    if (listIconFile.isEmpty()) {
+        listIconFile = KStandardDirs::locate("data", "skrooge/images/logo/list_bank.txt");
+    }
 
     // Logo for banks
     ui.kAccountCreatorIcon->addItem("");
@@ -216,7 +220,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
 
 SKGBankPluginWidget::~SKGBankPluginWidget()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::~SKGBankPluginWidget");
+    SKGTRACEINFUNC(10);
 }
 
 bool SKGBankPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -237,7 +241,7 @@ bool SKGBankPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGBankPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
     // Mapping
     int nbSelect = ui.kView->getView()->getNbSelectedObjects();
     if (nbSelect == 1) {
@@ -255,8 +259,9 @@ void SKGBankPluginWidget::onSelectionChanged()
             if (rx.indexIn(iconName) != -1) {
                 iconName = rx.cap(1);
             }
-            if (ui.kAccountCreatorIcon->contains(iconName)) ui.kAccountCreatorIcon->setText(iconName);
-            else if (ui.kAccountCreatorIcon->contains(fileName)) {
+            if (ui.kAccountCreatorIcon->contains(iconName)) {
+                ui.kAccountCreatorIcon->setText(iconName);
+            } else if (ui.kAccountCreatorIcon->contains(fileName)) {
                 ui.kAccountCreatorIcon->setText(fileName);
             } else {
                 int c = ui.kAccountCreatorIcon->count() - 1;
@@ -289,7 +294,9 @@ void SKGBankPluginWidget::onSelectionChanged()
         account.getInitialBalance(oBalance, oUnit);
 
         int nbDec = oUnit.getNumberDecimal();
-        if (nbDec == 0) nbDec = 2;
+        if (nbDec == 0) {
+            nbDec = 2;
+        }
 
         ui.kAmountEdit->setText(KGlobal::locale()->formatMoney(oBalance, "", nbDec));
         if (oUnit.exist()) {
@@ -330,7 +337,7 @@ void SKGBankPluginWidget::onSelectionChanged()
 
 void SKGBankPluginWidget::onRefreshGraph()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::onRefreshGraph");
+    SKGTRACEINFUNC(10);
     if (m_graph) {
         bool visible = ui.kView->getShowWidget()->getState().contains("graph");
 
@@ -381,14 +388,15 @@ void SKGBankPluginWidget::onRefreshGraph()
 
 void SKGBankPluginWidget::onIconChanged()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::onIconChanged");
+    SKGTRACEINFUNC(10);
 
     int c = ui.kAccountCreatorIcon->currentIndex();
     if (c && c == ui.kAccountCreatorIcon->count() - 1) {
         QString fileName = KFileDialog::getOpenFileName(KUrl(KStandardDirs::locate("data", "skrooge/images/logo/")), "image/png image/jpeg image/gif image/tiff" , this);
         if (!fileName.isEmpty()) {
-            if (ui.kAccountCreatorIcon->contains(fileName)) ui.kAccountCreatorIcon->setText(fileName);
-            else {
+            if (ui.kAccountCreatorIcon->contains(fileName)) {
+                ui.kAccountCreatorIcon->setText(fileName);
+            } else {
                 bool b = ui.kAccountCreatorIcon->blockSignals(true);
                 ui.kAccountCreatorIcon->insertItem(c, QIcon(fileName), fileName);
                 ui.kAccountCreatorIcon->setCurrentIndex(c);
@@ -415,7 +423,7 @@ void SKGBankPluginWidget::onIconChanged()
 
 void SKGBankPluginWidget::onAccountCreatorModified()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::onAccountCreatorModified");
+    SKGTRACEINFUNC(10);
 
     bool activatedForWallet = ui.kWidgetSelector->getSelectedMode() != -1 &&
                               ui.kAccountCreatorAccount->text().length() > 0 &&
@@ -451,7 +459,7 @@ SKGError SKGBankPluginWidget::setInitialBalanceFromEditor(SKGAccountObject& iAcc
 void SKGBankPluginWidget::onAddAccountClicked()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGBankPluginWidget::onAddAccountClicked", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         SKGAccountObject accountObj;
 
@@ -459,7 +467,9 @@ void SKGBankPluginWidget::onAddAccountClicked()
         QString accountName = ui.kAccountCreatorAccount->text();
         QString name = bankName % '-' % accountName;
         SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
-        if (accountType == SKGAccountObject::WALLET) bankName = "";
+        if (accountType == SKGAccountObject::WALLET) {
+            bankName = "";
+        }
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Creating an account", "Account creation '%1'", name), err);
 
@@ -471,7 +481,9 @@ void SKGBankPluginWidget::onAddAccountClicked()
                 QString icon = ui.kAccountCreatorIcon->currentText();
                 if (!QFile(icon).exists() && !icon.isEmpty()) {
                     QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
-                    if (!code.isEmpty()) icon += "  " % code;
+                    if (!code.isEmpty()) {
+                        icon += "  " % code;
+                    }
 
                     icon.replace(' ', '_');
                     icon += ".png";
@@ -519,7 +531,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
 void SKGBankPluginWidget::onModifyAccountClicked()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGBankPluginWidget::onModifyAccountClicked", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
@@ -546,23 +558,35 @@ void SKGBankPluginWidget::onModifyAccountClicked()
 
         QString bankName = ui.kAccountCreatorBank->text();
         SKGAccountObject::AccountType accountType = static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt());
-        if (accountType == SKGAccountObject::WALLET) bankName = "";
+        if (accountType == SKGAccountObject::WALLET) {
+            bankName = "";
+        }
 
         for (int i = 0; !err && i < nb; ++i) {
             SKGAccountObject accountObj(selection[i]);
             err = accountObj.setName(ui.kAccountCreatorAccount->text());
             IFOKDO(err, accountObj.setNumber(ui.kAccountCreatorNumber->text()))
             IFOKDO(err, setInitialBalanceFromEditor(accountObj))
-            if (!err && ui.kAccountCreatorType->text() != NOUPDATE) err = accountObj.setType(static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()));
+            if (!err && ui.kAccountCreatorType->text() != NOUPDATE) {
+                err = accountObj.setType(static_cast<SKGAccountObject::AccountType>(ui.kAccountCreatorType->itemData(ui.kAccountCreatorType->currentIndex()).toInt()));
+            }
             IFOKDO(err, accountObj.setAgencyNumber(ui.kAccountCreatorAgencyNumber->text()))
             IFOKDO(err, accountObj.setAgencyAddress(ui.kAccountCreatorAddress->text()))
             IFOKDO(err, accountObj.setComment(ui.kAccountCreatorComment->text()))
 
-            if (!err && ui.kMaxLimit->checkState() != Qt::PartiallyChecked) err = accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked());
-            if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) err = accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value());
+            if (!err && ui.kMaxLimit->checkState() != Qt::PartiallyChecked) {
+                err = accountObj.maxLimitAmountEnabled(ui.kMaxLimit->isChecked());
+            }
+            if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) {
+                err = accountObj.setMaxLimitAmount(ui.kMaxLimitAmout->value());
+            }
 
-            if (!err && ui.kMinLimit->checkState() != Qt::PartiallyChecked) err = accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked());
-            if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) err = accountObj.setMinLimitAmount(ui.kMinLimitAmout->value());
+            if (!err && ui.kMinLimit->checkState() != Qt::PartiallyChecked) {
+                err = accountObj.minLimitAmountEnabled(ui.kMinLimit->isChecked());
+            }
+            if (!err && ui.kMaxLimitAmout->text() != NOUPDATE) {
+                err = accountObj.setMinLimitAmount(ui.kMinLimitAmout->value());
+            }
 
             IFOKDO(err, accountObj.save())
 
@@ -610,7 +634,9 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                     QString icon = ui.kAccountCreatorIcon->currentText();
                     if (!QFile(icon).exists() && !icon.isEmpty()) {
                         QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
-                        if (!code.isEmpty()) icon += "  " % code;
+                        if (!code.isEmpty()) {
+                            icon += "  " % code;
+                        }
                         icon.replace(' ', '_');
                         icon += ".png";
                     }
@@ -678,7 +704,7 @@ void SKGBankPluginWidget::cleanEditor()
 
 QString SKGBankPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -690,14 +716,16 @@ QString SKGBankPluginWidget::getState()
 
 void SKGBankPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::setState");
+    SKGTRACEINFUNC(10);
 
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     QString currentPage = root.attribute("currentPage");
-    if (currentPage.isEmpty()) currentPage = '0';
+    if (currentPage.isEmpty()) {
+        currentPage = '0';
+    }
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
 
     ui.kView->setState(root.attribute("view"));
@@ -711,7 +739,7 @@ QString SKGBankPluginWidget::getDefaultStateAttribute()
 
 void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     // Refresh widgets
@@ -740,7 +768,7 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
 
 void SKGBankPluginWidget::refreshInfoZone()
 {
-    SKGTRACEIN(10, "SKGBankPluginWidget::refreshInfoZone");
+    SKGTRACEINFUNC(10);
 
     // Refresh info area
     SKGStringListList listTmp;
@@ -789,7 +817,9 @@ QList< QWidget* > SKGBankPluginWidget::printableWidgets()
 
 void SKGBankPluginWidget::activateEditor()
 {
-    if (ui.kWidgetSelector->getSelectedMode() == -1) ui.kWidgetSelector->setSelectedMode(0);
+    if (ui.kWidgetSelector->getSelectedMode() == -1) {
+        ui.kWidgetSelector->setSelectedMode(0);
+    }
     ui.kAccountCreatorBank->setFocus();
 }
 
