@@ -37,8 +37,10 @@
 SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGBudgetPluginWidget::SKGBudgetPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -69,8 +71,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
                                        "",
                                        "current;currentYear;currentMonth;previousYear;previousMonth",
                                        "none", "", "",
-                                       Qt::META + Qt::Key_A
-                                      );
+                                       Qt::META + Qt::Key_A);
     ui.kView->getShowWidget()->addItem("none", i18nc("Noun, budget items to display", "None"), "",
                                        "1=0",
                                        "",  // Check when checked
@@ -193,7 +194,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
 
 SKGBudgetPluginWidget::~SKGBudgetPluginWidget()
 {
-    SKGTRACEIN(1, "SKGBudgetPluginWidget::~SKGBudgetPluginWidget");
+    SKGTRACEINFUNC(1);
     m_objectModel = NULL;
 }
 
@@ -215,7 +216,7 @@ bool SKGBudgetPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 QString SKGBudgetPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGBudgetPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -234,13 +235,15 @@ QString SKGBudgetPluginWidget::getState()
 
 void SKGBudgetPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGBudgetPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     QString currentPage = root.attribute("currentPage");
-    if (currentPage.isEmpty()) currentPage = '0';
+    if (currentPage.isEmpty()) {
+        currentPage = '0';
+    }
 
     ui.kWidgetSelector->setSelectedMode(SKGServices::stringToInt(currentPage));
 
@@ -265,7 +268,7 @@ QWidget* SKGBudgetPluginWidget::mainWidget()
 
 void SKGBudgetPluginWidget::refresh()
 {
-    SKGTRACEIN(1, "SKGBudgetPluginWidget::refresh");
+    SKGTRACEINFUNC(1);
 
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
@@ -276,7 +279,7 @@ void SKGBudgetPluginWidget::refresh()
 
 void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
-    SKGTRACEIN(10, "SKGBudgetPluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     // Refresh widgets
@@ -297,8 +300,10 @@ void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
 void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
 {
-    SKGTRACEIN(10, "SKGBudgetPluginWidget::onBtnModeClicked");
-    if (!m_objectModel) return;
+    SKGTRACEINFUNC(10);
+    if (!m_objectModel) {
+        return;
+    }
 
     if (mode == 2 && m_objectModel->getTable() != "v_budgetrule_display") {
         ui.kView->getShowWidget()->setEnabled(false);
@@ -319,7 +324,7 @@ void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
 void SKGBudgetPluginWidget::onAddClicked()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGBudgetPluginWidget::onAddClicked", err);
+    _SKGTRACEINFUNCRC(10, err);
 
     if (ui.kWidgetSelector->getSelectedMode() == 2) {
         // Creation of a rule
@@ -393,7 +398,7 @@ void SKGBudgetPluginWidget::onAddClicked()
 void SKGBudgetPluginWidget::onUpdateClicked()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGBudgetPluginWidget::onUpdateClicked", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
     if (ui.kWidgetSelector->getSelectedMode() == 2) {
@@ -442,8 +447,12 @@ void SKGBudgetPluginWidget::onUpdateClicked()
 SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMonth)
 {
     SKGError err;
-    if (!err && ui.kYear->isEnabled()) err = iBudget.setYear(ui.kYear->value());
-    if (!err && ui.kMonth->isEnabled()) err = iBudget.setMonth(iMonth != -1 ? iMonth : ui.kMonth->value());
+    if (!err && ui.kYear->isEnabled()) {
+        err = iBudget.setYear(ui.kYear->value());
+    }
+    if (!err && ui.kMonth->isEnabled()) {
+        err = iBudget.setMonth(iMonth != -1 ? iMonth : ui.kMonth->value());
+    }
 
     SKGCategoryObject cat;
     QString catName = ui.kCategoryEdit->text().trimmed();
@@ -458,7 +467,9 @@ SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMont
         SKGObjectBase cat2(cat.getDocument(), "v_category_display", cat.getID());
 
         // Are we able to find to sign with the category ?
-        if (cat2.getAttribute("t_TYPEEXPENSE") == "-") val = -val;
+        if (cat2.getAttribute("t_TYPEEXPENSE") == "-") {
+            val = -val;
+        }
     }
     IFOKDO(err, iBudget.setBudgetedAmount(val))
 
@@ -484,7 +495,9 @@ SKGError SKGBudgetPluginWidget::updateBudgetRule(SKGBudgetRuleObject& iRule)
     IFOK(err) {
         bool absolute = (ui.kUnitCmb->currentIndex() == 1);
         double val = ui.kAmountEdit2->value();
-        if (!absolute) val = qMin(qMax(static_cast<double>(0), val), static_cast<double>(100));
+        if (!absolute) {
+            val = qMin(qMax(static_cast<double>(0), val), static_cast<double>(100));
+        }
         err = iRule.setQuantity(val, absolute);
     }
     IFOKDO(err, iRule.setCondition(static_cast<SKGBudgetRuleObject::Condition>(ui.kConditionCmb->itemData(ui.kConditionCmb->currentIndex()).toInt())))
@@ -508,8 +521,10 @@ void SKGBudgetPluginWidget::onCreatorModified()
 
 void SKGBudgetPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGBudgetPluginWidget::onSelectionChanged");
-    if (!m_objectModel) return;
+    SKGTRACEINFUNC(10);
+    if (!m_objectModel) {
+        return;
+    }
 
     SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
     int nb = objs.count();
@@ -524,7 +539,9 @@ void SKGBudgetPluginWidget::onSelectionChanged()
             ui.kPeriod->setCurrentIndex(budget.getMonth() == 0 ? 1 : 2);  // Set yearly or individual
             ui.kIncludingSubCategories->setChecked(budget.isSubCategoriesInclusionEnabled());
 
-            if (mode > 0) ui.kWidgetSelector->setSelectedMode(0);
+            if (mode > 0) {
+                ui.kWidgetSelector->setSelectedMode(0);
+            }
         } else {
             SKGBudgetRuleObject rule(objs.at(0));
             ui.kYearCheck->setChecked(rule.isYearConditionEnabled());
@@ -553,7 +570,9 @@ void SKGBudgetPluginWidget::onSelectionChanged()
 
 void SKGBudgetPluginWidget::activateEditor()
 {
-    if (ui.kWidgetSelector->getSelectedMode() == -1) ui.kWidgetSelector->setSelectedMode(0);
+    if (ui.kWidgetSelector->getSelectedMode() == -1) {
+        ui.kWidgetSelector->setSelectedMode(0);
+    }
     ui.kAmountEdit->setFocus();
 }
 
@@ -564,7 +583,7 @@ bool SKGBudgetPluginWidget::isEditor()
 
 void SKGBudgetPluginWidget::refreshInfoZone()
 {
-    SKGTRACEIN(10, "SKGBudgetPluginWidget::refreshInfoZone");
+    SKGTRACEINFUNC(10);
     KLocale* loc = KGlobal::locale();
     SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
     if (doc && loc && ui.kWidgetSelector->getSelectedMode() != 2) {
