@@ -52,22 +52,24 @@ SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* iWidget, QObject* iParent, con
     : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_importStdCatAction(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGCategoriesPlugin::SKGCategoriesPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGCategoriesPlugin::~SKGCategoriesPlugin()
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::~SKGCategoriesPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
     m_importStdCatAction = NULL;
 }
 
 bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_categories/skrooge_categories.rc");
@@ -105,15 +107,16 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
 
 int SKGCategoriesPlugin::getNbDashboardWidgets()
 {
-    SKGTRACEIN(1, "SKGCategoriesPlugin::getNbDashboardWidgets");
+    SKGTRACEINFUNC(1);
     return 3;
 }
 
 QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidgetTitle");
-    if (iIndex == 0) return i18nc("Report header",  "5 main categories of expenditure");
-    else if (iIndex == 1) {
+    SKGTRACEINFUNC(1);
+    if (iIndex == 0) {
+        return i18nc("Report header",  "5 main categories of expenditure");
+    } else if (iIndex == 1) {
         return i18nc("Report header",  "5 main variations");
     }
     return i18nc("Report header",  "Budget");
@@ -121,7 +124,7 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 {
-    SKGTRACEIN(1, "SKGCategoriesPlugin::getDashboardWidget");
+    SKGTRACEINFUNC(1);
     if (iIndex == 0)  {
         SKGHtmlBoardWidget* w = new SKGHtmlBoardWidget(m_currentBankDocument,
                 getDashboardWidgetTitle(iIndex),
@@ -154,10 +157,12 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 
 void SKGCategoriesPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (m_currentBankDocument) {
         bool test = (m_currentBankDocument->getDatabase() != NULL);
-        if (m_importStdCatAction) m_importStdCatAction->setEnabled(test);
+        if (m_importStdCatAction) {
+            m_importStdCatAction->setEnabled(test);
+        }
 
         // Automatic categories creation
         if (m_currentBankDocument->getDatabase() != NULL) {
@@ -180,7 +185,7 @@ void SKGCategoriesPlugin::refresh()
 
 void SKGCategoriesPlugin::importCategories()
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::importCategories");
+    SKGTRACEINFUNC(10);
     SKGError err;
     KAction* act = qobject_cast< KAction* >(sender());
     if (act) {
@@ -208,7 +213,7 @@ void SKGCategoriesPlugin::importCategories()
 
 void SKGCategoriesPlugin::importStandardCategories()
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::importStandardCategories");
+    SKGTRACEINFUNC(10);
     SKGError err;
     {
         QString cats = i18nc("List of categories.It is not needed to translate each item. You can set the list you want. ';' must be used to separate categories. ' > ' must be used to separate categorie and sub caterogie (no limit of level).",
@@ -255,7 +260,7 @@ void SKGCategoriesPlugin::importStandardCategories()
 
 SKGTabPage* SKGCategoriesPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGCategoriesPluginWidget(m_currentBankDocument);
 }
 
@@ -294,11 +299,11 @@ bool SKGCategoriesPlugin::isInPagesChooser() const
 
 SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGCategoriesPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
     // Check unused categies
     if (!iIgnoredAdvice.contains("skgcategoriesplugin_unused")) {
-        SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgcategoriesplugin_unused");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_category_used2", "t_ISUSEDCASCADE='N'", exist);
         if (exist) {
@@ -316,7 +321,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations not validated
     if (!iIgnoredAdvice.contains("skgmonthlyplugin_maincategoriesvariation")) {
-        SKGTRACEIN(10, "SKGCategoriesPlugin::advice-skgmonthlyplugin_maincategoriesvariation");
+        SKGTRACEINFUNC(10);
         QString month = QDate::currentDate().toString("yyyy-MM");
         QDate datepreviousmonth = QDate::currentDate().addDays(-QDate::currentDate().day());
         QString previousmonth = datepreviousmonth.toString("yyyy-MM");
@@ -358,7 +363,7 @@ SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIden
 void SKGCategoriesPlugin::deleteUnusedCategories() const
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGCategoriesPlugin::deleteUnusedCategories", err);
+    _SKGTRACEINFUNCRC(10, err);
     if (m_currentBankDocument) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused categories")  , err);
 
@@ -373,13 +378,16 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
             QString cat = categoriesUsed.at(i);
             categoriesUsed[i] = SKGServices::stringToSqlString(cat);
             int pos = cat.lastIndexOf(OBJECTSEPARATOR);
-            if (pos != -1) categoriesUsed.push_back(cat.left(pos));
+            if (pos != -1) {
+                categoriesUsed.push_back(cat.left(pos));
+            }
         }
 
         IFOK(err) {
             QString sql;
-            if (categoriesUsed.count())  sql = "DELETE FROM category WHERE t_fullname NOT IN ('" % categoriesUsed.join("','") % "')";
-            else {
+            if (categoriesUsed.count()) {
+                sql = "DELETE FROM category WHERE t_fullname NOT IN ('" % categoriesUsed.join("','") % "')";
+            } else {
                 sql = "DELETE FROM category";
             }
             err = m_currentBankDocument->executeSqliteOrder(sql);
