@@ -41,8 +41,10 @@
 SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(10, "SKGCategoriesPluginWidget::SKGCategoriesPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(10);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -101,7 +103,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
 
 SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget()
 {
-    SKGTRACEIN(10, "SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget");
+    SKGTRACEINFUNC(10);
 }
 
 bool SKGCategoriesPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -122,7 +124,7 @@ bool SKGCategoriesPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
-    SKGTRACEIN(10, "SKGCategoriesPluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (!iLightTransaction) {
@@ -137,7 +139,7 @@ void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdT
 
 void SKGCategoriesPluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGCategoriesPluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
     // Clean widgets
     int nb = ui.kLayout->count();
     for (int i = 0; i < nb; ++i) {
@@ -165,7 +167,9 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
             KPushButton* btn = new KPushButton(ui.kFrame);
             btn->setFlat(true);
             btn->setText(items.at(i).trimmed());
-            if (!fullname.isEmpty()) fullname += OBJECTSEPARATOR;
+            if (!fullname.isEmpty()) {
+                fullname += OBJECTSEPARATOR;
+            }
             fullname += items.at(i).trimmed();
             btn->setProperty("FULLNAME", fullname);
             connect(btn, SIGNAL(clicked()), this, SLOT(changeSelection()));
@@ -197,7 +201,7 @@ void SKGCategoriesPluginWidget::changeSelection()
 
 QString SKGCategoriesPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGCategoriesPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -209,7 +213,7 @@ QString SKGCategoriesPluginWidget::getState()
 
 void SKGCategoriesPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGCategoriesPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -230,7 +234,7 @@ QWidget* SKGCategoriesPluginWidget::mainWidget()
 
 void SKGCategoriesPluginWidget::onEditorModified()
 {
-    _SKGTRACEIN(10, "SKGCategoriesPluginWidget::onEditorModified");
+    _SKGTRACEINFUNC(10);
     int nb = getNbSelectedObjects();
     ui.kModifyCategoryButton->setEnabled(!ui.kNameInput1->text().isEmpty() && nb >= 1);
 }
@@ -238,10 +242,12 @@ void SKGCategoriesPluginWidget::onEditorModified()
 void SKGCategoriesPluginWidget::onAddCategory()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGCategoriesPluginWidget::onAddCategory", err);
+    _SKGTRACEINFUNCRC(10, err);
     SKGCategoryObject cat;
     QString name = ui.kNameInput1->text();
-    if (name.isEmpty()) name = i18nc("Noun, default name for a new category", "New category");
+    if (name.isEmpty()) {
+        name = i18nc("Noun, default name for a new category", "New category");
+    }
     {
         // Get Selection
         SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
@@ -271,7 +277,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
 void SKGCategoriesPluginWidget::onUpdateCategory()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGCategoriesPluginWidget::onUpdateCategory", err);
+    _SKGTRACEINFUNCRC(10, err);
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
 
@@ -316,7 +322,9 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
 void SKGCategoriesPluginWidget::onDeleteUnused()
 {
     QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("clean_delete_unused_categories");
-    if (act) act->trigger();
+    if (act) {
+        act->trigger();
+    }
 }
 
 void SKGCategoriesPluginWidget::cleanEditor()
