@@ -22,19 +22,26 @@
 #include "skgoperationboardwidget.h"
 
 #include <QDomDocument>
+#include <QParallelAnimationGroup>
+#include <QPropertyAnimation>
 
 #include <KAction>
 
 #include "skgdocumentbank.h"
+#include "skgreportbank.h"
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skgobjectbase.h"
 #include "skgmainpanel.h"
+#include "skgperiodedit.h"
 
 SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Income & Expenditure"))
 {
-    SKGTRACEIN(10, "SKGOperationBoardWidget::SKGOperationBoardWidget");
+    SKGTRACEINFUNC(10);
+
+    // Initialize animation group
+    m_anim = new QParallelAnimationGroup(this);
 
     QFrame* f = new QFrame();
     ui.setupUi(f);
@@ -63,9 +70,11 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     connect(m_menuOpen, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     addAction(m_menuOpen);
 
-    QAction* sep = new QAction(this);
-    sep->setSeparator(true);
-    addAction(sep);
+    {
+        QAction* sep = new QAction(this);
+        sep->setSeparator(true);
+        addAction(sep);
+    }
 
     m_menuTransfert = new KAction(i18nc("Noun, a type of operations", "Transfers"), this);
     m_menuTransfert->setCheckable(true);
@@ -85,15 +94,62 @@ SKGOperationBoardWidget::SKGOperationBoardWidget(SKGDocument* iDocument)
     connect(m_menuSuboperation, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
     addAction(m_menuSuboperation);
 
+    {
+        QAction* sep = new QAction(this);
+        sep->setSeparator(true);
+        addAction(sep);
+    }
+
+    m_periodEdit1 = new SKGPeriodEdit(this);
+    {
+        // Set default
+        QDomDocument doc("SKGML");
+        QDomElement root = doc.createElement("parameters");
+        doc.appendChild(root);
+        root.setAttribute("period", SKGServices::intToString(static_cast<int>(SKGPeriodEdit::CURRENT)));
+        m_periodEdit1->setState(doc.toString());
+
+        // Add widget in menu
+        QWidgetAction* periodEditWidget = new QWidgetAction(this);
+        periodEditWidget->setDefaultWidget(m_periodEdit1);
+
+        addAction(periodEditWidget);
+    }
+
+    {
+        QAction* sep = new QAction(this);
+        sep->setSeparator(true);
+        addAction(sep);
+    }
+
+    m_periodEdit2 = new SKGPeriodEdit(this);
+    {
+        // Set default
+        QDomDocument doc("SKGML");
+        QDomElement root = doc.createElement("parameters");
+        doc.appendChild(root);
+        root.setAttribute("period", SKGServices::intToString(static_cast<int>(SKGPeriodEdit::PREVIOUS)));
+        m_periodEdit2->setState(doc.toString());
+
+        // Add widget in menu
+        QWidgetAction* periodEditWidget = new QWidgetAction(this);
+        periodEditWidget->setDefaultWidget(m_periodEdit2);
+
+        addAction(periodEditWidget);
+    }
+
     // Refresh
+    connect(m_periodEdit1, SIGNAL(changed()), this, SLOT(dataModified()), Qt::QueuedConnection);
+    connect(m_periodEdit2, SIGNAL(changed()), this, SLOT(dataModified()), Qt::QueuedConnection);
     connect(getDocument(), SIGNAL(tableModified(QString,int,bool)), this, SLOT(dataModified(QString,int)), Qt::QueuedConnection);
 }
 
 SKGOperationBoardWidget::~SKGOperationBoardWidget()
 {
-    SKGTRACEIN(10, "SKGOperationBoardWidget::~SKGOperationBoardWidget");
+    SKGTRACEINFUNC(10);
     m_menuTransfert = NULL;
     m_menuTracked = NULL;
+    m_anim = NULL;
 }
 
 QString SKGOperationBoardWidget::getState()
@@ -105,6 +161,8 @@ QString SKGOperationBoardWidget::getState()
     root.setAttribute("menuTransfert", m_menuTransfert && m_menuTransfert->isChecked() ? "Y" : "N");
     root.setAttribute("menuTracked", m_menuTracked && m_menuTracked->isChecked() ? "Y" : "N");
     root.setAttribute("menuSuboperation", m_menuSuboperation && m_menuSuboperation->isChecked() ? "Y" : "N");
+    root.setAttribute("period1", m_periodEdit1->getState());
+    root.setAttribute("period2", m_periodEdit2->getState());
     return doc.toString();
 }
 
@@ -113,10 +171,23 @@ void SKGOperationBoardWidget::setState(const QString& iState)
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
-    if (m_menuTransfert) m_menuTransfert->setChecked(root.attribute("menuTransfert") == "Y");
-    if (m_menuTracked) m_menuTracked->setChecked(root.attribute("menuTracked") != "N");
-    if (m_menuSuboperation) m_menuSuboperation->setChecked(root.attribute("menuSuboperation") == "Y");
-
+    if (m_menuTransfert) {
+        m_menuTransfert->setChecked(root.attribute("menuTransfert") == "Y");
+    }
+    if (m_menuTracked) {
+        m_menuTracked->setChecked(root.attribute("menuTracked") != "N");
+    }
+    if (m_menuSuboperation) {
+        m_menuSuboperation->setChecked(root.attribute("menuSuboperation") == "Y");
+    }
+    QString period1 = root.attribute("period1");
+    if (m_periodEdit1 && !period1.isEmpty()) {
+        m_periodEdit1->setState(period1);
+    }
+    QString period2 = root.attribute("period2");
+    if (m_periodEdit2 && !period2.isEmpty()) {
+        m_periodEdit2->setState(period2);
+    }
     dataModified("", 0);
 }
 
@@ -124,30 +195,33 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
 {
     // Call operation plugin
     QString wc;
-    if (iLink.endsWith(QLatin1String("C"))) wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now')) AND t_TYPEACCOUNT<>'L'";
-    else {
-        wc = "d_DATEMONTH=STRFTIME('%Y-%m', date('now','-1 Month')) AND t_TYPEACCOUNT<>'L'";
+    if (iLink.endsWith(QLatin1String("C"))) {
+        wc = m_periodEdit1->getWhereClause() % " AND t_TYPEACCOUNT<>'L'";
+    } else {
+        wc = m_periodEdit2->getWhereClause() % " AND t_TYPEACCOUNT<>'L'";
     }
 
-    if (iLink.startsWith(QLatin1String("I"))) wc = wc % " AND t_TYPEEXPENSE='+'";
-    else if (iLink.startsWith(QLatin1String("E"))) {
+    if (iLink.startsWith(QLatin1String("I"))) {
+        wc = wc % " AND t_TYPEEXPENSE='+'";
+    } else if (iLink.startsWith(QLatin1String("E"))) {
         wc = wc % " AND t_TYPEEXPENSE='-'";
     }
 
     wc = wc % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : " AND t_TRANSFER='N'") % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''");
 
     QString title;
-    if (iLink == "IC") title = i18nc("Title of a list of operations", "Incomes of current month");
-    else if (iLink == "EC") {
-        title = i18nc("Title of a list of operations", "Expenses of current month");
+    if (iLink == "IC") {
+        title = i18nc("Title of a list of operations", "Incomes of %1", ui.kLabel->text());
+    } else if (iLink == "EC") {
+        title = i18nc("Title of a list of operations", "Expenses of %1", ui.kLabel->text());
     } else if (iLink == "SC") {
-        title = i18nc("Title of a list of operations", "Savings of current month");
+        title = i18nc("Title of a list of operations", "Savings of %1", ui.kLabel->text());
     } else if (iLink == "IP") {
-        title = i18nc("Title of a list of operations", "Incomes of previous month");
+        title = i18nc("Title of a list of operations", "Incomes of %1", ui.kLabel_previous->text());
     } else if (iLink == "EP") {
-        title = i18nc("Title of a list of operations", "Expenses of previous month");
+        title = i18nc("Title of a list of operations", "Expenses of %1", ui.kLabel_previous->text());
     } else if (iLink == "SP") {
-        title = i18nc("Title of a list of operations", "Savings of previous month");
+        title = i18nc("Title of a list of operations", "Savings of %1", ui.kLabel_previous->text());
     }
 
     bool onSubOperation = (m_menuSuboperation && m_menuSuboperation->isChecked());
@@ -157,18 +231,13 @@ void SKGOperationBoardWidget::onOpen(const QString& iLink)
 
 void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(10, "SKGOperationBoardWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
     QString table = (m_menuSuboperation && m_menuSuboperation->isChecked() ? "v_operation_consolidated" : "v_operation_display");
-    QString amount = (m_menuSuboperation && m_menuSuboperation->isChecked() ? "f_REALCURRENTAMOUNT" : "f_CURRENTAMOUNT");
-
     if (iTableName == table || iTableName.isEmpty()) {
-        // Get month
-        QDate date = QDate::currentDate();
-        date = date.addDays(1 - date.day());
-        QDate date1 = date.addDays(-1);
-        QString month = date.toString("yyyy-MM");
-        QString previousmonth = date1.toString("yyyy-MM");
+        // Set titles
+        ui.kLabel->setText(m_periodEdit1->text());
+        ui.kLabel_previous->setText(m_periodEdit2->text());
 
         SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
@@ -186,36 +255,27 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             SKGServices::SKGUnitInfo secondary = doc->getSecondaryUnit();
 
-            SKGStringListList listTmp;
-            SKGError err = getDocument()->executeSelectSqliteOrder(
-                               "SELECT TOTAL(" % amount % "), d_DATEMONTH  from " % table % " WHERE d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TYPEACCOUNT<>'L'"
-                               % (m_menuTransfert && m_menuTransfert->isChecked() ? "" : "AND t_TRANSFER='N'")
-                               % (m_menuTracked && m_menuTracked->isChecked() ? "" : " AND t_REFUND=''")
-                               % " group by d_DATEMONTH, t_TYPEEXPENSE",
-                               listTmp);
-            IFOK(err) {
-                double income_previous_month = 0;
-                double expense_previous_month = 0;
-                double income_month = 0;
-                double expense_month = 0;
+            SKGReportBank* bk = qobject_cast< SKGReportBank* >(doc->getReport());
+            if (bk) {
+                QVariantList table = bk->getIncomeVsExpenditure(m_menuSuboperation && m_menuSuboperation->isChecked(),
+                                     m_menuTransfert && m_menuTransfert->isChecked(),
+                                     m_menuTracked && m_menuTracked->isChecked(),
+                                     m_periodEdit1->getWhereClause(),
+                                     m_periodEdit2->getWhereClause());
+                delete bk;
 
-                int nbval = listTmp.count();
-                for (int i = 1; i < nbval; ++i) {  // Ignore header
-                    QString m = listTmp.at(i).at(1);
-                    double v = SKGServices::stringToDouble(listTmp.at(i).at(0));
-                    if (v > 0 && m == month) income_month = v;
-                    else if (v < 0 && m == month) {
-                        expense_month = -v;
-                    } else if (v > 0 && m == previousmonth) {
-                        income_previous_month = v;
-                    } else if (v < 0 && m == previousmonth) {
-                        expense_previous_month = -v;
-                    }
-                }
+                QList<QVariant> l1 = table.value(1).toList();
+                QList<QVariant> l2 = table.value(2).toList();
+                double income_previous_month = l1.value(2).toDouble();
+                double expense_previous_month = l2.value(2).toDouble();
+                double income_month = l1.value(3).toDouble();
+                double expense_month = l2.value(3).toDouble();
 
                 // Set Maximum
                 int max = qMax(income_previous_month, qMax(expense_previous_month, qMax(income_month, expense_month)));
-                if (nbval == 1 || max == 0) max = 100.0;
+                if (max == 0) {
+                    max = 100.0;
+                }
                 ui.kIncome->setMaximum(max);
                 ui.kIncome_previous->setMaximum(max);
                 ui.kExpense->setMaximum(max);
@@ -223,14 +283,6 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 ui.kSaving->setMaximum(max);
                 ui.kSaving_previous->setMaximum(max);
 
-                // Set values
-                ui.kIncome->setValue(income_month);
-                ui.kIncome_previous->setValue(income_previous_month);
-                ui.kExpense->setValue(expense_month);
-                ui.kExpense_previous->setValue(expense_previous_month);
-                ui.kSaving->setValue(qAbs(income_month - expense_month));
-                ui.kSaving_previous->setValue(qAbs(income_previous_month - expense_previous_month));
-
                 // Set texts and tool tips
                 ui.kIncome->setFormat(doc->formatMoney(income_month, primary, false));
                 ui.kIncome_previous->setFormat(doc->formatMoney(income_previous_month, primary, false));
@@ -254,12 +306,66 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                 ui.kExpense_previous->setLimits(max, -1, -1);
                 ui.kSaving->setLimits(income_month - expense_month < 0 ? max : 0, 0.1 * income_month, max);
                 ui.kSaving_previous->setLimits(income_previous_month - expense_previous_month < 0 ? max : 0, 0.1 * income_previous_month, max);
+
+                // Set values
+                m_anim->clear();
+                {
+                    QPropertyAnimation* panim = new QPropertyAnimation(ui.kIncome, "value");
+                    panim->setDuration(1000);
+                    panim->setStartValue(0);
+                    panim->setEndValue(static_cast<int>(income_month));
+                    m_anim->addAnimation(panim);
+                }
+
+                {
+                    QPropertyAnimation* panim = new QPropertyAnimation(ui.kIncome_previous, "value");
+                    panim->setDuration(1000);
+                    panim->setStartValue(0);
+                    panim->setEndValue(static_cast<int>(income_previous_month));
+                    m_anim->addAnimation(panim);
+                }
+
+                {
+                    QPropertyAnimation* panim = new QPropertyAnimation(ui.kExpense, "value");
+                    panim->setDuration(1000);
+                    panim->setStartValue(0);
+                    panim->setEndValue(static_cast<int>(expense_month));
+                    m_anim->addAnimation(panim);
+                }
+
+                {
+                    QPropertyAnimation* panim = new QPropertyAnimation(ui.kExpense_previous, "value");
+                    panim->setDuration(1000);
+                    panim->setStartValue(0);
+                    panim->setEndValue(static_cast<int>(expense_previous_month));
+                    m_anim->addAnimation(panim);
+                }
+
+                {
+                    QPropertyAnimation* panim = new QPropertyAnimation(ui.kSaving, "value");
+                    panim->setDuration(1000);
+                    panim->setStartValue(0);
+                    panim->setEndValue(static_cast<int>(qAbs(income_month - expense_month)));
+                    m_anim->addAnimation(panim);
+                }
+
+                {
+                    QPropertyAnimation* panim = new QPropertyAnimation(ui.kSaving_previous, "value");
+                    panim->setDuration(1000);
+                    panim->setStartValue(0);
+                    panim->setEndValue(static_cast<int>(qAbs(income_previous_month - expense_previous_month)));
+                    m_anim->addAnimation(panim);
+                }
+
+                QTimer::singleShot(1000, m_anim, SLOT(start()));
             }
 
             // No widget if no account
             bool exist = false;
             doc->existObjects("account", "", exist);
-            if (parentWidget()) setVisible(exist);
+            if (parentWidget()) {
+                setVisible(exist);
+            }
         }
     }
 }
