@@ -64,12 +64,12 @@ SKGOperationPlugin::SKGOperationPlugin(QWidget* iWidget, QObject* iParent, const
     m_open(NULL), m_currentBankDocument(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGOperationPlugin::SKGOperationPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGOperationPlugin::~SKGOperationPlugin()
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::~SKGOperationPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
     m_duplicateAction = NULL;
     m_switchToPointedAction = NULL;
@@ -86,10 +86,12 @@ SKGOperationPlugin::~SKGOperationPlugin()
 
 bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     m_currentBankDocument->setComputeBalances(skgoperation_settings::computeBalances());
 
@@ -203,11 +205,23 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     connect(actTmp, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     registerGlobalAction("view_open_operation_with_comment_not_aligned", actTmp);
 
+    // ------------
+    actTmp = new KAction(KIcon("view-pim-calendar", NULL, overlayopen), i18nc("Verb", "Open operations with dates not aligned..."), this);
+    actTmp->setData(QString("skg://skrooge_operation_plugin/?title_icon=draw-freehand&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations with dates not aligned")) %
+                            "&operationWhereClause=" % SKGServices::encodeForUrl("id IN (SELECT op.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.d_date<>op.d_date AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)")));
+    connect(actTmp, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+    registerGlobalAction("view_open_operation_with_date_not_aligned", actTmp);
+
     // ------------
     actTmp = new KAction(KIcon("draw-freehand", NULL, overlayrun), i18nc("Verb", "Align comment of suboperations"), this);
     connect(actTmp, SIGNAL(triggered(bool)), this, SLOT(onAlignComment()));
     registerGlobalAction("clean_align_comment", actTmp);
 
+    // ------------
+    actTmp = new KAction(KIcon("view-pim-calendar", NULL, overlayrun), i18nc("Verb", "Align date of suboperations"), this);
+    connect(actTmp, SIGNAL(triggered(bool)), this, SLOT(onAlignDate()));
+    registerGlobalAction("clean_align_date", actTmp);
+
     // ------------
     actTmp = new KAction(KIcon("view-financial-transfer", NULL, overlayopen), i18nc("Verb", "Open operations in groups with only one operation..."), this);
     actTmp->setData(QString("skg://skrooge_operation_plugin/?title_icon=view-financial-transfer&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations in groups with only one operation")) %
@@ -244,32 +258,66 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
 void SKGOperationPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (m_currentBankDocument && SKGMainPanel::getMainPanel()) {
         bool test = (m_currentBankDocument->getDatabase() != NULL);
-        if (m_openHighLights) m_openHighLights->setEnabled(test);
-        if (m_openSuboperations) m_openSuboperations->setEnabled(test);
-        if (m_openDuplicate) m_openDuplicate->setEnabled(test);
-        if (m_openLastModified) m_openLastModified->setEnabled(test && m_currentBankDocument->getNbTransaction() > 0);
+        if (m_openHighLights) {
+            m_openHighLights->setEnabled(test);
+        }
+        if (m_openSuboperations) {
+            m_openSuboperations->setEnabled(test);
+        }
+        if (m_openDuplicate) {
+            m_openDuplicate->setEnabled(test);
+        }
+        if (m_openLastModified) {
+            m_openLastModified->setEnabled(test && m_currentBankDocument->getNbTransaction() > 0);
+        }
 
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
-        if (m_open) m_open->setEnabled(nb > 0);
+        if (m_open) {
+            m_open->setEnabled(nb > 0);
+        }
         if (nb > 0) {
             bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
-            if (m_duplicateAction) m_duplicateAction->setEnabled(onOperation);
-            if (m_createTemplateAction) m_createTemplateAction->setEnabled(onOperation);
-            if (m_switchToPointedAction) m_switchToPointedAction->setEnabled(onOperation);
-            if (m_groupOperation) m_groupOperation->setEnabled(onOperation && selection.count() >= 2);
-            if (m_ungroupOperation) m_ungroupOperation->setEnabled(onOperation);
-            if (m_mergeOperationAction) m_mergeOperationAction->setEnabled(onOperation);
+            if (m_duplicateAction) {
+                m_duplicateAction->setEnabled(onOperation);
+            }
+            if (m_createTemplateAction) {
+                m_createTemplateAction->setEnabled(onOperation);
+            }
+            if (m_switchToPointedAction) {
+                m_switchToPointedAction->setEnabled(onOperation);
+            }
+            if (m_groupOperation) {
+                m_groupOperation->setEnabled(onOperation && selection.count() >= 2);
+            }
+            if (m_ungroupOperation) {
+                m_ungroupOperation->setEnabled(onOperation);
+            }
+            if (m_mergeOperationAction) {
+                m_mergeOperationAction->setEnabled(onOperation);
+            }
         } else {
-            if (m_duplicateAction) m_duplicateAction->setEnabled(false);
-            if (m_createTemplateAction) m_createTemplateAction->setEnabled(false);
-            if (m_switchToPointedAction) m_switchToPointedAction->setEnabled(false);
-            if (m_groupOperation) m_groupOperation->setEnabled(false);
-            if (m_ungroupOperation) m_ungroupOperation->setEnabled(false);
-            if (m_mergeOperationAction) m_mergeOperationAction->setEnabled(false);
+            if (m_duplicateAction) {
+                m_duplicateAction->setEnabled(false);
+            }
+            if (m_createTemplateAction) {
+                m_createTemplateAction->setEnabled(false);
+            }
+            if (m_switchToPointedAction) {
+                m_switchToPointedAction->setEnabled(false);
+            }
+            if (m_groupOperation) {
+                m_groupOperation->setEnabled(false);
+            }
+            if (m_ungroupOperation) {
+                m_ungroupOperation->setEnabled(false);
+            }
+            if (m_mergeOperationAction) {
+                m_mergeOperationAction->setEnabled(false);
+            }
         }
     }
 }
@@ -281,13 +329,17 @@ int SKGOperationPlugin::getNbDashboardWidgets()
 
 QString SKGOperationPlugin::getDashboardWidgetTitle(int iIndex)
 {
-    if (iIndex == 0) return i18nc("Noun, the title of a section", "Income && Expenditure");
+    if (iIndex == 0) {
+        return i18nc("Noun, the title of a section", "Income && Expenditure");
+    }
     return i18nc("Noun, the title of a section", "Highlighted operations");
 }
 
 SKGBoardWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
 {
-    if (iIndex == 0) return new SKGOperationBoardWidget(m_currentBankDocument);
+    if (iIndex == 0) {
+        return new SKGOperationBoardWidget(m_currentBankDocument);
+    }
     return new SKGHtmlBoardWidget(m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
                                   KStandardDirs().findResource("data", "skrooge/html/default/highlighted_operations.html"),
@@ -296,13 +348,13 @@ SKGBoardWidget* SKGOperationPlugin::getDashboardWidget(int iIndex)
 
 SKGTabPage* SKGOperationPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGOperationPluginWidget(m_currentBankDocument);
 }
 
 QWidget* SKGOperationPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
     return w;
@@ -360,7 +412,7 @@ bool SKGOperationPlugin::isInPagesChooser() const
 void SKGOperationPlugin::onGroupOperation()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onGroupOperation", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -393,7 +445,7 @@ void SKGOperationPlugin::onGroupOperation()
 void SKGOperationPlugin::onUngroupOperation()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onUngroupOperation", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -423,7 +475,7 @@ void SKGOperationPlugin::onUngroupOperation()
 void SKGOperationPlugin::onSwitchToPointed()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onSwitchToPointed", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -453,7 +505,7 @@ void SKGOperationPlugin::onSwitchToPointed()
 void SKGOperationPlugin::onDuplicate()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onDuplicate", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         QStringList listUUID;
@@ -475,7 +527,9 @@ void SKGOperationPlugin::onDuplicate()
         IFOK(err) {
             err = SKGError(0, i18nc("Successful message after an user action", "Operation duplicated."));
             SKGOperationPluginWidget* w = qobject_cast<SKGOperationPluginWidget*>(SKGMainPanel::getMainPanel()->currentPage());
-            if (w) w->getTableView()->selectObjects(listUUID, true);
+            if (w) {
+                w->getTableView()->selectObjects(listUUID, true);
+            }
         } else {
             err.addError(ERR_FAIL, i18nc("Error message",  "Duplicate operation failed"));
         }
@@ -488,7 +542,7 @@ void SKGOperationPlugin::onDuplicate()
 void SKGOperationPlugin::onCreateTemplate()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onCreateTemplate", err);
+    SKGTRACEINFUNCRC(10, err);
     // Get Selection
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         QStringList listUUID;
@@ -525,15 +579,19 @@ void SKGOperationPlugin::onCreateTemplate()
 
 void SKGOperationPlugin::onOpenOperations()
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::onOpenOperations");
+    SKGTRACEINFUNC(10);
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection;
         QAction* act = qobject_cast< QAction* >(sender());
         if (act) {
             QStringList data = SKGServices::splitCSVLine(act->data().toString(), '-');
-            if (data.count() == 2) selection.push_back(SKGObjectBase(m_currentBankDocument, data[1], SKGServices::stringToInt(data[0])));
+            if (data.count() == 2) {
+                selection.push_back(SKGObjectBase(m_currentBankDocument, data[1], SKGServices::stringToInt(data[0])));
+            }
+        }
+        if (selection.isEmpty()) {
+            selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         }
-        if (selection.isEmpty()) selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
         int nb = selection.count();
         if (nb > 0) {
@@ -596,8 +654,9 @@ void SKGOperationPlugin::onOpenOperations()
                     QString name = tmp.getFullName();
 
                     wc += "(t_REALCATEGORY";
-                    if (name.isEmpty()) wc += " IS NULL OR t_REALCATEGORY='')";
-                    else {
+                    if (name.isEmpty()) {
+                        wc += " IS NULL OR t_REALCATEGORY='')";
+                    } else {
                         wc += " = '" % SKGServices::stringToSqlString(name) % "' OR t_REALCATEGORY like '" % SKGServices::stringToSqlString(name) % OBJECTSEPARATOR % "%')";
                     }
 
@@ -716,7 +775,9 @@ void SKGOperationPlugin::onOpenOperations()
                     wc += "(id=" % SKGServices::intToString(opid);
 
                     opid = SKGServices::stringToInt(tmp.getAttribute("i_group_id"));
-                    if (opid != 0) wc += " or i_group_id=" % SKGServices::intToString(opid);
+                    if (opid != 0) {
+                        wc += " or i_group_id=" % SKGServices::intToString(opid);
+                    }
                     wc += ')';
 
                     titleOpen += i18n("'%1'", tmp.getDisplayName());
@@ -735,12 +796,21 @@ void SKGOperationPlugin::onOpenOperations()
                 doc.appendChild(root);
             }
 
-            if (!view.isEmpty()) root.setAttribute("operationTable", view);
-            if (!wc.isEmpty()) root.setAttribute("operationWhereClause", wc);
-            if (!titleOpen.isEmpty()) root.setAttribute("title", titleOpen);
-            if (!iconOpen.isEmpty()) root.setAttribute("title_icon", iconOpen);
-            if (!account.isEmpty()) root.setAttribute("account", account);
-            else {
+            if (!view.isEmpty()) {
+                root.setAttribute("operationTable", view);
+            }
+            if (!wc.isEmpty()) {
+                root.setAttribute("operationWhereClause", wc);
+            }
+            if (!titleOpen.isEmpty()) {
+                root.setAttribute("title", titleOpen);
+            }
+            if (!iconOpen.isEmpty()) {
+                root.setAttribute("title_icon", iconOpen);
+            }
+            if (!account.isEmpty()) {
+                root.setAttribute("account", account);
+            } else {
                 root.setAttribute("currentPage", "-1");
             }
 
@@ -751,12 +821,12 @@ void SKGOperationPlugin::onOpenOperations()
 
 SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGOperationPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Search duplicate number on operation
     if (!iIgnoredAdvice.contains("skgoperationplugin_duplicate")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_duplicate");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT count(1), t_ACCOUNT, i_number FROM v_operation_display WHERE i_number!=0 GROUP BY t_ACCOUNT, i_number HAVING count(1)>1 ORDER BY count(1) DESC", result);
         int nb = result.count();
@@ -780,7 +850,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations not reconciliated
     if (!iIgnoredAdvice.contains("skgoperationplugin_notreconciliated")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_notreconciliated");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT count(1), t_ACCOUNT FROM v_operation_display WHERE t_status='N' GROUP BY t_ACCOUNT HAVING count(1)>100 ORDER BY count(1) DESC", result);
         int nb = result.count();
@@ -803,7 +873,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations without mode
     if (!iIgnoredAdvice.contains("skgimportexportplugin_notvalidated")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgimportexportplugin_notvalidated");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("operation", "t_template='N' AND t_mode='' AND d_date<>'0000-00-00'", exist);
         if (exist) {
@@ -821,7 +891,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations without category
     if (!iIgnoredAdvice.contains("skgoperationplugin_nocategory")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_nocategory");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='N' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
         if (exist) {
@@ -838,7 +908,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     if (!iIgnoredAdvice.contains("skgoperationplugin_transfer_nocategory")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_transfer_nocategory");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='Y' AND EXISTS (SELECT 1 FROM suboperation WHERE rd_operation_id=v_operation_display.id AND r_category_id=0)", exist);
         if (exist) {
@@ -856,7 +926,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations without payee
     if (!iIgnoredAdvice.contains("skgoperationplugin_nopayee")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_nopayee");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='N' AND r_payee_id=0", exist);
         if (exist) {
@@ -873,7 +943,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
     }
 
     if (!iIgnoredAdvice.contains("skgoperationplugin_transfer_nopayee")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_transfer_nopayee");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "t_TRANSFER='Y' AND r_payee_id=0", exist);
         if (exist) {
@@ -891,7 +961,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check operations in group of only one transaction
     if (!iIgnoredAdvice.contains("skgoperationplugin_groupofone")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_groupofone");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("v_operation_display", "i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=v_operation_display.i_group_id)<2", exist);
         if (exist) {
@@ -910,7 +980,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Check simple operations with comment not aligned with the comment of the suboperation
     if (!iIgnoredAdvice.contains("skgoperationplugin_commentsnotaligned")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_commentsnotaligned");
+        SKGTRACEINFUNC(10);
         bool exist = false;
         m_currentBankDocument->existObjects("operation op, suboperation so", "so.rd_operation_id=op.id AND so.t_comment<>op.t_comment AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1", exist);
         if (exist) {
@@ -927,9 +997,28 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
+    // Check simple operations with date not aligned with the date of the suboperation
+    if (!iIgnoredAdvice.contains("skgoperationplugin_datesnotaligned")) {
+        SKGTRACEINFUNC(10);
+        bool exist = false;
+        m_currentBankDocument->existObjects("operation op, suboperation so", "so.rd_operation_id=op.id AND so.d_date<>op.d_date AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1", exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgoperationplugin_datesnotaligned");
+            ad.setPriority(5);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Some simple operations don't have their dates aligned"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "The date of the operation is not aligned with the date of the suboperation."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://view_open_operation_with_date_not_aligned");
+            autoCorrections.push_back("skg://clean_align_date");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
+    }
+
     // Too much money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_too_much_money")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_too_much_money");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name, f_RATE FROM v_account_display WHERE t_close='N' AND f_RATE>0 AND (t_maxamount_enabled='N' OR f_CURRENTAMOUNT<f_maxamount*0.9) ORDER BY f_RATE DESC", result);
         int nb = result.count();
@@ -960,7 +1049,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Not enough money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_minimum_limit")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_minimum_limit");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
 
         // Get accounts with amount close or below the minimum limit
@@ -981,7 +1070,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Not enough money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_maximum_limit")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_maximum_limit");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
 
         // Get accounts with amount over the maximum limit
@@ -1002,7 +1091,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Not enough money in your account
     if (!iIgnoredAdvice.contains("skgoperationplugin_close_minimum_limit")) {
-        SKGTRACEIN(10, "SKGOperationPlugin::advice-skgoperationplugin_close_minimum_limit");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
 
         // Get accounts with amount close or below the minimum limit
@@ -1051,7 +1140,7 @@ SKGError SKGOperationPlugin::executeAdviceCorrection(const QString& iAdviceIdent
 void SKGOperationPlugin::onRemoveGroupWithOneOperation()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onRemoveGroupWithOneOperation", err);
+    SKGTRACEINFUNCRC(10, err);
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Remove groups with only one operation"), err);
         err = m_currentBankDocument->executeSqliteOrder("UPDATE operation SET i_group_id=0 WHERE i_group_id<>0 AND (SELECT COUNT(1) FROM operation o WHERE o.i_group_id=operation.i_group_id)<2");
@@ -1070,7 +1159,7 @@ void SKGOperationPlugin::onRemoveGroupWithOneOperation()
 void SKGOperationPlugin::onAlignComment()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onAlignComment", err);
+    SKGTRACEINFUNCRC(10, err);
 
     {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Align comment of suboperations"), err);
@@ -1087,10 +1176,30 @@ void SKGOperationPlugin::onAlignComment()
     SKGMainPanel::displayErrorMessage(err);
 }
 
+void SKGOperationPlugin::onAlignDate()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err);
+
+    {
+        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Align date of suboperations"), err);
+        err = m_currentBankDocument->executeSqliteOrder("UPDATE suboperation SET d_date=(SELECT op.d_date FROM operation op WHERE suboperation.rd_operation_id=op.id) WHERE suboperation.id IN (SELECT so.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.d_date<>op.d_date AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)");
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Dates aligned.")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Dates alignment failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 void SKGOperationPlugin::onMergeSubOperations()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGOperationPlugin::onMergeSubOperations", err);
+    SKGTRACEINFUNCRC(10, err);
 
     if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
