@@ -36,8 +36,10 @@
 SKGPayeePluginWidget::SKGPayeePluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGPayeePluginWidget::SKGPayeePluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
 
@@ -82,7 +84,7 @@ SKGPayeePluginWidget::SKGPayeePluginWidget(SKGDocument* iDocument)
 
 SKGPayeePluginWidget::~SKGPayeePluginWidget()
 {
-    SKGTRACEIN(1, "SKGPayeePluginWidget::~SKGPayeePluginWidget");
+    SKGTRACEINFUNC(1);
 }
 
 bool SKGPayeePluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
@@ -103,7 +105,7 @@ bool SKGPayeePluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGPayeePluginWidget::onSelectionChanged()
 {
-    SKGTRACEIN(10, "SKGPayeePluginWidget::onSelectionChanged");
+    SKGTRACEINFUNC(10);
 
     int nbSelect = ui.kView->getView()->getNbSelectedObjects();
     if (nbSelect == 1) {
@@ -122,7 +124,7 @@ void SKGPayeePluginWidget::onSelectionChanged()
 
 QString SKGPayeePluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGPayeePluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -132,7 +134,7 @@ QString SKGPayeePluginWidget::getState()
 
 void SKGPayeePluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGPayeePluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
@@ -151,7 +153,7 @@ QWidget* SKGPayeePluginWidget::mainWidget()
 
 void SKGPayeePluginWidget::onEditorModified()
 {
-    _SKGTRACEIN(10, "SKGPayeePluginWidget::onEditorModified");
+    _SKGTRACEINFUNC(10);
     int nb = getNbSelectedObjects();
     ui.kModifyButton->setEnabled(!ui.kNameInput->text().isEmpty() && nb >= 1);
     ui.kAddButton->setEnabled(!ui.kNameInput->text().isEmpty());
@@ -159,7 +161,7 @@ void SKGPayeePluginWidget::onEditorModified()
 
 void SKGPayeePluginWidget::dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction)
 {
-    SKGTRACEIN(10, "SKGPayeePluginWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (!iLightTransaction) {
@@ -174,7 +176,7 @@ void SKGPayeePluginWidget::dataModified(const QString& iTableName, int iIdTransa
 void SKGPayeePluginWidget::onAddPayee()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGPayeePluginWidget::onAddPayee", err);
+    _SKGTRACEINFUNCRC(10, err);
 
     QString name = ui.kNameInput->text();
     SKGPayeeObject payee;
@@ -200,7 +202,7 @@ void SKGPayeePluginWidget::onAddPayee()
 void SKGPayeePluginWidget::onModifyPayee()
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGPayeePluginWidget::onModifyPayee", err);
+    _SKGTRACEINFUNCRC(10, err);
 
     // Get Selection
     SKGObjectBase::SKGListSKGObjectBase selection = getSelectedObjects();
@@ -266,7 +268,9 @@ bool SKGPayeePluginWidget::isEditor()
 void SKGPayeePluginWidget::onDeleteUnused()
 {
     QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction("clean_delete_unused_payees");
-    if (act) act->trigger();
+    if (act) {
+        act->trigger();
+    }
 }
 
 #include "skgpayeepluginwidget.moc"
