@@ -50,22 +50,24 @@ SKGScheduledPlugin::SKGScheduledPlugin(QWidget* iWidget, QObject* iParent, const
     SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_scheduleOperationAction(NULL), m_counterAdvice(0)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGScheduledPlugin::SKGScheduledPlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGScheduledPlugin::~SKGScheduledPlugin()
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::~SKGScheduledPlugin");
+    SKGTRACEINFUNC(10);
     m_currentBankDocument = NULL;
     m_scheduleOperationAction = NULL;
 }
 
 bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
     m_currentBankDocument = qobject_cast<SKGDocumentBank*>(iDocument);
-    if (m_currentBankDocument == NULL) return false;
+    if (m_currentBankDocument == NULL) {
+        return false;
+    }
 
     setComponentData(KGlobal::mainComponent());
     setXMLFile("../skrooge_scheduled/skrooge_scheduled.rc");
@@ -80,15 +82,19 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
 void SKGScheduledPlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::refresh");
+    SKGTRACEINFUNC(10);
     if (SKGMainPanel::getMainPanel()) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
         if (selection.count() > 0) {
             bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
-            if (m_scheduleOperationAction) m_scheduleOperationAction->setEnabled(onOperation);
+            if (m_scheduleOperationAction) {
+                m_scheduleOperationAction->setEnabled(onOperation);
+            }
         } else {
-            if (m_scheduleOperationAction) m_scheduleOperationAction->setEnabled(false);
+            if (m_scheduleOperationAction) {
+                m_scheduleOperationAction->setEnabled(false);
+            }
         }
 
         // Automatic insert
@@ -135,13 +141,13 @@ SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 
 SKGTabPage* SKGScheduledPlugin::getWidget()
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::getWidget");
+    SKGTRACEINFUNC(10);
     return new SKGScheduledPluginWidget(m_currentBankDocument);
 }
 
 QWidget* SKGScheduledPlugin::getPreferenceWidget()
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::getPreferenceWidget");
+    SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
     return w;
@@ -250,7 +256,9 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
     IFOKDO(err, recOp.setTimeLimit(skgscheduled_settings::nb_times_val()))
     IFOKDO(err, recOp.setPeriodIncrement(skgscheduled_settings::once_every()))
     IFOKDO(err, recOp.setPeriodUnit(static_cast<SKGRecurrentOperationObject::PeriodUnit>(SKGServices::stringToInt(skgscheduled_settings::once_every_unit()))))
-    if (!err && !isTemplate) err = recOp.setDate(recOp.getNextDate());
+    if (!err && !isTemplate) {
+        err = recOp.setDate(recOp.getNextDate());
+    }
     IFOKDO(err, recOp.save())
     if (!isTemplate && skgscheduled_settings::create_template()) {
         IFOKDO(err, recOp.load())
@@ -266,7 +274,7 @@ SKGError SKGScheduledPlugin::scheduleOperation(const SKGOperationObject& iOperat
 void SKGScheduledPlugin::onScheduleOperation()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGScheduledPlugin::onScheduleOperation", err);
+    SKGTRACEINFUNCRC(10, err);
 
     // Get Selection
     if (SKGMainPanel::getMainPanel()) {
@@ -302,12 +310,12 @@ void SKGScheduledPlugin::onScheduleOperation()
 
 SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 {
-    SKGTRACEIN(10, "SKGScheduledPlugin::advice");
+    SKGTRACEINFUNC(10);
     SKGAdviceList output;
 
     // Recurrent operation with the last inserted operation having a different amount
     if (!iIgnoredAdvice.contains("skgscheduledplugin_notuptodate")) {
-        SKGTRACEIN(10, "SKGScheduledPlugin::advice-skgscheduledplugin_notuptodate");
+        SKGTRACEINFUNC(10);
         SKGStringListList result;
         m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.rd_operation_id, r.f_CURRENTAMOUNT, r2.f_CURRENTAMOUNT FROM v_recurrentoperation_display r INNER JOIN (SELECT MAX(d_date), f_CURRENTAMOUNT, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 WHERE r2.r_recurrentoperation_id=r.id AND ABS(r.f_CURRENTAMOUNT-r2.f_CURRENTAMOUNT)>" % SKGServices::doubleToString(EPSILON), result);
         int nb = result.count();
@@ -336,7 +344,7 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 
     // Possible recurrent operations
     if (!iIgnoredAdvice.contains("skgscheduledplugin_possibleschedule")) {
-        SKGTRACEIN(10, "SKGScheduledPlugin::advice-skgscheduledplugin_possibleschedule");
+        SKGTRACEINFUNC(10);
         if (m_counterAdvice % 10 != 0) {
             output.append(m_cacheAdvice);
         } else {
