@@ -37,7 +37,7 @@
 SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Alarms"))
 {
-    SKGTRACEIN(10, "SKGAlarmBoardWidget::SKGAlarmBoardWidget");
+    SKGTRACEINFUNC(10);
 
     // Create widget
     m_frame = new QFrame();
@@ -66,7 +66,7 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
 
 SKGAlarmBoardWidget::~SKGAlarmBoardWidget()
 {
-    SKGTRACEIN(10, "SKGAlarmBoardWidget::~SKGAlarmBoardWidget");
+    SKGTRACEINFUNC(10);
 
     m_menuFavorite = NULL;
 }
@@ -87,14 +87,16 @@ void SKGAlarmBoardWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    if (m_menuFavorite) m_menuFavorite->setChecked(root.attribute("menuFavorite") == "Y");
+    if (m_menuFavorite) {
+        m_menuFavorite->setChecked(root.attribute("menuFavorite") == "Y");
+    }
 
     dataModified("", 0);
 }
 
 void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(10, "SKGAlarmBoardWidget::dataModified");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iIdTransaction);
 
     if (iTableName == "operation" || iTableName == "rule" || iTableName.isEmpty()) {
@@ -165,7 +167,9 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
             // No widget if no account
             bool exist = false;
             getDocument()->existObjects("account", "", exist);
-            if (parentWidget()) setVisible(exist);
+            if (parentWidget()) {
+                setVisible(exist);
+            }
         }
     }
 }
