@@ -48,15 +48,16 @@
 #include "skgtraces.h"
 #include "skgmainpanel.h"
 
-SKGObjectModel::SKGObjectModel(SKGDocumentBank* iDocument,
-                               const QString& iTable,
-                               const QString& iWhereClause,
-                               QWidget* iParent,
-                               const QString& iParentAttribute,
-                               bool iResetOnCreation)
+SKGObjectModel::
+SKGObjectModel(SKGDocumentBank* iDocument,
+               const QString& iTable,
+               const QString& iWhereClause,
+               QWidget* iParent,
+               const QString& iParentAttribute,
+               bool iResetOnCreation)
     : SKGObjectModelBase(iDocument, iTable, iWhereClause, iParent, iParentAttribute, false)
 {
-    SKGTRACEIN(1, "SKGObjectModel::SKGObjectModel");
+    SKGTRACEINFUNC(1);
 
 
     m_isResetRealyNeeded = iResetOnCreation;
@@ -98,7 +99,9 @@ void SKGObjectModel::buidCache()
             m_cacheUnit.Value = 1;
             m_cacheUnit.NbDecimal = unitObject.getNumberDecimal();
         }
-        if (m_cacheUnit.Symbol.isEmpty()) m_cacheUnit.Symbol = ' ';
+        if (m_cacheUnit.Symbol.isEmpty()) {
+            m_cacheUnit.Symbol = ' ';
+        }
 
         // Bug 209672 vvvv
         if (unitObject.getType() == SKGUnitObject::INDEX) {
@@ -184,12 +187,12 @@ void SKGObjectModel::buidCache()
 
 SKGObjectModel::~SKGObjectModel()
 {
-    SKGTRACEIN(1, "SKGObjectModel::~SKGObjectModel");
+    SKGTRACEINFUNC(1);
 }
 
 QVariant SKGObjectModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    _SKGTRACEIN(10, "SKGObjectModelBase::headerData");
+    _SKGTRACEINFUNC(10);
 
     if (orientation == Qt::Horizontal) {
         if (role == Qt::DisplayRole) {
@@ -211,11 +214,14 @@ QVariant SKGObjectModel::headerData(int section, Qt::Orientation orientation, in
 QString SKGObjectModel::getAttributeForGrouping(const SKGObjectBase& iObject, const QString& iAttribute) const
 {
     if (m_recurrentoperationTable && iAttribute == "i_nb_times") {
-        if (iObject.getAttribute("t_times") != "Y") return QChar(8734);
+        if (iObject.getAttribute("t_times") != "Y") {
+            return QChar(8734);
+        }
     } else if (m_ruleTable && iAttribute == "t_action_type") {
         QString val = iObject.getAttribute(iAttribute);
-        if (val == "S") val = i18nc("Noun, a search", "Search");
-        else if (val == "U") {
+        if (val == "S") {
+            val = i18nc("Noun, a search", "Search");
+        } else if (val == "U") {
             val = i18nc("Noun, a modification", "Update");
         } else {
             val = i18nc("Noun, an alarm", "Alarm");
@@ -233,10 +239,14 @@ QString SKGObjectModel::getAttributeForGrouping(const SKGObjectBase& iObject, co
 
 QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 {
-    if (!iIndex.isValid()) return QVariant();
-    _SKGTRACEIN(10, "SKGObjectModel::data");
+    if (!iIndex.isValid()) {
+        return QVariant();
+    }
+    _SKGTRACEINFUNC(10);
     SKGObjectBase* obj = getObjectPointer(iIndex);
-    if (obj->getTable().isEmpty()) return SKGObjectModelBase::data(iIndex, iRole);
+    if (obj->getTable().isEmpty()) {
+        return SKGObjectModelBase::data(iIndex, iRole);
+    }
 
     switch (iRole) {
     case Qt::DisplayRole:
@@ -250,8 +260,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
            ) {
             if (iRole == Qt::UserRole) {
                 if (m_ruleTable && att == "t_action_type") {
-                    if (val == "S") return i18nc("Noun, a search", "Search");
-                    else if (val == "U") {
+                    if (val == "S") {
+                        return i18nc("Noun, a search", "Search");
+                    } else if (val == "U") {
                         return i18nc("Noun, a modification", "Update");
                     } else {
                         return i18nc("Noun, an alarm", "Alarm");
@@ -262,8 +273,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 return "";
             }
         } else if (m_interestTable && att == "t_expenditure_value_date_mode") {
-            if (val == "0") return i18nc("Noun", "Day -0");
-            else if (val == "1") {
+            if (val == "0") {
+                return i18nc("Noun", "Day -0");
+            } else if (val == "1") {
                 return i18nc("Noun", "Day -1");
             } else if (val == "2") {
                 return i18nc("Noun", "Day -2");
@@ -277,10 +289,13 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 return i18nc("Noun", "Fifteen");
             }
         } else if (m_accountTable && att == "d_reconciliationdate") {
-            if (val.isEmpty()) return i18nc("Noun", "Never");
+            if (val.isEmpty() && iRole == Qt::DisplayRole) {
+                return i18nc("Noun", "Never");
+            }
         } else if (m_interestTable && att == "t_income_value_date_mode") {
-            if (val == "0") return i18nc("Noun", "Day +0");
-            else if (val == "1") {
+            if (val == "0") {
+                return i18nc("Noun", "Day +0");
+            } else if (val == "1") {
                 return i18nc("Noun", "Day +1");
             } else if (val == "2") {
                 return i18nc("Noun", "Day +2");
@@ -300,7 +315,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                         att.endsWith(QLatin1String("_EXPENSE")) ||
                         (m_categoryTable && (att == "f_REALCURRENTAMOUNT" ||
                                              att == "f_SUMCURRENTAMOUNT"))) {
-                    if (dval == 0) return "";
+                    if (dval == 0) {
+                        return "";
+                    }
                 }
 
                 SKGServices::SKGUnitInfo unit;
@@ -313,7 +330,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                     }
                 } else {
                     unit.NbDecimal = SKGServices::stringToInt(obj->getAttribute("i_NBDEC"));
-                    if (unit.NbDecimal == 0) unit.NbDecimal = 2;
+                    if (unit.NbDecimal == 0) {
+                        unit.NbDecimal = 2;
+                    }
                     if (att != "f_QUANTITYOWNED") {
                         unit.Symbol = obj->getAttribute("t_UNIT");
                     }
@@ -321,7 +340,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 
                 // Bug 209672 vvvv
                 if (m_unitTable) {
-                    if (obj->getAttribute("t_type") == "I") unit.Symbol = ' ';
+                    if (obj->getAttribute("t_type") == "I") {
+                        unit.Symbol = ' ';
+                    }
                 }
                 // Bug 209672 ^^^
 
@@ -333,7 +354,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                     unit.NbDecimal = 2;
                 }
 
-                if (unit.Symbol.isEmpty()) unit.Symbol = ' ';
+                if (unit.Symbol.isEmpty()) {
+                    unit.Symbol = ' ';
+                }
 
                 return KGlobal::locale()->formatMoney(dval, unit.Symbol, unit.NbDecimal);
             } else {
@@ -342,7 +365,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         } else if (getAttributeType(iIndex.column()) == SKGServices::INTEGER) {
             if (m_recurrentoperationTable && att == "i_nb_times") {
                 QString t_times = obj->getAttribute("t_times");
-                if (t_times != "Y") return QChar(8734);
+                if (t_times != "Y") {
+                    return QChar(8734);
+                }
             } else if ((att == "i_number" || att == "i_NBOPERATIONS" || att == "i_SUMNBOPERATIONS") && val == "0") {
                 return "";
             }
@@ -355,13 +380,21 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         // decoration
         QString att = m_listAttibutes[iIndex.column()];
         if (att == "t_bookmarked") {
-            if (obj->getAttribute("t_bookmarked") == "Y")  return m_iconFavorite;
+            if (obj->getAttribute("t_bookmarked") == "Y") {
+                return m_iconFavorite;
+            }
         } else if (m_operationTable || m_recurrentoperationTable) {
             if (att == "t_mode") {
-                if (obj->getAttribute("t_TRANSFER") == "Y") return m_iconTransfer;
-                if (obj->getAttribute("i_group_id") != "0") return m_iconGroup;
+                if (obj->getAttribute("t_TRANSFER") == "Y") {
+                    return m_iconTransfer;
+                }
+                if (obj->getAttribute("i_group_id") != "0") {
+                    return m_iconGroup;
+                }
             } else if (att == "t_CATEGORY") {
-                if (SKGServices::stringToInt(obj->getAttribute("i_NBSUBOPERATIONS")) > 1) return m_iconSplit;
+                if (SKGServices::stringToInt(obj->getAttribute("i_NBSUBOPERATIONS")) > 1) {
+                    return m_iconSplit;
+                }
             } else if (att == "i_NBRECURRENT" && m_operationTable) {
                 if (obj->getAttribute("i_NBRECURRENT") != "0") {
                     return m_iconRecurrentMaster;
@@ -370,8 +403,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 }
             } else if (att == "t_imported") {
                 QString impStatus = obj->getAttribute("t_imported");
-                if (impStatus == "Y") return m_iconImported;
-                else if (impStatus == "P") {
+                if (impStatus == "Y") {
+                    return m_iconImported;
+                } else if (impStatus == "P") {
                     return m_iconImportedChecked;
                 }
             } else if (att == "t_REFUND" || att == "t_REALREFUND") {
@@ -382,14 +416,17 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                     tracker.setName(trackerName);
                     tracker.load();
 
-                    if (tracker.isClosed()) return m_iconClosed;
+                    if (tracker.isClosed()) {
+                        return m_iconClosed;
+                    }
                 }
             }
         } else if (m_ruleTable) {
             if (att == "t_action_type") {
                 QString val = obj->getAttribute(att);
-                if (val == "S") return m_iconSearch;
-                else if (val == "U") {
+                if (val == "S") {
+                    return m_iconSearch;
+                } else if (val == "U") {
                     return m_iconUpdate;
                 } else {
                     return m_iconAlarm;
@@ -399,8 +436,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             if (att == "f_CURRENTAMOUNT") {
                 SKGUnitObject unit(*obj);
                 double annualchange = 365 * unit.getDailyChange();
-                if (annualchange >= 15) return m_iconMuchMore;
-                else if (annualchange <= -15) {
+                if (annualchange >= 15) {
+                    return m_iconMuchMore;
+                } else if (annualchange <= -15) {
                     return m_iconMuchLess;
                 } else if (annualchange >= 5) {
                     return m_iconMore;
@@ -411,7 +449,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         } else if (m_accountTable) {
             if (att == "t_BANK") {
                 QString t_icon = obj->getAttribute("t_icon");
-                if (t_icon.isEmpty()) t_icon = obj->getAttribute("t_ICON");
+                if (t_icon.isEmpty()) {
+                    t_icon = obj->getAttribute("t_ICON");
+                }
                 if (!t_icon.isEmpty()) {
                     QDir dirLogo(KStandardDirs::locate("data", QString::fromLatin1("skrooge/images/logo/")));
                     return qVariantFromValue(QIcon(dirLogo.absoluteFilePath(t_icon)));
@@ -420,8 +460,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 #if 0
             else if (att == "t_TYPENLS") {
                 QString type = obj->getAttribute("t_type");
-                if (type == "C") return KIcon("view-bank-account-savings");
-                else if (type == "D")  {
+                if (type == "C") {
+                    return KIcon("view-bank-account-savings");
+                } else if (type == "D")  {
                     return KIcon("view-credit-card-account");
                 } else if (type == "I")  {
                     return KIcon("view-stock-account");
@@ -437,8 +478,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         } else if (m_categoryTable) {
             if (iIndex.column() == 0) {
                 QString t_TYPEEXPENSE = obj->getAttribute("t_TYPEEXPENSE");
-                if (t_TYPEEXPENSE == "-") return m_iconCategoryMoins;
-                else if (t_TYPEEXPENSE == "+") {
+                if (t_TYPEEXPENSE == "-") {
+                    return m_iconCategoryMoins;
+                } else if (t_TYPEEXPENSE == "+") {
                     return m_iconCategoryPlus;
                 }
                 return m_iconCategory;
@@ -452,8 +494,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                     return m_iconGreen;
                 } else {
                     double transferred = SKGServices::stringToDouble(obj->getAttribute("f_transferred"));
-                    if (transferred < -EPSILON) return m_iconAnber;
-                    else {
+                    if (transferred < -EPSILON) {
+                        return m_iconAnber;
+                    } else {
                         return m_iconGreen;
                     }
                 }
@@ -465,15 +508,18 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         // Text color
         QString att = m_listAttibutes[iIndex.column()];
         if (m_recurrentoperationTable) {
-            if (obj->getAttribute("i_nb_times") == "0") return  m_fontDisabledScheduleColor;
-            else if (att == "d_date" && SKGServices::stringToTime(obj->getAttribute("d_date")).date() <= QDate::currentDate()) {
+            if (obj->getAttribute("i_nb_times") == "0") {
+                return  m_fontDisabledScheduleColor;
+            } else if (att == "d_date" && SKGServices::stringToTime(obj->getAttribute("d_date")).date() <= QDate::currentDate()) {
                 return m_fontNegativeColor;
             }
         } else if (m_operationTable) {
-            if (SKGServices::stringToTime(obj->getAttribute("d_date")).date() > QDate::currentDate()) return m_fontFutureOperationsColor;
-            else if (getAttributeType(iIndex.column()) != SKGServices::FLOAT) {
-                if (obj->getAttribute("t_imported") == "P") return  m_fontNotValidatedOperationsColor;
-                else if (m_suboperationTable) {
+            if (SKGServices::stringToTime(obj->getAttribute("d_date")).date() > QDate::currentDate()) {
+                return m_fontFutureOperationsColor;
+            } else if (getAttributeType(iIndex.column()) != SKGServices::FLOAT) {
+                if (obj->getAttribute("t_imported") == "P") {
+                    return  m_fontNotValidatedOperationsColor;
+                } else if (m_suboperationTable) {
                     return m_fontSubOperationsColor;
                 }
             }
@@ -496,64 +542,74 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
         QString att = m_listAttibutes[iIndex.column()];
         if (m_operationTable && att == "t_status") {
             QString cond = obj->getAttribute("t_status");
-            if (cond == "P") return Qt::PartiallyChecked;
-            else if (cond == "Y") {
+            if (cond == "P") {
+                return Qt::PartiallyChecked;
+            } else if (cond == "Y") {
                 return Qt::Checked;
             } else if (cond == "N") {
                 return Qt::Unchecked;
             }
         } else if (att == "t_close") {
             QString cond = obj->getAttribute("t_close");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_recurrentoperationTable && att == "i_auto_write_days") {
             QString cond = obj->getAttribute("t_auto_write");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_recurrentoperationTable && att == "i_warn_days") {
             QString cond = obj->getAttribute("t_warn");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_recurrentoperationTable && att == "i_nb_times") {
             QString cond = obj->getAttribute("t_times");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_budgetRuleTable && att == "t_CATEGORYCONDITION") {
             QString cond = obj->getAttribute("t_category_condition");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_budgetRuleTable && att == "i_year") {
             QString cond = obj->getAttribute("t_year_condition");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_budgetRuleTable && att == "i_month") {
             QString cond = obj->getAttribute("t_month_condition");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_budgetRuleTable && att == "t_CATEGORY") {
             QString cond = obj->getAttribute("t_category_target");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         } else  if (m_budgetTable && att == "t_CATEGORY") {
             QString cond = obj->getAttribute("t_including_subcategories");
-            if (cond == "Y") return Qt::Checked;
-            else {
+            if (cond == "Y") {
+                return Qt::Checked;
+            } else {
                 return Qt::Unchecked;
             }
         }
@@ -570,7 +626,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 if (!secondaryUnit.Symbol.isEmpty()) {
                     double val = SKGServices::stringToDouble(obj->getAttribute(att));
                     if ((!att.endsWith(QLatin1String("_INCOME")) && !att.endsWith(QLatin1String("_EXPENSE"))) || val != 0) {
-                        if (secondaryUnit.Value)  toolTipString = KGlobal::locale()->formatMoney(val / secondaryUnit.Value, secondaryUnit.Symbol, secondaryUnit.NbDecimal);
+                        if (secondaryUnit.Value) {
+                            toolTipString = KGlobal::locale()->formatMoney(val / secondaryUnit.Value, secondaryUnit.Symbol, secondaryUnit.NbDecimal);
+                        }
                     }
                 }
             }
@@ -578,7 +636,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             // Add original amount
             QString originalAmount = obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
             if (!originalAmount.isEmpty()) {
-                if (!toolTipString.isEmpty()) toolTipString += "\n\n";
+                if (!toolTipString.isEmpty()) {
+                    toolTipString += "\n\n";
+                }
                 double val1 = SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
                 double val2 = SKGServices::stringToDouble(originalAmount);
                 double gain = (val2 != 0 ? 100.0 * (val1 - val2) / val2 : 0);
@@ -592,7 +652,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             if (m_operationTable) {
                 SKGOperationObject op(*obj);
                 if (!op.isTemplate()) {
-                    if (!toolTipString.isEmpty()) toolTipString += "\n\n";
+                    if (!toolTipString.isEmpty()) {
+                        toolTipString += "\n\n";
+                    }
                     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     toolTipString += i18nc("Noun", "Account balance=%1",
                                            KGlobal::locale()->formatMoney(op.getBalance(), primaryUnit.Symbol, primaryUnit.NbDecimal));
@@ -603,7 +665,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 if (att == "f_DELTA") {
                     double val = SKGServices::stringToDouble(obj->getAttribute("f_DELTABEFORETRANSFER"));
 
-                    if (!toolTipString.isEmpty()) toolTipString += "\n\n";
+                    if (!toolTipString.isEmpty()) {
+                        toolTipString += "\n\n";
+                    }
 
                     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     toolTipString += i18nc("Noun", "Original delta=%1",
@@ -620,7 +684,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 toolTipString = op.getImportID();
             } else if (att == "t_REFUND" || att == "t_REALREFUND") {
                 QString trackerName;
-                if (obj) trackerName = obj->getAttribute(att);
+                if (obj) {
+                    trackerName = obj->getAttribute(att);
+                }
                 if (!trackerName.isEmpty()) {
                     SKGTrackerObject tracker(SKGObjectBase(getDocument(), "v_refund"));
                     tracker.setName(trackerName);
@@ -684,8 +750,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             }
         } else if (m_ruleTable && att == "t_action_type") {
             QString val = obj->getAttribute(att);
-            if (val == "S") toolTipString = i18nc("Noun, a search", "Search");
-            else if (val == "U") {
+            if (val == "S") {
+                toolTipString = i18nc("Noun, a search", "Search");
+            } else if (val == "U") {
                 toolTipString = i18nc("Noun, a modification", "Update");
             } else {
                 toolTipString = i18nc("Noun, an alarm", "Alarm");
@@ -694,7 +761,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 
         QString toolTipStringBase = SKGObjectModelBase::data(iIndex, iRole).toString();
         if (!toolTipStringBase.isEmpty()) {
-            if (!toolTipString.isEmpty()) toolTipString += "\n\n";
+            if (!toolTipString.isEmpty()) {
+                toolTipString += "\n\n";
+            }
             toolTipString += toolTipStringBase;
         }
         return toolTipString;
@@ -707,7 +776,9 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
 
 bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue, int iRole)
 {
-    if (!iIndex.isValid()) return false;
+    if (!iIndex.isValid()) {
+        return false;
+    }
 
     if (iRole == Qt::CheckStateRole) {
         SKGError err;
@@ -716,7 +787,9 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
                 SKGAccountObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
                                          (static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
-                if (abs(obj.getCurrentAmount()) > 0.01) err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
+                if (abs(obj.getCurrentAmount()) > 0.01) {
+                    err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
+                }
                 IFOKDO(err, obj.setClosed(static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked))
                 IFOKDO(err, obj.save())
             } else if (m_trackerTable) {
@@ -815,18 +888,21 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
 
 Qt::ItemFlags SKGObjectModel::flags(const QModelIndex& iIndex) const
 {
-    _SKGTRACEIN(10, "SKGObjectModel::flags");
+    _SKGTRACEINFUNC(10);
 
     Qt::ItemFlags f = SKGObjectModelBase::flags(iIndex);
 
     if (iIndex.isValid()) {
         QString att = m_listAttibutes[iIndex.column()];
-        if (att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable || m_interestTable || m_interestResultTable) f = f & ~Qt::ItemIsEditable;
+        if (att == "t_bookmarked" || m_ruleTable || m_recurrentoperationTable || m_interestTable || m_interestResultTable) {
+            f = f & ~Qt::ItemIsEditable;
+        }
     }
 
     if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
-        if (iIndex.isValid()) f |= Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
-        else {
+        if (iIndex.isValid()) {
+            f |= Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
+        } else {
             f |= Qt::ItemIsDropEnabled;
         }
     }
@@ -836,13 +912,17 @@ Qt::ItemFlags SKGObjectModel::flags(const QModelIndex& iIndex) const
 
 Qt::DropActions SKGObjectModel::supportedDragActions() const
 {
-    if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) return Qt::MoveAction;
+    if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
+        return Qt::MoveAction;
+    }
     return SKGObjectModelBase::supportedDragActions();
 }
 
 Qt::DropActions SKGObjectModel::supportedDropActions() const
 {
-    if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) return Qt::MoveAction;
+    if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
+        return Qt::MoveAction;
+    }
     return SKGObjectModelBase::supportedDropActions();
 }
 
@@ -851,15 +931,22 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
                                   int iRow, int iColumn,
                                   const QModelIndex& iParent)
 {
-    if (SKGObjectModelBase::dropMimeData(iData, iAction, iRow, iColumn, iParent)) return true;
-    if (iAction == Qt::IgnoreAction) return true;
+    if (SKGObjectModelBase::dropMimeData(iData, iAction, iRow, iColumn, iParent)) {
+        return true;
+    }
+    if (iAction == Qt::IgnoreAction) {
+        return true;
+    }
     if (!iData || !(iData->hasFormat("application/skg.category.ids") ||
                     iData->hasFormat("application/skg.payee.ids") ||
                     iData->hasFormat("application/skg.account.ids") ||
                     iData->hasFormat("application/skg.refund.ids") ||
-                    iData->hasFormat("application/skg.unit.ids")
-                   )) return false;
-    if (iColumn > 0) return false;
+                    iData->hasFormat("application/skg.unit.ids"))) {
+        return false;
+    }
+    if (iColumn > 0) {
+        return false;
+    }
 
     SKGError err;
     if (iData->hasFormat("application/skg.category.ids")) {
@@ -868,7 +955,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
         QStringList newItems;
 
         SKGCategoryObject parentCategory;
-        if (iParent.isValid()) parentCategory = getObject(iParent);
+        if (iParent.isValid()) {
+            parentCategory = getObject(iParent);
+        }
         {
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Move category"), err);
 
@@ -881,8 +970,9 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
                 SKGCategoryObject child(getDocument(), o_id);
                 err = child.load();
                 IFOK(err) {
-                    if (iParent.isValid()) err = child.setParentCategory(parentCategory);
-                    else {
+                    if (iParent.isValid()) {
+                        err = child.setParentCategory(parentCategory);
+                    } else {
                         err = child.removeParentCategory();
                     }
                 }
@@ -973,7 +1063,7 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
 void SKGObjectModel::dataModified(const QString& iTableName, int iIdTransaction)
 {
     if (getRealTable() == iTableName || iTableName.isEmpty() || getRealTable() == "doctransaction") {
-        SKGTRACEIN(1, "SKGObjectModel::dataModified");
+        SKGTRACEINFUNC(1);
         if (iTableName == "category") {
             // Full refresh
             m_isResetRealyNeeded = true;
