@@ -38,7 +38,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     : QWidget(iParent), m_updateMode(iModeUpdate), m_kValue1(NULL), m_kValue2(NULL), m_kAttributes(NULL)
 {
     SKGServices::AttributeType attType = SKGServices::TEXT;
-    if (document) attType = document->getAttributeType(attribute);
+    if (document) {
+        attType = document->getAttributeType(attribute);
+    }
 
     // Build
     this->setAutoFillBackground(true);
@@ -73,7 +75,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             horizontalLayout->addWidget(m_kAttributes);
 
             foreach(const QString & att, iListAtt) {
-                if (document) m_kAttributes->addItem(document->getIcon(att), document->getDisplay(att), att);
+                if (document) {
+                    m_kAttributes->addItem(document->getIcon(att), document->getDisplay(att), att);
+                }
             }
         }
     }
@@ -224,14 +228,24 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     m_kOperator->clear();
     m_kOperator->addItem("" , "");
 
-    if (m_kValue1) m_kValue1->installEventFilter(this);
-    if (m_kValue2) m_kValue2->installEventFilter(this);
-    if (m_kOperator) m_kOperator->installEventFilter(this);
-    if (m_kAttributes) m_kAttributes->installEventFilter(this);
+    if (m_kValue1) {
+        m_kValue1->installEventFilter(this);
+    }
+    if (m_kValue2) {
+        m_kValue2->installEventFilter(this);
+    }
+    if (m_kOperator) {
+        m_kOperator->installEventFilter(this);
+    }
+    if (m_kAttributes) {
+        m_kAttributes->installEventFilter(this);
+    }
 
     QStringList listOps = SKGRuleObject::getListOfOperators(attType, m_updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH);
     int nb = listOps.count();
-    if (iModeUpdate && attribute == "t_REALCATEGORY" && nb > 1) nb = 1;  // TODO(Stephane MANKOWSKI): unblock t_REALCATEGORY
+    if (iModeUpdate && attribute == "t_REALCATEGORY" && nb > 1) {
+        nb = 1;    // TODO(Stephane MANKOWSKI): unblock t_REALCATEGORY
+    }
     for (int i = 0; i < nb; ++i) {
         QString op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
@@ -261,10 +275,14 @@ bool SKGPredicatCreator::eventFilter(QObject* iObject, QEvent* iEvent)
         QObject* appliFocus = QApplication::focusWidget();
 
         while (appliFocus) {
-            if (appliFocus == this) break;
+            if (appliFocus == this) {
+                break;
+            }
             appliFocus = appliFocus->parent();
         }
-        if (!appliFocus) Q_EMIT editingFinished();
+        if (!appliFocus) {
+            Q_EMIT editingFinished();
+        }
     }
     return false;
 }
@@ -272,10 +290,18 @@ bool SKGPredicatCreator::eventFilter(QObject* iObject, QEvent* iEvent)
 void SKGPredicatCreator::onOperatorChanged()
 {
     QString req;
-    if (m_kOperator) req = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
-    if (m_kValue1) m_kValue1->setVisible(req.contains("#V1S#") || req.contains("#V1#"));
-    if (m_kValue2) m_kValue2->setVisible(req.contains("#V2S#") || req.contains("#V2#") || req.contains("#DF#"));
-    if (m_kAttributes) m_kAttributes->setVisible(req.contains("#ATT2#"));
+    if (m_kOperator) {
+        req = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
+    }
+    if (m_kValue1) {
+        m_kValue1->setVisible(req.contains("#V1S#") || req.contains("#V1#"));
+    }
+    if (m_kValue2) {
+        m_kValue2->setVisible(req.contains("#V2S#") || req.contains("#V2#") || req.contains("#DF#"));
+    }
+    if (m_kAttributes) {
+        m_kAttributes->setVisible(req.contains("#ATT2#"));
+    }
 }
 
 QString SKGPredicatCreator::text()
@@ -309,29 +335,38 @@ QString SKGPredicatCreator::xmlDescription()
             root.setAttribute("operator", op);
             if (m_kValue1 && m_kValue1->isVisible()) {
                 SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
-                if (cmbVal1)  root.setAttribute("value", SKGServices::dateToSqlString(QDateTime(cmbVal1->date())));
-                else {
+                if (cmbVal1) {
+                    root.setAttribute("value", SKGServices::dateToSqlString(QDateTime(cmbVal1->date())));
+                } else {
                     SKGCalculatorEdit* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
-                    if (cmbVal12)  root.setAttribute("value", cmbVal12->text());
-                    else {
+                    if (cmbVal12) {
+                        root.setAttribute("value", cmbVal12->text());
+                    } else {
                         QCheckBox* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
-                        if (cmbVal13)  root.setAttribute("value", cmbVal13->checkState() == Qt::Checked ? "Y" : cmbVal13->checkState() == Qt::Unchecked ? "N" : "P");
-                        else {
+                        if (cmbVal13) {
+                            root.setAttribute("value", cmbVal13->checkState() == Qt::Checked ? "Y" : cmbVal13->checkState() == Qt::Unchecked ? "N" : "P");
+                        } else {
                             SKGComboBox* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
-                            if (cmbVal14) root.setAttribute("value", cmbVal14->text());
+                            if (cmbVal14) {
+                                root.setAttribute("value", cmbVal14->text());
+                            }
                         }
                     }
                 }
             }
             if (m_kValue2 && m_kValue2->isVisible()) {
                 SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
-                if (cmbVal2)  root.setAttribute("value2", SKGServices::dateToSqlString(QDateTime(cmbVal2->date())));
-                else {
+                if (cmbVal2) {
+                    root.setAttribute("value2", SKGServices::dateToSqlString(QDateTime(cmbVal2->date())));
+                } else {
                     SKGCalculatorEdit* cmbVal21 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
-                    if (cmbVal21)  root.setAttribute("value2", cmbVal21->text());
-                    else {
+                    if (cmbVal21) {
+                        root.setAttribute("value2", cmbVal21->text());
+                    } else {
                         SKGComboBox* cmbVal22 = qobject_cast<SKGComboBox*> (m_kValue2);
-                        if (cmbVal22)  root.setAttribute("value2", cmbVal22->text());
+                        if (cmbVal22) {
+                            root.setAttribute("value2", cmbVal22->text());
+                        }
                     }
                 }
             }
@@ -357,28 +392,37 @@ void SKGPredicatCreator::setXmlDescription(const QString& iXML)
     if (m_kOperator) {
         m_kOperator->setCurrentIndex(m_kOperator->findData(root.attribute("operator")));
         SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
-        if (cmbVal1)  cmbVal1->setDate(SKGServices::stringToTime(root.attribute("value")).date());
-        else {
+        if (cmbVal1) {
+            cmbVal1->setDate(SKGServices::stringToTime(root.attribute("value")).date());
+        } else {
             SKGCalculatorEdit* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
-            if (cmbVal12)  cmbVal12->setText(root.attribute("value"));
-            else {
+            if (cmbVal12) {
+                cmbVal12->setText(root.attribute("value"));
+            } else {
                 QCheckBox* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
-                if (cmbVal13)  cmbVal13->setCheckState(root.attribute("value") == "Y" ? Qt::Checked : root.attribute("value") == "P" ? Qt::PartiallyChecked : Qt::Unchecked);
-                else {
+                if (cmbVal13) {
+                    cmbVal13->setCheckState(root.attribute("value") == "Y" ? Qt::Checked : root.attribute("value") == "P" ? Qt::PartiallyChecked : Qt::Unchecked);
+                } else {
                     SKGComboBox* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
-                    if (cmbVal14)  cmbVal14->setText(root.attribute("value"));
+                    if (cmbVal14) {
+                        cmbVal14->setText(root.attribute("value"));
+                    }
                 }
             }
         }
 
         SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
-        if (cmbVal2)  cmbVal2->setDate(SKGServices::stringToTime(root.attribute("value2")).date());
-        else {
+        if (cmbVal2) {
+            cmbVal2->setDate(SKGServices::stringToTime(root.attribute("value2")).date());
+        } else {
             SKGCalculatorEdit* cmbVal22 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
-            if (cmbVal22)  cmbVal22->setText(root.attribute("value2"));
-            else {
+            if (cmbVal22) {
+                cmbVal22->setText(root.attribute("value2"));
+            } else {
                 SKGComboBox* cmbVal23 = qobject_cast<SKGComboBox*> (m_kValue2);
-                if (cmbVal23) cmbVal23->setText(root.attribute("value2"));
+                if (cmbVal23) {
+                    cmbVal23->setText(root.attribute("value2"));
+                }
             }
         }
 
