@@ -67,7 +67,7 @@ const SKGAccountObject& SKGAccountObject::operator= (const SKGObjectBase& iObjec
 SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObject& iUnit)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGAccountObject::setInitialBalance", err);
+    SKGTRACEINFUNCRC(10, err);
     if (getDocument()) {
         // Delete previous initial balance for this account
         err = getDocument()->executeSqliteOrder("DELETE FROM operation  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()));
@@ -83,6 +83,7 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
 
             SKGSubOperationObject initialBalanceSubOp;
             IFOKDO(err, initialBalanceOp.addSubOperation(initialBalanceSubOp))
+            IFOKDO(err, initialBalanceSubOp.setAttribute("d_date", "0000-00-00"))
             IFOKDO(err, initialBalanceSubOp.setQuantity(iBalance))
             IFOKDO(err, initialBalanceSubOp.save())
         }
@@ -93,7 +94,7 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
 SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oUnit)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGAccountObject::getInitialBalance", err);
+    SKGTRACEINFUNCRC(10, err);
     // Initialisation
     oBalance = 0;
     oUnit = SKGUnitObject();
@@ -167,8 +168,9 @@ QString SKGAccountObject::getAgencyAddress() const
 SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation, bool iForce)
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addOperation")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addOperation")));
+    } else {
         oOperation = SKGOperationObject(getDocument());
         err = oOperation.setParentAccount(*this, iForce);
     }
@@ -178,7 +180,9 @@ SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation, bool iFo
 int SKGAccountObject::getNbOperation() const
 {
     int nb = 0;
-    if (getDocument()) getDocument()->getNbObjects("operation", "rd_account_id=" % SKGServices::intToString(getID()), nb);
+    if (getDocument()) {
+        getDocument()->getNbObjects("operation", "rd_account_id=" % SKGServices::intToString(getID()), nb);
+    }
     return nb;
 }
 
@@ -200,7 +204,7 @@ double SKGAccountObject::getCurrentAmount() const
 
 double SKGAccountObject::getAmount(const QDate& iDate, bool iOnlyCurrencies) const
 {
-    SKGTRACEIN(10, "SKGAccountObject::getAmount");
+    SKGTRACEINFUNC(10);
     double output = 0;
     if (getDocument()) {
         // Search result in cache
@@ -228,7 +232,9 @@ double SKGAccountObject::getAmount(const QDate& iDate, bool iOnlyCurrencies) con
                 } else {
                     // No
                     SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
-                    if (unit.getType() != SKGUnitObject::PRIMARY) coef = unit.getAmount(iDate);
+                    if (unit.getType() != SKGUnitObject::PRIMARY) {
+                        coef = unit.getAmount(iDate);
+                    }
                 }
 
                 output += coef * SKGServices::stringToDouble(quantity);
@@ -300,7 +306,9 @@ bool SKGAccountObject::isMaxLimitAmountEnabled() const
 SKGError SKGAccountObject::setMaxLimitAmount(double iAmount)
 {
     SKGError err = setAttribute("f_maxamount", SKGServices::doubleToString(iAmount));
-    if (!err && getMinLimitAmount() > iAmount) err = setMinLimitAmount(iAmount);
+    if (!err && getMinLimitAmount() > iAmount) {
+        err = setMinLimitAmount(iAmount);
+    }
     return err;
 }
 
@@ -322,7 +330,9 @@ bool SKGAccountObject::isMinLimitAmountEnabled() const
 SKGError SKGAccountObject::setMinLimitAmount(double iAmount)
 {
     SKGError err = setAttribute("f_minamount", SKGServices::doubleToString(iAmount));
-    if (!err && getMaxLimitAmount() < iAmount) err = setMaxLimitAmount(iAmount);
+    if (!err && getMaxLimitAmount() < iAmount) {
+        err = setMaxLimitAmount(iAmount);
+    }
     return err;
 }
 
@@ -359,7 +369,9 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
             err = getDocument()->getObjects("v_unit",
                                             "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id=" % SKGServices::intToString(getID()) % ") ORDER BY t_type", units);
             int nb = units.count();
-            if (nb) oUnit = units.at(0);
+            if (nb) {
+                oUnit = units.at(0);
+            }
         }
     }
     return err;
@@ -368,8 +380,9 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
 SKGError SKGAccountObject::addInterest(SKGInterestObject& oInterest)
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addInterest")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGAccountObject::addInterest")));
+    } else {
         oInterest = SKGInterestObject(static_cast<SKGDocumentBank*>(getDocument()));
         err = oInterest.setAccount(*this);
     }
@@ -411,7 +424,9 @@ SKGError SKGAccountObject::getInterestItems(QList<SKGAccountObject::SKGInterestI
 
     // Initial date
     int y = iYear;
-    if (y == 0) y = QDate::currentDate().year();
+    if (y == 0) {
+        y = QDate::currentDate().year();
+    }
     QDate initialDate = QDate(y, 1, 1);
     QDate lastDate = QDate(y, 12, 31);
 
@@ -523,7 +538,9 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
 
     // Initial date
     int y = iYear;
-    if (y == 0) y = QDate::currentDate().year();
+    if (y == 0) {
+        y = QDate::currentDate().year();
+    }
     QDate initialDate = QDate(y, 1, 1);
 
     // Default interest item
@@ -561,13 +578,15 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
             if (object.getRealTable() == "operation") {
                 if (valueMode == SKGInterestObject::FIFTEEN) {
                     if (tmp.amount >= 0) {
-                        if (tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
-                        else {
+                        if (tmp.date.day() <= 15) {
+                            tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
+                        } else {
                             tmp.valueDate = tmp.date.addMonths(1).addDays(1 - tmp.date.day());
                         }
                     } else {
-                        if (tmp.date.day() <= 15) tmp.valueDate = tmp.date.addDays(1 - tmp.date.day());
-                        else {
+                        if (tmp.date.day() <= 15) {
+                            tmp.valueDate = tmp.date.addDays(1 - tmp.date.day());
+                        } else {
                             tmp.valueDate = tmp.date.addDays(16 - tmp.date.day());
                         }
                     }
@@ -589,7 +608,9 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                 tmp.coef = 2 * (12 - tmp.valueDate.month()) + (tmp.valueDate.day() <= 15 ? 2 : 1);
                 tmp.coef /= 24;
             }
-            if (tmp.valueDate.year() != iYear) tmp.coef = 0;
+            if (tmp.valueDate.year() != iYear) {
+                tmp.coef = 0;
+            }
 
             // Compute annual interest
             tmp.annualInterest = tmp.amount * tmp.coef * tmp.rate / 100;
@@ -608,10 +629,13 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
                 tmp.coef = 2 * (12 - tmp.valueDate.month()) + (tmp.valueDate.day() <= 15 ? 2 : 1);
                 tmp.coef /= 24;
             }
-            if (tmp.valueDate.year() != iYear) tmp.coef = 0;
+            if (tmp.valueDate.year() != iYear) {
+                tmp.coef = 0;
+            }
 
             // Compute annual interest
-            tmp.amount = getAmount(tmp.valueDate, true);
+            // BUG 329568: We must ignore operations of the day
+            tmp.amount = getAmount(tmp.valueDate.addDays(-1), true);
             tmp.annualInterest = tmp.amount * tmp.coef * (tmp.rate - currentInterest.rate) / 100;
 
             currentInterest = tmp;
@@ -669,7 +693,7 @@ SKGError SKGAccountObject::computeInterestItems(QList<SKGAccountObject::SKGInter
 SKGError SKGAccountObject::autoReconcile(double iBalance)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGAccountObject::autoReconcile", err);
+    SKGTRACEINFUNCRC(10, err);
     //
     SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc) {
@@ -689,7 +713,9 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         err = getDocument()->executeSelectSqliteOrder(
                   "SELECT TOTAL(f_CHECKED) from v_account_display WHERE id=" % SKGServices::intToString(getID()),
                   listTmp2);
-        if (listTmp2.count() == 2) balance = SKGServices::stringToDouble(listTmp2.at(1).at(0)) / unit1.Value;
+        if (listTmp2.count() == 2) {
+            balance = SKGServices::stringToDouble(listTmp2.at(1).at(0)) / unit1.Value;
+        }
 
 
         // Get all imported operation
@@ -742,7 +768,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
 SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGAccountObject::merge", err);
+    SKGTRACEINFUNCRC(10, err);
 
     // Get initial balances
     double balance1;
@@ -765,7 +791,9 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
 
     // Set initial balance
     SKGUnitObject unit = unit1;
-    if (!unit1.exist()) unit = unit2;
+    if (!unit1.exist()) {
+        unit = unit2;
+    }
     if (unit.exist()) {
         double balance = balance1 + SKGUnitObject::convert(balance2, unit2, unit);
         IFOKDO(err, setInitialBalance(balance, unit))
