@@ -176,21 +176,21 @@ public Q_SLOTS:
 
     /**
      * Get main categorys report
-     * @param iMonth the month
+     * @param iPeriod the period
      * @param iNb number of categories
      * @return the report
      */
-    virtual QVariantList getMainCategories(const QString& iMonth, int iNb = 5);
+    virtual QVariantList getMainCategories(const QString& iPeriod, int iNb = 5);
 
     /**
      * Get 5 main variation of categories report
-     * @param iMonth the month
-     * @param iPreviousMonth the previous month
+     * @param iPeriod the period
+     * @param iPreviousPeriod the previous period
      * @param iOnlyIssues only "Expenses increased" and "Incomes decreased"
      * @param oCategoryList to get the category for each variation
      * @return the list of variation string
      */
-    virtual QStringList get5MainCategoriesVariationList(const QString& iMonth, const QString& iPreviousMonth, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
+    virtual QStringList get5MainCategoriesVariationList(const QString& iPeriod, const QString& iPreviousPeriod, bool iOnlyIssues = false, QStringList* oCategoryList = NULL);
 
     /**
      * Enable/disable balances computation
