@@ -60,7 +60,9 @@ SKGImportExportManager::~SKGImportExportManager()
     m_importPlugin = NULL;
     m_exportPlugin = NULL;
 
-    if (!m_localFileName.isEmpty() && m_localFileName != getFileName().toLocalFile()) QFile(m_localFileName).remove();
+    if (!m_localFileName.isEmpty() && m_localFileName != getFileName().toLocalFile()) {
+        QFile(m_localFileName).remove();
+    }
 }
 
 QString SKGImportExportManager::getFileNameExtension() const
@@ -76,10 +78,12 @@ KUrl SKGImportExportManager::getFileName() const
 QString SKGImportExportManager::getLocalFileName(bool iDownload)
 {
     if (m_localFileName.isEmpty()) {
-        if (getFileName().isLocalFile()) m_localFileName = getFileName().toLocalFile();
-        else {
-            if (iDownload) SKGServices::download(KUrl(getFileName()), m_localFileName);
-            else {
+        if (getFileName().isLocalFile()) {
+            m_localFileName = getFileName().toLocalFile();
+        } else {
+            if (iDownload) {
+                SKGServices::download(KUrl(getFileName()), m_localFileName);
+            } else {
                 QTemporaryFile tmpFile;
                 tmpFile.setAutoRemove(false);
                 tmpFile.open();
@@ -93,25 +97,28 @@ QString SKGImportExportManager::getLocalFileName(bool iDownload)
 SKGError SKGImportExportManager::setDefaultAccount(SKGAccountObject* iAccount)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::setDefaultAccount", err);
+    SKGTRACEINFUNCRC(10, err);
     delete m_defaultAccount;
     m_defaultAccount = NULL;
-    if (iAccount) m_defaultAccount = new SKGAccountObject(*iAccount);
+    if (iAccount) {
+        m_defaultAccount = new SKGAccountObject(*iAccount);
+    }
     return err;
 }
 
 SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::getDefaultAccount", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_defaultAccount == NULL && m_document) {
         QFileInfo fInfo(getLocalFileName());
         QStringList items = fInfo.baseName().split('@');
         QString bankname;
         QString number;
         QString name = items.at(0);
-        if (items.count() == 2) bankname = items.at(1);
-        else {
+        if (items.count() == 2) {
+            bankname = items.at(1);
+        } else {
             bankname = name;
         }
         name.replace('_', ' ');
@@ -119,12 +126,16 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         QRegExp rx("(\\d{6,})");
         if (rx.indexIn(name) != -1) {
             number = rx.cap(1);
-            if (name != number) name = name.remove(number).trimmed();
+            if (name != number) {
+                name = name.remove(number).trimmed();
+            }
         }
 
         // Searching if an account exist
         QString whereClause = "t_name='" % name % '\'';
-        if (!number.isEmpty()) whereClause += " OR t_number='" % number % "'";
+        if (!number.isEmpty()) {
+            whereClause += " OR t_number='" % number % "'";
+        }
         foreach(const QString & val, name.split(' ')) {
             whereClause += " OR t_number='" % val % "'";
         }
@@ -148,17 +159,23 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
             SKGAccountObject account;
             SKGBankObject bank(m_document);
             IFOKDO(err, bank.setName(bankname))
-            if (!err && bank.load().isFailed()) err = bank.save(false);    // Save only
+            if (!err && bank.load().isFailed()) {
+                err = bank.save(false);    // Save only
+            }
             IFOKDO(err, bank.addAccount(account))
             IFOKDO(err, account.setName(name))
             IFOKDO(err, account.setNumber(number))
-            if (!err && account.load().isFailed()) err = account.save(false);    // Save only
+            if (!err && account.load().isFailed()) {
+                err = account.save(false);    // Save only
+            }
             IFOK(err) m_defaultAccount = new SKGAccountObject(account);
             IFOKDO(err, m_document->sendMessage(i18nc("An information message",  "Default account '%1' created for import", name)))
         }
     }
 
-    if (m_defaultAccount != NULL)  oAccount = *m_defaultAccount;
+    if (m_defaultAccount != NULL) {
+        oAccount = *m_defaultAccount;
+    }
 
     return err;
 }
@@ -166,17 +183,19 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
 SKGError SKGImportExportManager::setDefaultUnit(SKGUnitObject* iUnit)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::setDefaultUnit", err);
+    SKGTRACEINFUNCRC(10, err);
     delete m_defaultUnit;
     m_defaultUnit = NULL;
-    if (iUnit) m_defaultUnit = new SKGUnitObject(*iUnit);
+    if (iUnit) {
+        m_defaultUnit = new SKGUnitObject(*iUnit);
+    }
     return err;
 }
 
 SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDate* iDate)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGImportExportManager::getDefaultUnit", err);
+    SKGTRACEINFUNCRC(10, err);
     if (m_document && (m_defaultUnit == NULL || iDate)) {
         if (m_defaultUnit == NULL) {
             delete m_defaultUnit;
@@ -262,7 +281,7 @@ bool SKGImportExportManager::sinceLastImportDate() const
 SKGError SKGImportExportManager::finalizeImportation()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation", err);
+    SKGTRACEINFUNCRC(2, err);
     if (m_document && !getImportParameters().contains("donotfinalize")) {
         // Count the number of operations imported but already existing
         QString wc = "v_operation.t_imported='T' AND v_operation.t_import_id<>'' AND exists (SELECT 1 from v_operation op2 WHERE op2.t_imported!='T' AND op2.rd_account_id=v_operation.rd_account_id AND op2.t_import_id=v_operation.t_import_id AND ABS(op2.f_CURRENTAMOUNT-v_operation.f_CURRENTAMOUNT)<" % SKGServices::doubleToString(EPSILON) % ')';
@@ -276,12 +295,12 @@ SKGError SKGImportExportManager::finalizeImportation()
         }
 
         // Delete operations before the last import
-        if (m_since_last_import && !err) {
-            SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-deletebeforelastimport", err);
+        if (sinceLastImportDate() && !err) {
+            SKGTRACEINFUNCRC(2, err);
 
             // Count the number of operations before the last import
             QString wc2 = "operation.t_imported='T' AND "
-                          "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND o.d_date>operation.d_date)";
+                          "EXISTS(SELECT 1 FROM operation o INDEXED BY idx_operation_rd_account_id_t_imported WHERE o.rd_account_id=operation.rd_account_id AND o.t_imported IN ('Y', 'P') AND date(o.d_date,'-4 day')>operation.d_date)";
             int nbOperations2;
             err = m_document->getNbObjects("operation", wc2, nbOperations2);
             if (!err && nbOperations2) {
@@ -297,7 +316,7 @@ SKGError SKGImportExportManager::finalizeImportation()
 
         // Apply rules
         if (!err && m_automaticApplyRulesOfImportedOperation) {
-            SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-applyrules", err);
+            SKGTRACEINFUNCRC(2, err);
             // Get rules
             SKGObjectBase::SKGListSKGObjectBase rules;
             IFOKDO(err, m_document->getObjects("v_rule", "1=1 ORDER BY f_sortorder", rules))
@@ -318,7 +337,7 @@ SKGError SKGImportExportManager::finalizeImportation()
 
         // Change imported status
         IFOK(err) {
-            SKGTRACEINRC(2, "SKGImportExportManager::finalizeImportation-setfinalstatus", err);
+            SKGTRACEINFUNCRC(2, err);
             err = m_document->executeSqliteOrder(QString("UPDATE operation SET t_imported='") %
                                                  (m_automaticValidationOfImportedOperation ? "Y" : "P") %
                                                  "' WHERE t_imported='T'");
@@ -330,14 +349,18 @@ SKGError SKGImportExportManager::finalizeImportation()
 void SKGImportExportManager::setImportParameters(const QMap< QString, QString >& iParameters)
 {
     SKGImportPlugin* plugin = getImportPlugin();
-    if (plugin) plugin->setImportParameters(iParameters);
+    if (plugin) {
+        plugin->setImportParameters(iParameters);
+    }
 }
 
 QMap< QString, QString > SKGImportExportManager::getImportParameters()
 {
     QMap< QString, QString > output;
     SKGImportPlugin* plugin = getImportPlugin();
-    if (plugin) output = plugin->getImportParameters();
+    if (plugin) {
+        output = plugin->getImportParameters();
+    }
     return output;
 }
 
@@ -373,7 +396,9 @@ QString SKGImportExportManager::getImportMimeTypeFilter()
     QString output = regexps.join(" ") % '|' % i18nc("A file format", "All supported formats");
     nb = descriptions.count();
     for (int i = 0; i < nb; ++i) {
-        if (!output.isEmpty()) output += '\n';
+        if (!output.isEmpty()) {
+            output += '\n';
+        }
         output += tmp[descriptions.at(i)] % '|' % descriptions.at(i);
     }
 
@@ -412,7 +437,9 @@ QString SKGImportExportManager::getExportMimeTypeFilter()
     QString output = regexps.join(" ") % '|' % i18nc("A file format", "All supported formats");
     nb = descriptions.count();
     for (int i = 0; i < nb; ++i) {
-        if (!output.isEmpty()) output += '\n';
+        if (!output.isEmpty()) {
+            output += '\n';
+        }
         output += tmp[descriptions.at(i)] % '|' % descriptions.at(i);
     }
 
@@ -437,7 +464,9 @@ SKGImportPlugin* SKGImportExportManager::getImportPlugin()
                     m_importPlugin = pluginInterface;
                 }
             } else {
-                if (m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
+                if (m_document) {
+                    m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
+                }
             }
         }
     }
@@ -461,7 +490,9 @@ SKGImportPlugin* SKGImportExportManager::getExportPlugin()
                     m_exportPlugin = pluginInterface;
                 }
             } else {
-                if (m_document) m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
+                if (m_document) {
+                    m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
+                }
             }
         }
     }
@@ -471,7 +502,7 @@ SKGImportPlugin* SKGImportExportManager::getExportPlugin()
 SKGError SKGImportExportManager::importFile()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::importFile", err);
+    SKGTRACEINFUNCRC(2, err);
     if (m_document) {
         SKGBEGINPROGRESSTRANSACTION(*m_document, i18nc("Noun, name of the user action", "Import with codec %1", m_codec), err, 3);
 
@@ -491,7 +522,9 @@ SKGError SKGImportExportManager::importFile()
                 err = pluginInterface->importFile();
             }
 
-            if (!err && !fileTreated)err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This import mode is not yet implemented"));
+            if (!err && !fileTreated) {
+                err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This import mode is not yet implemented"));
+            }
         }
         IFOKDO(err, m_document->stepForward(2))
 
@@ -505,7 +538,7 @@ SKGError SKGImportExportManager::importFile()
 SKGError SKGImportExportManager::exportFile()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::exportFile", err);
+    SKGTRACEINFUNCRC(2, err);
     if (m_document) {
         err = m_document->executeSqliteOrder("ANALYZE");
         IFOK(err) {
@@ -521,7 +554,9 @@ SKGError SKGImportExportManager::exportFile()
                 IFOKDO(err, SKGServices::upload(KUrl::fromLocalFile(getLocalFileName(false)), m_fileName))
             }
 
-            if (!err && !fileTreated) err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This export mode is not yet implemented"));
+            if (!err && !fileTreated) {
+                err.setReturnCode(ERR_NOTIMPL).setMessage(i18nc("Error message",  "This export mode is not yet implemented"));
+            }
         }
     }
 
@@ -531,7 +566,7 @@ SKGError SKGImportExportManager::exportFile()
 SKGError SKGImportExportManager::cleanBankImport()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::cleanBankImport", err);
+    SKGTRACEINFUNCRC(2, err);
 
     // Begin transaction
     if (m_document) {
@@ -624,7 +659,7 @@ SKGError SKGImportExportManager::cleanBankImport()
 SKGError SKGImportExportManager::anonymize()
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::anonymize", err);
+    SKGTRACEINFUNCRC(2, err);
     if (m_document) {
         if (m_document->isFileModified()) {
             err = SKGError(ERR_ABORT, i18nc("An information message",  "The document must be saved to be anonymized."));
@@ -658,7 +693,7 @@ SKGError SKGImportExportManager::anonymize()
 SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged, bool iOnCurrentlyImport)
 {
     SKGError err;
-    SKGTRACEINRC(2, "SKGImportExportManager::findAndGroupTransfers", err);
+    SKGTRACEINFUNCRC(2, err);
 
     oNbOperationsMerged = 0;
 
