@@ -60,7 +60,9 @@ const SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase& iO
 SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDate& iDate, bool iTemplateMode) const
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGOperationObject::duplicate", err);
+    SKGTRACEINFUNCRC(20, err);
+    QDate previousDate = getDate();
+
     // Create the duplicated operation
     oOperation = SKGOperationObject(getDocument(), this->getID());  // To be sure the object is on v_operation
     IFOKDO(err, oOperation.load())
@@ -84,6 +86,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
             SKGSubOperationObject subop(subops.at(i));
             err = subop.resetID();
             IFOKDO(err, subop.setParentOperation(oOperation))
+            IFOKDO(err, subop.setDate(subop.getDate().addDays(previousDate.daysTo(iDate))))
             IFOKDO(err, subop.save(false))
         }
     }
@@ -144,11 +147,13 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount,
     SKGError err;
     QString currentAccount = getAttribute("rd_account_id");
     QString newAccount = SKGServices::intToString(iAccount.getID());
-    if (newAccount == "0") err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::setParentAccount")));
-    else {
+    if (newAccount == "0") {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::setParentAccount")));
+    } else {
         if (newAccount != currentAccount) {
-            if (iAccount.isClosed() && !iForce) err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
-            else {
+            if (iAccount.isClosed() && !iForce) {
+                err = SKGError(ERR_FAIL, i18nc("Error message",  "Impossible to add an operation in a closed account"));
+            } else {
                 err = setAttribute("rd_account_id", newAccount);
             }
         }
@@ -200,8 +205,9 @@ qlonglong SKGOperationObject::getNumber() const
 SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
 {
     QString t_status = getAttribute("t_status");
-    if (t_status == "Y") return SKGOperationObject::CHECKED;
-    else if (t_status == "P") {
+    if (t_status == "Y") {
+        return SKGOperationObject::CHECKED;
+    } else if (t_status == "P") {
         return SKGOperationObject::POINTED;
     }
     return SKGOperationObject::NONE;
@@ -212,9 +218,33 @@ SKGError SKGOperationObject::setStatus(SKGOperationObject::OperationStatus iStat
     return setAttribute("t_status", (iStatus == SKGOperationObject::CHECKED ? "Y" : (iStatus == SKGOperationObject::POINTED ? "P" : "N")));
 }
 
-SKGError SKGOperationObject::setDate(const QDate& iDate)
+SKGError SKGOperationObject::setDate(const QDate& iDate, bool iRefreshSubOperations)
 {
-    return setAttribute("d_date", SKGServices::dateToSqlString(QDateTime(iDate)));
+    SKGError err;
+    // Compute deta of the change of date
+    QDate previousDate = getDate();
+    if (iRefreshSubOperations) {
+        // Apply the detla on sub operations
+        SKGObjectBase::SKGListSKGObjectBase listSubOperations;
+        getSubOperations(listSubOperations);  // Error is not manage to avoid error in case of first creation
+        int nbSubOperations = listSubOperations.count();
+        for (int i = 0; !err && i < nbSubOperations; ++i) {
+            SKGSubOperationObject sop(listSubOperations.at(i));
+            QDate previousSubDate = sop.getDate();
+            if (previousSubDate.isValid()) {
+                if (previousDate.isValid()) {
+                    int delta = previousDate.daysTo(iDate);
+                    err = sop.setDate(previousSubDate.addDays(delta));
+                    IFOKDO(err, sop.save(true, false));
+                }
+            } else {
+                err = sop.setDate(iDate);
+                IFOKDO(err, sop.save(true, false));
+            }
+        }
+    }
+    IFOKDO(err, setAttribute("d_date", SKGServices::dateToSqlString(QDateTime(iDate))));
+    return err;
 }
 
 QDate SKGOperationObject::getDate() const
@@ -241,10 +271,12 @@ bool SKGOperationObject::isInGroup() const
 
 bool SKGOperationObject::isTransfer(SKGOperationObject& oOperation) const
 {
-    SKGTRACEIN(10, "SKGOperationObject::isTransfer")
+    SKGTRACEINFUNC(10);
     SKGObjectBase::SKGListSKGObjectBase ops;
     getGroupedOperations(ops);
-    if (ops.count() == 2) oOperation = (*this == SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
+    if (ops.count() == 2) {
+        oOperation = (*this == SKGOperationObject(ops.at(0)) ? ops.at(1) : ops.at(0));
+    }
     return (getAttribute("t_TRANSFER") == "Y");
 }
 
@@ -252,8 +284,9 @@ SKGError SKGOperationObject::getGroupedOperations(SKGListSKGObjectBase& oGrouped
 {
     SKGError err;
     QString gpId1 = getAttribute("i_group_id");
-    if (gpId1 == "0") oGroupedOperations.clear();
-    else {
+    if (gpId1 == "0") {
+        oGroupedOperations.clear();
+    } else {
         err = getDocument()->getObjects("v_operation", "i_group_id=" % gpId1, oGroupedOperations);
     }
     return err;
@@ -268,7 +301,7 @@ SKGError SKGOperationObject::getGroupOperation(SKGOperationObject& oOperation) c
 SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperation)
 {
     SKGError err;
-    SKGTRACEINRC(20, "SKGOperationObject::setGroupOperation", err);
+    SKGTRACEINFUNCRC(20, err);
 
     // Is it a remove group ?
     if (iOperation == *this) {
@@ -297,10 +330,14 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
             IFOKDO(err, setAttribute("i_group_id", newIdGroup))
 
             // Update all objects of group2
-            if (!err && !group1.isEmpty() && group1 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group1);
+            if (!err && !group1.isEmpty() && group1 != "0") {
+                err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group1);
+            }
 
             // Update all objects of group2
-            if (!err && !group1.isEmpty() && group2 != "0") err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group2);
+            if (!err && !group1.isEmpty() && group2 != "0") {
+                err = getDocument()->executeSqliteOrder("UPDATE operation SET i_group_id=" % newIdGroup % " WHERE i_group_id=" % group2);
+            }
         }
     }
 
@@ -330,7 +367,9 @@ bool SKGOperationObject::isImported() const
 SKGError SKGOperationObject::setImportID(const QString& iImportID)
 {
     SKGError err = setAttribute("t_import_id", iImportID);
-    if (!err && !iImportID.isEmpty()) err = setAttribute("t_imported", "T");
+    if (!err && !iImportID.isEmpty()) {
+        err = setAttribute("t_imported", "T");
+    }
     return err;
 }
 
@@ -357,10 +396,12 @@ int SKGOperationObject::getNbSubOperations() const
 SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperation)
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addSubOperation")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addSubOperation")));
+    } else {
         oSubOperation = SKGSubOperationObject(getDocument());
         err = oSubOperation.setParentOperation(*this);
+        IFOKDO(err, oSubOperation.setDate(getDate()));
     }
     return err;
 }
@@ -368,10 +409,11 @@ SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperatio
 SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getSubOperations")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getSubOperations")));
+    } else {
         err = getDocument()->getObjects("v_suboperation",
-                                        "rd_operation_id=" % SKGServices::intToString(getID()), oSubOperations);
+                                        "rd_operation_id=" % SKGServices::intToString(getID()) % " ORDER BY i_order", oSubOperations);
     }
     return err;
 }
@@ -409,7 +451,9 @@ double SKGOperationObject::getAmount(const QDate& iDate) const
     } else {
         // No
         SKGUnitObject unit;
-        if (getUnit(unit).isSucceeded()) coef = unit.getAmount(iDate);
+        if (getUnit(unit).isSucceeded()) {
+            coef = unit.getAmount(iDate);
+        }
     }
 
     return coef * quantity;
@@ -418,8 +462,9 @@ double SKGOperationObject::getAmount(const QDate& iDate) const
 SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject& oRecurrentOperation) const
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addRecurrentOperation")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::addRecurrentOperation")));
+    } else {
         oRecurrentOperation = SKGRecurrentOperationObject(getDocument());
         err = oRecurrentOperation.setParentOperation(*this);
         IFOK(err) oRecurrentOperation.setDate(getDate());
@@ -430,8 +475,9 @@ SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject&
 SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecurrentOperation) const
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getRecurrentOperation")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message",  "%1 failed because linked object is not yet saved in the database.", QString("SKGOperationObject::getRecurrentOperation")));
+    } else {
         err = getDocument()->getObjects("v_recurrentoperation",
                                         "rd_operation_id=" % SKGServices::intToString(getID()), oRecurrentOperation);
     }
@@ -444,13 +490,21 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     SKGError err = setDate(iDeletedOne.getDate());
     IFOKDO(err, setImportID(iDeletedOne.getImportID()))
     IFOKDO(err, setAttribute("t_imported", iDeletedOne.getAttribute("t_imported")))
-    if (!err && getComment().isEmpty()) err = setComment(iDeletedOne.getComment());
+    if (!err && getComment().isEmpty()) {
+        err = setComment(iDeletedOne.getComment());
+    }
     SKGPayeeObject payee;
     getPayee(payee);
     IFOKDO(err, setPayee(payee))
-    if (!err && getMode().isEmpty()) err = setMode(iDeletedOne.getMode());
-    if (!err && !isBookmarked()) err = bookmark(iDeletedOne.isBookmarked());
-    if (!err && !getNumber()) err = setNumber(iDeletedOne.getNumber());
+    if (!err && getMode().isEmpty()) {
+        err = setMode(iDeletedOne.getMode());
+    }
+    if (!err && !isBookmarked()) {
+        err = bookmark(iDeletedOne.isBookmarked());
+    }
+    if (!err && !getNumber()) {
+        err = setNumber(iDeletedOne.getNumber());
+    }
     IFOKDO(err, save())
 
     // Merge suboperations
