@@ -182,10 +182,11 @@ public:
     /**
      * Set date of this operation
      * @param iDate the date
+     * @param iRefreshSubOperations to refresh the sub operations
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setDate(const QDate& iDate);
+    virtual SKGError setDate(const QDate& iDate, bool iRefreshSubOperations = true);
 
     /**
      * Get date of this operation
