@@ -83,8 +83,9 @@ int SKGRecurrentOperationObject::getPeriodIncrement() const
 SKGRecurrentOperationObject::PeriodUnit SKGRecurrentOperationObject::getPeriodUnit() const
 {
     QString t_period_unit = getAttribute("t_period_unit");
-    if (t_period_unit == "D") return SKGRecurrentOperationObject::DAY;
-    else if (t_period_unit == "W") {
+    if (t_period_unit == "D") {
+        return SKGRecurrentOperationObject::DAY;
+    } else if (t_period_unit == "W") {
         return SKGRecurrentOperationObject::WEEK;
     } else if (t_period_unit == "M") {
         return SKGRecurrentOperationObject::MONTH;
@@ -136,8 +137,9 @@ SKGError SKGRecurrentOperationObject::setTimeLimit(const QDate& iLastDate)
 
     // Compute nb time
     int nbd = firstDate.daysTo(iLastDate);
-    if (period == SKGRecurrentOperationObject::DAY) nbd = nbd / occu;
-    else if (period == SKGRecurrentOperationObject::WEEK) {
+    if (period == SKGRecurrentOperationObject::DAY) {
+        nbd = nbd / occu;
+    } else if (period == SKGRecurrentOperationObject::WEEK) {
         nbd = nbd / (7 * occu);
     } else if (period == SKGRecurrentOperationObject::MONTH) {
         nbd = (iLastDate.day() >= firstDate.day() ? 0 : -1) + (iLastDate.year() - firstDate.year()) * 12 + (iLastDate.month() - firstDate.month());
@@ -145,7 +147,9 @@ SKGError SKGRecurrentOperationObject::setTimeLimit(const QDate& iLastDate)
         nbd = nbd / (365 * occu);
     }
 
-    if (nbd < -1) nbd = -1;
+    if (nbd < -1) {
+        nbd = -1;
+    }
     return setTimeLimit(nbd + 1);
 }
 
@@ -168,8 +172,9 @@ QDate SKGRecurrentOperationObject::getNextDate() const
     QDate nextDate = getDate();
     SKGRecurrentOperationObject::PeriodUnit punit = getPeriodUnit();
     int p = getPeriodIncrement();
-    if (punit == SKGRecurrentOperationObject::DAY) nextDate = nextDate.addDays(p);
-    else if (punit == SKGRecurrentOperationObject::WEEK) {
+    if (punit == SKGRecurrentOperationObject::DAY) {
+        nextDate = nextDate.addDays(p);
+    } else if (punit == SKGRecurrentOperationObject::WEEK) {
         nextDate = nextDate.addDays(7 * p);
     } else if (punit == SKGRecurrentOperationObject::MONTH) {
         nextDate = nextDate.addMonths(p);
@@ -212,7 +217,7 @@ SKGError SKGRecurrentOperationObject::getRecurredOperations(SKGListSKGObjectBase
 SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, const QDate& iDate)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGRecurrentOperationObject::process", err);
+    SKGTRACEINFUNCRC(10, err);
     oNbInserted = 0;
 
     if (!hasTimeLimit() || getTimeLimit() > 0) {
@@ -240,7 +245,9 @@ SKGError SKGRecurrentOperationObject::process(int& oNbInserted, bool iForce, con
                     }
 
                     IFOKDO(err, setDate(getNextDate()))
-                    if (!err && hasTimeLimit()) err = setTimeLimit(getTimeLimit() - 1);
+                    if (!err && hasTimeLimit()) {
+                        err = setTimeLimit(getTimeLimit() - 1);
+                    }
                     IFOKDO(err, save())
                     IFOKDO(err, load())
 
@@ -283,7 +290,9 @@ SKGError SKGRecurrentOperationObject::process(SKGDocumentBank* iDocument, int& o
 
     // Get all operation with auto_write
     SKGListSKGObjectBase recuOps;
-    if (iDocument) err = iDocument->getObjects("v_recurrentoperation", "", recuOps);
+    if (iDocument) {
+        err = iDocument->getObjects("v_recurrentoperation", "", recuOps);
+    }
 
     int nb = recuOps.count();
     for (int i = 0; !err && i < nb; ++i) {
