@@ -49,7 +49,7 @@ GRANTLEE_END_LOOKUP
 SKGReportBank::SKGReportBank(SKGDocument* iDocument)
     : SKGReport(iDocument)
 {
-    SKGTRACEIN(1, "SKGReportBank::SKGReportBank");
+    SKGTRACEINFUNC(1);
 
     // Grantlee initialization
     Grantlee::MetaType::init();
@@ -58,16 +58,16 @@ SKGReportBank::SKGReportBank(SKGDocument* iDocument)
 
 SKGReportBank::~SKGReportBank()
 {
-    SKGTRACEIN(1, "SKGReportBank::~SKGReportBank");
+    SKGTRACEINFUNC(1);
 }
 
 QVariantList SKGReportBank::getBudgetTable()
 {
     QVariantList table = m_cache["getBudgetTable"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getBudgetTable");
+        SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-        table = doc ? doc->getBudget(getMonth()) : QVariantList();
+        table = doc ? doc->getBudget(getPeriod()) : QVariantList();
         m_cache["getBudgetTable"] = table;
     }
     return table;
@@ -77,12 +77,10 @@ QVariantList SKGReportBank::getPortfolio()
 {
     QVariantList table = m_cache["getPortfolio"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getPortfolio");
-        QString month = getMonth();
-        if (!month.isEmpty()) {
-            QDate date = qMin(QDate::fromString(month, "yyyy-MM"), QDate::currentDate().addDays(1 - QDate::currentDate().day()));
-            QDate date2 = date.addMonths(1).addDays(-1);
-
+        SKGTRACEINFUNC(10);
+        QString period = getPeriod();
+        if (!period.isEmpty()) {
+            QDate date = qMin(SKGServices::periodToDate(period), QDate::currentDate().addDays(1 - QDate::currentDate().day()).addMonths(1).addDays(-1));
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
             KLocale* loc = KGlobal::locale();
             if (doc && loc) {
@@ -90,7 +88,7 @@ QVariantList SKGReportBank::getPortfolio()
 
                 // Get list of operations
                 SKGObjectBase::SKGListSKGObjectBase objs;
-                SKGError err = doc->getObjects("v_operation_display", "d_date<'" % SKGServices::dateToSqlString(QDateTime(date2)) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
+                SKGError err = doc->getObjects("v_operation_display", "d_date<'" % SKGServices::dateToSqlString(QDateTime(date)) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
                 int nb = objs.count();
                 if (!err && nb > 0) {
                     QVariantList line;
@@ -99,7 +97,7 @@ QVariantList SKGReportBank::getPortfolio()
                          << i18nc("Column table title", "Quantity")
                          << i18nc("Column table title", "Purchase amount")
                          << i18nc("Column table title", "Initial amount")
-                         << loc->formatDate(date2, KLocale::ShortDate)
+                         << loc->formatDate(date, KLocale::ShortDate)
                          << i18nc("Column table title", "Variation")
                          << i18nc("Column table title", "Variation %");
                     table << QVariant(line);
@@ -124,7 +122,7 @@ QVariantList SKGReportBank::getPortfolio()
 
                         current.unit = unit;
                         current.initalAmount += obj.getAmount(obj.getDate());
-                        current.currentAmount += obj.getAmount(date2);
+                        current.currentAmount += obj.getAmount(date);
                         SKGObjectBase::SKGListSKGObjectBase oGroupedOperations;
                         obj.getGroupedOperations(oGroupedOperations);
                         oGroupedOperations.removeAll(obj);
@@ -134,7 +132,9 @@ QVariantList SKGReportBank::getPortfolio()
                         }
                         current.quantity += SKGServices::stringToDouble(obj.getAttribute("f_QUANTITY"));
                     }
-                    if (!current.unit.getName().isEmpty()) listUnitValues.push_back(current);
+                    if (!current.unit.getName().isEmpty()) {
+                        listUnitValues.push_back(current);
+                    }
 
                     nb = listUnitValues.count();
                     for (int j = 0; j < nb; ++j) {
@@ -167,13 +167,12 @@ QVariantList SKGReportBank::getUnitTable()
 {
     QVariantList table = m_cache["getUnitTable"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getUnitTable");
-        QString month = getMonth();
-        if (!month.isEmpty()) {
-            QDate date = QDate::fromString(month, "yyyy-MM");
-            QDate date1 = date.addDays(-1);
-            QDate date2 = date.addMonths(1).addDays(-1);
-            QString previousmonth = date1.toString("yyyy-MM");
+        SKGTRACEINFUNC(10);
+        QString period = getPeriod();
+        if (!period.isEmpty()) {
+            QDate date1 = SKGServices::periodToDate(getPreviousPeriod());
+            QDate date2 = SKGServices::periodToDate(period);
+
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
             KLocale* loc = KGlobal::locale();
             if (doc && loc) {
@@ -211,14 +210,16 @@ QVariantList SKGReportBank::getAccountTable()
 {
     QVariantList table = m_cache["getAccountTable"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getAccountTable");
-        QString month = getMonth();
-        if (!month.isEmpty()) {
-            QDate date = QDate::fromString(month, "yyyy-MM");
-            QDate date1 = date.addDays(-1);
-            QDate date2 = date.addMonths(1).addDays(-1);
+        SKGTRACEINFUNC(10);
+        QString period = getPeriod();
+        if (!period.isEmpty()) {
+            QDate date1 = SKGServices::periodToDate(getPreviousPeriod());
+            QDate date2 = SKGServices::periodToDate(period);
             QDate date3 = date2.addYears(-1);
-            QString previousmonth = date1.toString("yyyy-MM");
+            if (date3 == date1) {
+                date3 = date3.addYears(-1);
+            }
+
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
             KLocale* loc = KGlobal::locale();
             if (doc && loc) {
@@ -292,14 +293,15 @@ QVariantList SKGReportBank::getBankTable()
 {
     QVariantList table = m_cache["getBankTable"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getBankTable");
-        QString month = getMonth();
-        if (!month.isEmpty()) {
-            QDate date = QDate::fromString(month, "yyyy-MM");
-            QDate date1 = date.addDays(-1);
-            QDate date2 = date.addMonths(1).addDays(-1);
+        SKGTRACEINFUNC(10);
+        QString period = getPeriod();
+        if (!period.isEmpty()) {
+            QDate date1 = SKGServices::periodToDate(getPreviousPeriod());
+            QDate date2 = SKGServices::periodToDate(period);
             QDate date3 = date2.addYears(-1);
-            QString previousmonth = date1.toString("yyyy-MM");
+            if (date3 == date1) {
+                date3 = date3.addYears(-1);
+            }
             SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
             KLocale* loc = KGlobal::locale();
             if (doc && loc) {
@@ -327,7 +329,9 @@ QVariantList SKGReportBank::getBankTable()
                         double v3 = account.getAmount(date3);
                         QString name = account.getAttribute("t_BANK");
                         // 320114 vvvv
-                        if (name.isEmpty()) name = i18nc("Noun", "Unknown");
+                        if (name.isEmpty()) {
+                            name = i18nc("Noun", "Unknown");
+                        }
                         // 320114 ^^^^
                         QString icon = account.getAttribute("t_ICON");
                         if (!icon.isEmpty()) {
@@ -378,7 +382,7 @@ QVariantList SKGReportBank::getScheduledOperations()
 {
     QVariantList table = m_cache["getScheduledOperations"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getScheduledOperations");
+        SKGTRACEINFUNC(10);
         SKGObjectBase::SKGListSKGObjectBase objs;
         SKGError err = m_document->getObjects("v_recurrentoperation_display", "i_nb_times!=0 ORDER BY d_date LIMIT 5", objs);
         IFOK(err) {
@@ -387,7 +391,9 @@ QVariantList SKGReportBank::getScheduledOperations()
                 for (int i = 0; i < nb; ++i) {
                     SKGRecurrentOperationObject obj(objs.at(i));
                     bool bold = false;
-                    if (obj.isWarnEnabled() &&  QDate::currentDate() >= obj.getDate().addDays(-obj.getWarnDays())) bold = true;
+                    if (obj.isWarnEnabled() &&  QDate::currentDate() >= obj.getDate().addDays(-obj.getWarnDays())) {
+                        bold = true;
+                    }
                     table.push_back(QVariantList() << bold << obj.getDisplayName());
                 }
             }
@@ -397,26 +403,26 @@ QVariantList SKGReportBank::getScheduledOperations()
     return table;
 }
 
-QVariantList SKGReportBank::getMainCategoriesMonth()
+QVariantList SKGReportBank::getMainCategoriesForPeriod()
 {
-    QVariantList table = m_cache["getMainCategoriesMonth"].toList();
+    QVariantList table = m_cache["getMainCategoriesForPeriod"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getMainCategoriesMonth");
+        SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-        table = doc ? doc->getMainCategories(getMonth(), 5) : QVariantList();
-        m_cache["getMainCategoriesMonth"] = table;
+        table = doc ? doc->getMainCategories(getPeriod(), 5) : QVariantList();
+        m_cache["getMainCategoriesForPeriod"] = table;
     }
     return table;
 }
 
-QVariantList SKGReportBank::getMainCategoriesPreviousMonth()
+QVariantList SKGReportBank::getMainCategoriesForPreviousPeriod()
 {
-    QVariantList table = m_cache["getMainCategoriesPreviousMonth"].toList();
+    QVariantList table = m_cache["getMainCategoriesForPreviousPeriod"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getMainCategoriesPreviousMonth");
+        SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-        table = doc ? doc->getMainCategories(getPreviousMonth(), 5) : QVariantList();
-        m_cache["getMainCategoriesPreviousMonth"] = table;
+        table = doc ? doc->getMainCategories(getPreviousPeriod(), 5) : QVariantList();
+        m_cache["getMainCategoriesForPreviousPeriod"] = table;
     }
     return table;
 }
@@ -425,9 +431,9 @@ QStringList SKGReportBank::get5MainCategoriesVariation()
 {
     QStringList table = m_cache["get5MainCategoriesVariation"].toStringList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::get5MainCategoriesVariation");
+        SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-        table = doc ? doc->get5MainCategoriesVariationList(getMonth(), getPreviousMonth()) : QStringList();
+        table = doc ? doc->get5MainCategoriesVariationList(getPeriod(), getPreviousPeriod()) : QStringList();
         m_cache["get5MainCategoriesVariation"] = table;
     }
     return table;
@@ -435,7 +441,7 @@ QStringList SKGReportBank::get5MainCategoriesVariation()
 
 QVariant SKGReportBank::getAdvice()
 {
-    SKGTRACEIN(10, "SKGReportBank::getAdvice");
+    SKGTRACEINFUNC(10);
     QVariant output = m_cache["getAdvice"];
     if (!output.isValid()) {
         // TODO(Stephane MANKOWSKI) output = qVariantFromValue(SKGMainPanel::getMainPanel()->getAdvice());
@@ -444,47 +450,66 @@ QVariant SKGReportBank::getAdvice()
     return output;
 }
 
-QVariantList SKGReportBank::getIncomeVsExpenditure()
+QVariantList SKGReportBank::getIncomeVsExpenditure(bool iOnSubOperation, bool iTransfert, bool iTracker, const QString& iWhereClause1, const QString& iWhereClause2)
 {
     QVariantList table = m_cache["getIncomeVsExpenditure"].toList();
     if (table.count() == 0) {
-        SKGTRACEIN(10, "SKGReportBank::getIncomeVsExpenditure");
+        SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
         if (doc) {
-            QString month = getMonth();
-            QString previousmonth = getPreviousMonth();
-            SKGObjectBase::SKGListSKGObjectBase ops;
-            SKGError err = doc->getObjects("v_operation_display", "d_DATEMONTH IN ('" % month % "', '" % previousmonth % "') AND t_TRANSFER='N'", ops);
-            int nbval = ops.count();
-            if (!err && nbval > 0) {
-                table.push_back(QVariantList() << "sum" << "" << previousmonth << month << "max");
+            QString tableDb = (iOnSubOperation ? "v_operation_consolidated" : "v_operation_display");
+            QString amount = (iOnSubOperation ? "f_REALCURRENTAMOUNT" : "f_CURRENTAMOUNT");
 
-                double income_previous_month = 0;
-                double expense_previous_month = 0;
-                double income_month = 0;
-                double expense_month = 0;
+            SKGStringListList listTmp;
+            QString wc1 = iWhereClause1;
+            if (wc1.isEmpty()) {
+                wc1 = SKGServices::getPeriodWhereClause(getPeriod());
+            }
+            QString wc2 = iWhereClause2;
+            if (wc2.isEmpty()) {
+                wc2 = SKGServices::getPeriodWhereClause(getPreviousPeriod());
+            }
 
-                for (int i = 0; i < nbval; ++i) {
-                    SKGOperationObject op(ops.at(i));
-                    QString m = op.getAttribute("d_DATEMONTH");
-                    QDate d = QDate::fromString(m, "yyyy-MM").addMonths(1).addDays(-1);
-                    double v = op.getAmount(d);
-                    if (v > 0 && m == month) income_month += v;
-                    else if (v < 0 && m == month) {
-                        expense_month += v;
-                    } else if (v > 0 && m == previousmonth) {
-                        income_previous_month += v;
-                    } else if (v < 0 && m == previousmonth) {
-                        expense_previous_month += v;
+            SKGError err = doc->executeSelectSqliteOrder(
+                               "SELECT TOTAL(" % amount % "), '1'  from " % tableDb % " WHERE " % wc1 % " AND t_TYPEACCOUNT<>'L'"
+                               % (iTransfert ? "" : "AND t_TRANSFER='N'")
+                               % (iTracker ? "" : " AND t_REFUND=''")
+                               % " group by t_TYPEEXPENSE "
+                               % " UNION ALL "
+                               % "SELECT TOTAL(" % amount % "), '2'  from " % tableDb % " WHERE " % wc2 % " AND t_TYPEACCOUNT<>'L'"
+                               % (iTransfert ? "" : "AND t_TRANSFER='N'")
+                               % (iTracker ? "" : " AND t_REFUND=''")
+                               % " group by t_TYPEEXPENSE ",
+                               listTmp);
+            IFOK(err) {
+                double income_previous_period = 0;
+                double expense_previous_period = 0;
+                double income_period = 0;
+                double expense_period = 0;
+
+                int nbval = listTmp.count();
+                for (int i = 1; i < nbval; ++i) {  // Ignore header
+                    QString m = listTmp.at(i).at(1);
+                    double v = SKGServices::stringToDouble(listTmp.at(i).at(0));
+                    if (v > 0 && m == "1") {
+                        income_period = v;
+                    } else if (v < 0 && m == "1") {
+                        expense_period = v;
+                    } else if (v > 0 && m == "2") {
+                        income_previous_period = v;
+                    } else if (v < 0 && m == "2") {
+                        expense_previous_period = v;
                     }
                 }
-                double saving_previous_month = income_previous_month + expense_previous_month;
-                double saving_month = income_month + expense_month;
 
-                table.push_back(QVariantList() << false << doc->getDisplay("f_CURRENTAMOUNT_INCOME") << qAbs(income_previous_month) << qAbs(income_month));
-                table.push_back(QVariantList() << false << doc->getDisplay("f_CURRENTAMOUNT_EXPENSE") << qAbs(expense_previous_month) << qAbs(expense_month));
-                table.push_back(QVariantList() << true << i18nc("Noun",  "Savings possible") << saving_previous_month << saving_month);
-                table.push_back(QVariantList() << true << i18nc("Noun",  "Max") << qMax(qAbs(income_previous_month), qAbs(expense_previous_month)) << qMax(qAbs(income_month), qAbs(expense_month)));
+                double saving_previous_period = income_previous_period + expense_previous_period;
+                double saving_period = income_period + expense_period;
+
+                table.push_back(QVariantList() << "sum" << "" << getPreviousPeriod() << getPeriod() << "max");
+                table.push_back(QVariantList() << false << doc->getDisplay("f_CURRENTAMOUNT_INCOME") << qAbs(income_previous_period) << qAbs(income_period));
+                table.push_back(QVariantList() << false << doc->getDisplay("f_CURRENTAMOUNT_EXPENSE") << qAbs(expense_previous_period) << qAbs(expense_period));
+                table.push_back(QVariantList() << true << i18nc("Noun",  "Savings possible") << saving_previous_period << saving_period);
+                table.push_back(QVariantList() << true << i18nc("Noun",  "Max") << qMax(qAbs(income_previous_period), qAbs(expense_previous_period)) << qMax(qAbs(income_period), qAbs(expense_period)));
             }
             m_cache["getIncomeVsExpenditure"] = table;
         }
@@ -516,7 +541,7 @@ void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
     iMapping.insert("logo", KUrl(KStandardDirs().findResource("icon", QString::fromLatin1("hicolor/128x128/apps/skrooge.png"))).url());
     iMapping.insert("logo_black", KUrl(KStandardDirs().findResource("icon", QString::fromLatin1("hicolor/128x128/apps/skrooge-black.png"))).url());
 
-    iMapping.insert("title_main", i18nc("A monthly report title", "Report for %1", getMonth()));
+    iMapping.insert("title_main", i18nc("A monthly report title", "Report for %1", getPeriod()));
     iMapping.insert("title_budget", i18nc("A monthly report title", "Budget"));
     iMapping.insert("title_main_categories", i18nc("A monthly report title", "5 main categories of expenditure"));
     iMapping.insert("title_variations", i18nc("A monthly report title", "5 main variations"));
@@ -531,7 +556,7 @@ void SKGReportBank::addItemsInMapping(QVariantHash& iMapping)
     iMapping.insert("msg_no_highlighted", i18nc("A monthly report message", "No highlighted operations defined on the \"<a href=\"%1\">Operations</a>\" page.", "skg://Skrooge_operation_plugin/"));
     iMapping.insert("msg_no_budget", i18nc("A monthly report message", "No budget defined on the \"<a href=\"%1\">Budget</a>\" page.", "skg://Skrooge_budget_plugin/"));
     iMapping.insert("msg_no_share", i18nc("A monthly report message", "No share defined on the \"<a href=\"%1\">Unit</a>\" page.", "skg://Skrooge_unit_plugin/"));
-    iMapping.insert("msg_amount_unit_date", i18nc("A monthly report message", "All amounts are calculated using the unit rates of the last day of the corresponding month."));
+    iMapping.insert("msg_amount_unit_date", i18nc("A monthly report message", "All amounts are calculated using the unit rates of the last day of the corresponding period."));
 }
 
 #include "skgreportbank.moc"
