@@ -82,14 +82,20 @@ QString SKGUnitObject::getWhereclauseId() const
     QString output = SKGObjectBase::getWhereclauseId();
     if (output.isEmpty()) {
         QString name = getName();
-        if (!name.isEmpty()) output = "t_name='" % SKGServices::stringToSqlString(name) % '\'';
+        if (!name.isEmpty()) {
+            output = "t_name='" % SKGServices::stringToSqlString(name) % '\'';
+        }
 
         QString symbol = getSymbol();
         if (!symbol.isEmpty()) {
-            if (!output.isEmpty()) output += " OR ";
+            if (!output.isEmpty()) {
+                output += " OR ";
+            }
             output += "t_symbol='" % SKGServices::stringToSqlString(symbol) % '\'';
         }
-        if (!output.isEmpty()) output = '(' % output % ')';
+        if (!output.isEmpty()) {
+            output = '(' % output % ')';
+        }
     }
 
     return output;
@@ -97,7 +103,7 @@ QString SKGUnitObject::getWhereclauseId() const
 
 QStringList SKGUnitObject::getListofKnownCurrencies(bool iIncludingObsolete)
 {
-    SKGTRACEIN(10, "SKGUnitObject::getListofKnownCurrencies");
+    SKGTRACEINFUNC(10);
     QStringList output;
     QStringList units = KCurrencyCode::allCurrencyCodesList(iIncludingObsolete ? KCurrencyCode::ActiveCurrency | KCurrencyCode::SuspendedCurrency | KCurrencyCode::ObsoleteCurrency : KCurrencyCode::ActiveCurrency);
     int nb = units.count();
@@ -124,7 +130,7 @@ QStringList SKGUnitObject::getListofKnownCurrencies(bool iIncludingObsolete)
 
 QString SKGUnitObject::getInternationalCode(const QString& iUnitName)
 {
-    SKGTRACEIN(10, "SKGUnitObject::getInternationalCode");
+    SKGTRACEINFUNC(10);
     QString output = iUnitName;
     QRegExp rx(".*\\(([^\\(\\)]+)\\)[^\\(\\)]*");
     if (rx.indexIn(iUnitName) != -1) {
@@ -136,7 +142,7 @@ QString SKGUnitObject::getInternationalCode(const QString& iUnitName)
 
 SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo()
 {
-    SKGTRACEIN(10, "SKGUnitObject::getUnitInfo");
+    SKGTRACEINFUNC(10);
     SKGServices::SKGUnitInfo info;
     info.Name = getName();
     info.Value = getAmount();
@@ -151,7 +157,7 @@ SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo()
 
 SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo(const QString& iUnitName)
 {
-    SKGTRACEIN(10, "SKGUnitObject::getUnitInfo");
+    SKGTRACEINFUNC(10);
     SKGServices::SKGUnitInfo info;
     info.NbDecimal = 2;
     info.Value = -1;
@@ -164,9 +170,13 @@ SKGServices::SKGUnitInfo SKGUnitObject::getUnitInfo(const QString& iUnitName)
         KCurrencyCode unitCode(isoCode, KGlobal::locale() == NULL ? "en" : "");
         info.Name = unitCode.name() % " (" % unitCode.isoCurrencyCode() % ')';
         info.Symbol = unitCode.unambiguousSymbol();
-        if (info.Symbol.isEmpty()) info.Symbol = unitCode.name();
+        if (info.Symbol.isEmpty()) {
+            info.Symbol = unitCode.name();
+        }
         QStringList counties = unitCode.countriesUsingCurrency();
-        if (counties.count()) info.Country = counties.at(0);
+        if (counties.count()) {
+            info.Country = counties.at(0);
+        }
         info.Date = unitCode.dateIntroduced();
         if (!info.Date.isValid()) {
             info.Date = QDate::currentDate();
@@ -271,8 +281,12 @@ SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QSt
 
         // Get information on the unit
         SKGServices::SKGUnitInfo info = getUnitInfo(iUnitName);
-        if (info.Name.isEmpty()) err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Unknown unit '%1'", iUnitName));
-        if (!err && !info.Parent.isEmpty()) err = createCurrencyUnit(iDocument, info.Parent, parentUnit);
+        if (info.Name.isEmpty()) {
+            err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Unknown unit '%1'", iUnitName));
+        }
+        if (!err && !info.Parent.isEmpty()) {
+            err = createCurrencyUnit(iDocument, info.Parent, parentUnit);
+        }
 
         // Set the type
         if (info.Name == info.Symbol) {
@@ -306,14 +320,18 @@ SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QSt
         }
 
         IFOKDO(err, oUnit.setName(info.Name))
-        if (!err && oUnit.exist()) err = oUnit.load();
+        if (!err && oUnit.exist()) {
+            err = oUnit.load();
+        }
         IFOKDO(err, oUnit.setType(type))
         IFOKDO(err, oUnit.setSymbol(info.Symbol))
         IFOKDO(err, oUnit.setInternetCode(info.Internet))
         IFOKDO(err, oUnit.setDownloadSource(info.Source))
         IFOKDO(err, oUnit.setCountry(info.Country))
         IFOKDO(err, oUnit.setNumberDecimal(info.NbDecimal))
-        if (!err && parentUnit.exist()) err = oUnit.setUnit(parentUnit);
+        if (!err && parentUnit.exist()) {
+            err = oUnit.setUnit(parentUnit);
+        }
         IFOKDO(err, oUnit.save())
 
         // Creation of the value
@@ -399,7 +417,9 @@ SKGError SKGUnitObject::setType(SKGUnitObject::UnitType iType)
             err = getDocument()->executeSqliteOrder("UPDATE unit SET t_type='C' WHERE t_type='2'");
 
             // Set old PRIMARY as SECONDARY
-            if (!err && iType == PRIMARY) err = getDocument()->executeSqliteOrder("UPDATE unit SET t_type='2' WHERE t_type='1'");
+            if (!err && iType == PRIMARY) {
+                err = getDocument()->executeSqliteOrder("UPDATE unit SET t_type='2' WHERE t_type='1'");
+            }
         }
     }
     IFOKDO(err, setAttribute("t_type", (iType == CURRENCY ? "C" : (iType == PRIMARY ? "1" : (iType == SECONDARY ? "2" : (iType == SHARE ? "S" : (iType == INDEX ? "I" : "O")))))))
@@ -415,15 +435,18 @@ SKGUnitObject::UnitType SKGUnitObject::getType() const
 SKGError SKGUnitObject::getUnit(SKGUnitObject& oUnit) const
 {
     SKGError err;
-    if (getDocument()) err = getDocument()->getObject("v_unit", "id=" % getAttribute("rd_unit_id"), oUnit);
+    if (getDocument()) {
+        err = getDocument()->getObject("v_unit", "id=" % getAttribute("rd_unit_id"), oUnit);
+    }
     return err;
 }
 
 SKGError SKGUnitObject::setUnit(const SKGUnitObject& iUnit)
 {
     SKGError err;
-    if (*this == iUnit && iUnit.getID() != 0) err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Reference unit of a unit cannot be itself."));
-    else {
+    if (*this == iUnit && iUnit.getID() != 0) {
+        err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Reference unit of a unit cannot be itself."));
+    } else {
         err = setAttribute("rd_unit_id", SKGServices::intToString(iUnit.getID()));
     }
     return err;
@@ -437,8 +460,9 @@ SKGError SKGUnitObject::removeUnit()
 SKGError SKGUnitObject::addUnitValue(SKGUnitValueObject& oUnitValue)
 {
     SKGError err;
-    if (getID() == 0) err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGUnitObject::addUnitValue")));
-    else {
+    if (getID() == 0) {
+        err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QString("SKGUnitObject::addUnitValue")));
+    } else {
         oUnitValue = SKGUnitValueObject(static_cast<SKGDocumentBank*>(getDocument()));
         err = oUnitValue.setAttribute("rd_unit_id", SKGServices::intToString(getID()));
     }
@@ -567,10 +591,11 @@ SKGError SKGUnitObject::getUnitValue(const QDate& iDate, SKGUnitValueObject& oUn
 
 double SKGUnitObject::getAmount(const QDate& iDate) const
 {
-    SKGTRACEIN(10, "SKGUnitObject::getAmount");
+    SKGTRACEINFUNC(10);
     double output = 0;
-    if (getType() == SKGUnitObject::PRIMARY) output = 1.0;
-    else if (getDocument()) {
+    if (getType() == SKGUnitObject::PRIMARY) {
+        output = 1.0;
+    } else if (getDocument()) {
         // Search result in cache
         QString ids = SKGServices::intToString(getID());
         QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
@@ -580,12 +605,16 @@ double SKGUnitObject::getAmount(const QDate& iDate) const
             // Get quantity
             double quantity = 1;
             SKGUnitValueObject uv;
-            if (getUnitValue(iDate, uv).isSucceeded()) quantity = uv.getQuantity();
+            if (getUnitValue(iDate, uv).isSucceeded()) {
+                quantity = uv.getQuantity();
+            }
 
             SKGUnitObject unit;
             double coef = 1;
             if (getUnit(unit).isSucceeded()) {
-                if (unit != *this) coef = unit.getAmount(iDate);
+                if (unit != *this) {
+                    coef = unit.getAmount(iDate);
+                }
             }
 
             output = coef * quantity;
@@ -644,7 +673,9 @@ QStringList SKGUnitObject::downloadSources()
     foreach(const QString & file, KStandardDirs().findAllResources("data", QString::fromLatin1("skrooge/quotes/*.txt"))) {
         QFileInfo f(file);
         QString file2 = f.completeBaseName();
-        if (!sources.contains(file2)) sources.push_back(file2);
+        if (!sources.contains(file2)) {
+            sources.push_back(file2);
+        }
     }
 
     return sources;
@@ -661,8 +692,9 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource, bool iOpenSource)
     // Check if file already existing
     if (!QFile(newfile).exists()) {
         // Creation of the template
-        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", newfile));
-        else {
+        if (!file.open()) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed", newfile));
+        } else {
             QTextStream out(&file);
 
             out << "#" << i18nc("Description test for a text file used to define a source of download",
@@ -692,7 +724,9 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource, bool iOpenSource)
     }
 
     // Open the created or already existing file
-    if (iOpenSource) QDesktopServices::openUrl(KUrl(newfile));
+    if (iOpenSource) {
+        QDesktopServices::openUrl(KUrl(newfile));
+    }
     return err;
 }
 
@@ -704,7 +738,9 @@ SKGError SKGUnitObject::deleteSource(const QString& iSource)
 
     // Delete the file
     QFile file(fileName);
-    if (!file.remove()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", fileName));
+    if (!file.remove()) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", fileName));
+    }
     return err;
 }
 
@@ -717,7 +753,7 @@ bool SKGUnitObject::isWritable(const QString& iSource)
 SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValues, bool iAdditionalInfo)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitObject::downloadUnitValue", err);
+    SKGTRACEINFUNCRC(10, err);
 
     QString unitname = getName();
     QString code = getInternetCode();
@@ -739,7 +775,9 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
         if (code.startsWith(QLatin1String("="))) {
             // MODE FORMULAR
             // Set 1st january if date is not found
-            if (!firstDate.isValid()) firstDate.setDate(QDate::currentDate().year(), 1, 1);
+            if (!firstDate.isValid()) {
+                firstDate.setDate(QDate::currentDate().year(), 1, 1);
+            }
 
             // Compute yearly rate
             double rate = SKGServices::stringToDouble(code.right(code.length() - 1));
@@ -752,13 +790,16 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             SKGStringListList result2;
             double value = 100;
             doc->executeSelectSqliteOrder("SELECT f_quantity FROM unitvalue where rd_unit_id=(SELECT id from unit where t_name='" % SKGServices::stringToSqlString(unitname) % "') AND d_date='" % SKGServices::dateToSqlString(QDateTime(firstDate)) % '\'', result2);
-            if (result2.count() == 2) value = SKGServices::stringToDouble(result2.at(1).at(0));
+            if (result2.count() == 2) {
+                value = SKGServices::stringToDouble(result2.at(1).at(0));
+            }
 
             // Compute and add values
             while (!err && firstDate <= QDate::currentDate()) {
                 // Compute next date and value
-                if (iMode == LAST_MONTHLY || ALL_MONTHLY) firstDate = firstDate.addMonths(1);
-                else if (iMode == LAST_WEEKLY || ALL_WEEKLY) {
+                if (iMode == LAST_MONTHLY || ALL_MONTHLY) {
+                    firstDate = firstDate.addMonths(1);
+                } else if (iMode == LAST_WEEKLY || ALL_WEEKLY) {
                     firstDate = firstDate.addDays(7);
                 } else {
                     firstDate = firstDate.addDays(1);
@@ -782,8 +823,9 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
             // &g=m = monthly
             QString parameters;
             bool last = (iMode == LAST);
-            if (last) parameters = dateParameters % "&g=d";
-            else if (iMode == LAST_MONTHLY) {
+            if (last) {
+                parameters = dateParameters % "&g=d";
+            } else if (iMode == LAST_MONTHLY) {
                 parameters = dateParameters % "&g=m";
             } else if (iMode == LAST_WEEKLY) {
                 parameters = dateParameters % "&g=w";
@@ -816,17 +858,26 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                         // Read line
                         QString line = lines.at(i);
                         QStringList fields = SKGServices::splitCSVLine(line, ',');
-                        if (fields.count() != 7) err2.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
-                        else {
+                        if (fields.count() != 7) {
+                            err2.setReturnCode(ERR_ABORT).setMessage(i18nc("An error message", "Invalid line '%1' found in downloaded file.\nCheck this page: %2", line, path));
+                        } else {
                             QDate ds = QDate::fromString(fields[0], "yyyy-MM-dd");
                             double val = SKGServices::stringToDouble(fields[6]);
 
                             // Creation or update of the value
                             SKGUnitValueObject value;
-                            if (!err2) err2 = addUnitValue(value);
-                            if (!err2) err2 = value.setDate(ds);
-                            if (!err2) err2 = value.setQuantity(invert && val != 0 ? 1 / val : val);
-                            if (!err2) err2 = value.save();
+                            if (!err2) {
+                                err2 = addUnitValue(value);
+                            }
+                            if (!err2) {
+                                err2 = value.setDate(ds);
+                            }
+                            if (!err2) {
+                                err2 = value.setQuantity(invert && val != 0 ? 1 / val : val);
+                            }
+                            if (!err2) {
+                                err2 = value.save();
+                            }
                         }
                     }
                 } else {
@@ -1042,7 +1093,9 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
 
                         for (int j = 2; !err && j < nb; ++j) {
                             QString val = fields[j];
-                            if (!val.contains("N/A") && val != "-" && val != "- - -" && val != "0" && val != "0.00") err = setProperty(unitYahooTitle[j - 2], val);
+                            if (!val.contains("N/A") && val != "-" && val != "- - -" && val != "0" && val != "0.00") {
+                                err = setProperty(unitYahooTitle[j - 2], val);
+                            }
                         }
                     }
                 } else {
@@ -1065,11 +1118,18 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                     QString price = properties["price"].replace("%1", code);
                     QString date = properties["date"].replace("%1", code);
                     QString dateFormat = properties["dateformat"];
+                    SKGTRACEL(1) << "path=[" << path << "]" << endl;
+                    SKGTRACEL(1) << "mode=[" << mode << "]" << endl;
+                    SKGTRACEL(1) << "price=[" << price << "]" << endl;
+                    SKGTRACEL(1) << "date=[" << date << "]" << endl;
+                    SKGTRACEL(1) << "dateFormat=[" << dateFormat << "]" << endl;
 
                     // Download url
                     QByteArray stream;
                     SKGServices::downloadToStream(KUrl(path), stream);
                     if (!stream.isEmpty()) {
+                        SKGTRACEL(1) << "stream=[" << stream << "]" << endl;
+
                         // Parse data
                         QRegExp priceRegExp(price, Qt::CaseInsensitive);
                         QRegExp dateRegExp(date, Qt::CaseInsensitive);
@@ -1083,21 +1143,27 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                                 SKGTRACEL(1) << "Downloaded data from [" << path << "]=[" << data << "]" << endl;
 
                                 double val = 0.0;
-                                if (priceRegExp.indexIn(data) > -1) val = SKGServices::stringToDouble(priceRegExp.cap(1));
+                                if (priceRegExp.indexIn(data) > -1) {
+                                    val = SKGServices::stringToDouble(priceRegExp.cap(1));
+                                }
                                 QString date2;
-                                if (dateRegExp.indexIn(data) > -1) date2 = dateRegExp.cap(1);
+                                if (dateRegExp.indexIn(data) > -1) {
+                                    date2 = dateRegExp.cap(1);
+                                }
                                 SKGTRACEL(1) << "Price found=[" << val << "]" << endl;
                                 SKGTRACEL(1) << "Date found=[" << date2 << "]" << endl;
 
                                 // Set value
                                 if (val) {
                                     QDate ds;
-                                    if (dateFormat == "UNIX")
+                                    if (dateFormat == "UNIX") {
                                         ds = QDateTime::fromTime_t(SKGServices::stringToInt(date2)).date();
-                                    else {
+                                    } else {
                                         ds = QDate::fromString(date2, dateFormat);
                                     }
-                                    if (!ds.isValid()) ds = QDate::currentDate();
+                                    if (!ds.isValid()) {
+                                        ds = QDate::currentDate();
+                                    }
                                     if (!dateFormat.contains("yyyy") && ds.year() < 2000) {
                                         ds = ds.addYears(100);
                                     }
@@ -1112,7 +1178,9 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                                     nbLoaded++;
                                 }
                             }
-                            if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data), SKGDocument::Warning);  // TODO(Stephane MANKOWSKI) does not work with html
+                            if (nbLoaded == 0) {
+                                err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data), SKGDocument::Warning);    // TODO(Stephane MANKOWSKI) does not work with html
+                            }
                         }
                     } else {
                         doc->sendMessage(i18nc("An information message", "Open url '%1' failed", path), SKGDocument::Warning);
@@ -1129,13 +1197,12 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
     return err;
 }
 
-SKGError SKGUnitObject::openURL()
+SKGError SKGUnitObject::getUrl(QUrl& oUrl) const
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGUnitObject::openURL", err);
+    SKGTRACEINFUNCRC(10, err);
 
     QString url;
-    QString unitname = getName();
     QString code = getInternetCode();
     code.remove(" /");
     QString source = getDownloadSource();
@@ -1164,9 +1231,21 @@ SKGError SKGUnitObject::openURL()
     }
 
     IFKO(err) {
-        err.addError(ERR_FAIL, i18nc("Error message", "Impossible to open unit %1 with Internet code %2.", unitname, code));
+        oUrl = QUrl(url);
+    }
+
+    return err;
+}
+
+SKGError SKGUnitObject::openURL() const
+{
+    QUrl url;
+    SKGError err = getUrl(url);
+
+    IFKO(err) {
+        err.addError(ERR_FAIL, i18nc("Error message", "Impossible to open unit %1 with Internet code %2.", getName(), getInternetCode()));
     } else {
-        QDesktopServices::openUrl(QUrl(url));
+        QDesktopServices::openUrl(url);
     }
 
     return err;
