@@ -101,7 +101,9 @@ void SKGCalculatorEdit::setText(const QString& iText)
     }
 
     // Set text (to display the input value)
-    if (m_valid) KLineEdit::setText(iText);
+    if (m_valid) {
+        KLineEdit::setText(iText);
+    }
 }
 
 bool SKGCalculatorEdit::valid() const
@@ -120,7 +122,9 @@ void SKGCalculatorEdit::addParameterValue(const QString& iParameter, double iVal
 
     // Refresh completion
     KCompletion* comp = this->completionObject();
-    if (comp) comp->addItem('=' % iParameter);
+    if (comp) {
+        comp->addItem('=' % iParameter);
+    }
 }
 
 void SKGCalculatorEdit::keyPressEvent(QKeyEvent* iEvent)
@@ -213,8 +217,12 @@ double SKGCalculatorEdit::getEvaluatedValue(bool& iOk)
         t = t.replace(',', '.');  // Replace comma by a point in case of typo
         KLocale* loc = KGlobal::locale();
         if (loc) {
-            if (!loc->thousandsSeparator().isEmpty()) t = t.replace(loc->thousandsSeparator(), ".");
-            if (!loc->monetaryThousandsSeparator().isEmpty()) t = t.replace(loc->monetaryThousandsSeparator(), ".");
+            if (!loc->thousandsSeparator().isEmpty()) {
+                t = t.replace(loc->thousandsSeparator(), ".");
+            }
+            if (!loc->monetaryThousandsSeparator().isEmpty()) {
+                t = t.replace(loc->monetaryThousandsSeparator(), ".");
+            }
         }
 
         // Remove double . in numbers
