@@ -92,7 +92,7 @@ public:
     /**
      * Display an error message
      * @param iError the error
-     * @param iAction the additionnal action to add
+     * @param iAction the additional action to add
      * @return the message widget
      */
     static KMessageWidget* displayErrorMessage(const SKGError& iError, QAction* iAction = NULL);
@@ -342,6 +342,13 @@ public Q_SLOTS:
      */
     virtual void registerGlobalAction(const QString& iIdentifier, QAction* iAction, bool iAddInCollection = true);
 
+    /**
+     * Unregister a global action
+     * @param iAction action pointer
+     */
+    virtual void unRegisterGlobalAction(QObject* iAction);
+
+
     /**
      * Get a registered global action
      * @param iIdentifier identifier of the action
@@ -354,7 +361,7 @@ public Q_SLOTS:
      * Get all registered global actions
      * @return actions
      */
-    virtual QMap<QString, QAction*> getGlobalActions() const;
+    virtual QMap<QString, QPointer<QAction> > getGlobalActions() const;
 
     /**
      * Get the temporary filename containing the tips of days
