@@ -91,17 +91,31 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
 
     //
     KAction* actCopy = KStandardAction::copy(this, SLOT(copy()), NULL);
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_copy", actCopy);
+    actCopy->setShortcutConfigurable(false);
+    actCopy->setShortcutContext(Qt::WidgetShortcut);
+    if (SKGMainPanel::getMainPanel()) {
+        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_copy", actCopy);
+    }
     insertGlobalAction("edit_copy");
 
     m_actExpandAll = new KAction(KIcon("format-indent-more"), i18nc("Noun, user action", "Expand all"), this);
+    m_actExpandAll->setShortcut(Qt::ALT + Qt::Key_Plus);
+    m_actExpandAll->setShortcutConfigurable(false);
+    m_actExpandAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actExpandAll, SIGNAL(triggered(bool)), this, SLOT(expandAll()));
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_expandall", m_actExpandAll);
+    if (SKGMainPanel::getMainPanel()) {
+        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_expandall", m_actExpandAll);
+    }
     insertGlobalAction("edit_expandall");
 
     m_actCollapseAll = new KAction(KIcon("format-indent-less"), i18nc("Noun, user action", "Collapse all"), this);
+    m_actCollapseAll->setShortcut(Qt::ALT + Qt::Key_Minus);
+    m_actCollapseAll->setShortcutConfigurable(false);
+    m_actCollapseAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actCollapseAll, SIGNAL(triggered(bool)), this, SLOT(collapseAll()));
-    if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registerGlobalAction("edit_collapseal", m_actCollapseAll);
+    if (SKGMainPanel::getMainPanel()) {
+        SKGMainPanel::getMainPanel()->registerGlobalAction("edit_collapseal", m_actCollapseAll);
+    }
     insertGlobalAction("edit_collapseal");
 
     connect(horizontalScrollBar(), SIGNAL(actionTriggered(int)), this, SLOT(onActionTriggered(int)));
@@ -133,7 +147,9 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     // Save original size
     m_fontOriginalPointSize = this->font().pointSize();
     m_iconOriginalSize = this->iconSize().height();
-    if (m_iconOriginalSize <= 0) m_iconOriginalSize = 16;
+    if (m_iconOriginalSize <= 0) {
+        m_iconOriginalSize = 16;
+    }
 }
 
 SKGTreeView::~SKGTreeView()
@@ -153,7 +169,7 @@ bool SKGTreeView::isAutoResized()
 
 QString SKGTreeView::getState()
 {
-    SKGTRACEIN(10, "SKGTreeView::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -174,17 +190,25 @@ QString SKGTreeView::getState()
             QString columnsVisibility;
             for (int i = 0; i < nb; ++i) {
                 int idx = hHeader->logicalIndex(i);
-                if (i) columns += ';';
+                if (i) {
+                    columns += ';';
+                }
                 columns += m_model->getAttribute(idx);
 
-                if (i) columnsSize += ';';
+                if (i) {
+                    columnsSize += ';';
+                }
                 columnsSize += SKGServices::intToString(hHeader->sectionSize(idx));
 
-                if (i) columnsVisibility += ';';
+                if (i) {
+                    columnsVisibility += ';';
+                }
                 columnsVisibility += (hHeader->isSectionHidden(idx) ? "N" : "Y");
             }
             root.setAttribute("columns", columns);
-            if (!m_autoResize) root.setAttribute("columnsSize", columnsSize);
+            if (!m_autoResize) {
+                root.setAttribute("columnsSize", columnsSize);
+            }
             root.setAttribute("columnsVisibility", columnsVisibility);
             root.setAttribute("columnsAutoResize", m_autoResize ? "Y" : "N");
         }
@@ -198,15 +222,19 @@ QString SKGTreeView::getState()
     root.setAttribute("zoomPosition", SKGServices::intToString(zoomPosition()));
 
     QScrollBar* scroll2 = horizontalScrollBar();
-    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) root.setAttribute("stickH", "Y");
+    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
+        root.setAttribute("stickH", "Y");
+    }
     scroll2 = verticalScrollBar();
-    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) root.setAttribute("stickV", "Y");
+    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
+        root.setAttribute("stickV", "Y");
+    }
     return doc.toString();
 }
 
 void SKGTreeView::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGTreeView::setState");
+    SKGTRACEINFUNC(10);
     resetColumnsOrder();
 
     QDomDocument doc("SKGML");
@@ -270,27 +298,41 @@ void SKGTreeView::setState(const QString& iState)
         // Set sort
         if (m_model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
             int index = SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
-            if (index == -1) index = m_model->getIndexAttribute(sortColumn);
-            if (index == -1) index = 0;
+            if (index == -1) {
+                index = m_model->getIndexAttribute(sortColumn);
+            }
+            if (index == -1) {
+                index = 0;
+            }
             qtsortorder = static_cast<Qt::SortOrder>(SKGServices::stringToInt(sortOrder));
             this->sortByColumn(index, qtsortorder);
         }
 
         if (m_model) {
             QString att = m_groupby;
-            if (att == "#") att = sortColumn;
+            if (att == "#") {
+                att = sortColumn;
+            }
             m_model->setGroupBy(att);
             m_model->dataModified();
 
             bool treeMode = !m_model->getParentChildAttribute().isEmpty();
             setRootIsDecorated(treeMode && m_groupby.isEmpty());
-            if (m_actExpandAll) m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
-            if (m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+            if (m_actExpandAll) {
+                m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+            }
+            if (m_actCollapseAll) {
+                m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+            }
         }
 
         // Set alternatingRowColors
-        if (!alternatingRowColors2.isEmpty()) setAlternatingRowColors(alternatingRowColors2 == "Y");
-        if (!zoomPositionString.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPositionString));
+        if (!alternatingRowColors2.isEmpty()) {
+            setAlternatingRowColors(alternatingRowColors2 == "Y");
+        }
+        if (!zoomPositionString.isEmpty()) {
+            setZoomPosition(SKGServices::stringToInt(zoomPositionString));
+        }
 
         // Set expanded groups
         m_expandedNodes = SKGServices::splitCSVLine(expandedGroups);
@@ -304,8 +346,12 @@ void SKGTreeView::setState(const QString& iState)
 
             bool treeMode = !m_model->getParentChildAttribute().isEmpty();
             setRootIsDecorated(treeMode && m_groupby.isEmpty());
-            if (m_actExpandAll) m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
-            if (m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+            if (m_actExpandAll) {
+                m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+            }
+            if (m_actCollapseAll) {
+                m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+            }
         }
 
         this->sortByColumn(0, qtsortorder);
@@ -324,11 +370,19 @@ void SKGTreeView::onActionTriggered(int action)
 {
     QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
     if (scroll2 && action == QAbstractSlider::SliderToMaximum) {
-        if (scroll2 == horizontalScrollBar()) stickH = true;
-        if (scroll2 == verticalScrollBar()) stickV = true;
+        if (scroll2 == horizontalScrollBar()) {
+            stickH = true;
+        }
+        if (scroll2 == verticalScrollBar()) {
+            stickV = true;
+        }
     } else {
-        if (scroll2 == horizontalScrollBar()) stickH = false;
-        if (scroll2 == verticalScrollBar()) stickV = false;
+        if (scroll2 == horizontalScrollBar()) {
+            stickH = false;
+        }
+        if (scroll2 == verticalScrollBar()) {
+            stickV = false;
+        }
     }
 }
 
@@ -346,16 +400,17 @@ void SKGTreeView::insertGlobalAction(const QString& iRegisteredAction)
 
 void SKGTreeView::resizeColumnsToContentsDelayed()
 {
-    SKGTRACEIN(10, "SKGTreeView::resizeColumnsToContentsDelayed");
+    SKGTRACEINFUNC(10);
     m_timerDelayedResize.start(300);
 }
 
 void SKGTreeView::resizeColumnsToContents()
 {
-    SKGTRACEIN(10, "SKGTreeView::resizeColumnsToContents");
+    SKGTRACEINFUNC(10);
     int nb = header()->count();
-    for (int i = nb - 1; i >= 0; --i)
+    for (int i = nb - 1; i >= 0; --i) {
         resizeColumnToContents(i);
+    }
 }
 
 void SKGTreeView::showHeaderMenu()
@@ -365,7 +420,9 @@ void SKGTreeView::showHeaderMenu()
 
 void SKGTreeView::showHeaderMenu(const QPoint& iPos)
 {
-    if (m_headerMenu) m_headerMenu->popup(header()->mapToGlobal(iPos));
+    if (m_headerMenu) {
+        m_headerMenu->popup(header()->mapToGlobal(iPos));
+    }
 }
 
 void SKGTreeView::setDefaultSaveParameters(SKGDocument* iDocument, const QString& iParameterName)
@@ -376,8 +433,10 @@ void SKGTreeView::setDefaultSaveParameters(SKGDocument* iDocument, const QString
 
 void SKGTreeView::setupHeaderMenu()
 {
-    SKGTRACEIN(10, "SKGTreeView::setupHeaderMenu");
-    if (m_model && m_model->isRefreshBlocked()) return;
+    SKGTRACEINFUNC(10);
+    if (m_model && m_model->isRefreshBlocked()) {
+        return;
+    }
 
     setCornerWidget(NULL);
     if (m_model && m_headerMenu) {
@@ -429,7 +488,9 @@ void SKGTreeView::setupHeaderMenu()
                 for (int i = 0; i < nbSchemas; ++i) {
                     SKGDocument::SKGModelTemplate schema = schemas.at(i);
                     QAction* act = viewAppearanceMenu->addAction(schema.name);
-                    if (!schema.icon.isEmpty()) act->setIcon(KIcon(schema.icon));
+                    if (!schema.icon.isEmpty()) {
+                        act->setIcon(KIcon(schema.icon));
+                    }
                     act->setData(schema.schema);
 
                     connect(act, SIGNAL(triggered(bool)), this, SLOT(changeSchema()));
@@ -469,10 +530,14 @@ void SKGTreeView::setupHeaderMenu()
                 QStringList values = col.split('|');
 
                 if (!m_autoResizeDone) {
-                    if (values.count() > 1) hHeader->setSectionHidden(idx, values.at(1) == "N");
+                    if (values.count() > 1) {
+                        hHeader->setSectionHidden(idx, values.at(1) == "N");
+                    }
                     if (values.count() > 2) {
                         int s = SKGServices::stringToInt(values.at(2));
-                        if (s > 0) hHeader->resizeSection(idx, s);
+                        if (s > 0) {
+                            hHeader->resizeSection(idx, s);
+                        }
                     }
                 }
 
@@ -503,21 +568,29 @@ void SKGTreeView::setupHeaderMenu()
             }
             m_autoResizeDone = true;
         }
-        if (groupby) connect(groupby, SIGNAL(triggered(QAction*)), this, SLOT(groupByChanged(QAction*)));
+        if (groupby) {
+            connect(groupby, SIGNAL(triggered(QAction*)), this, SLOT(groupByChanged(QAction*)));
+        }
         m_headerMenu->addSeparator();
 
         QAction* actExport = m_headerMenu->addAction(KIcon("document-export"), i18nc("Noun, user action", "Export..."));
         connect(actExport, SIGNAL(triggered(bool)), this, SLOT(onExport()));
 
-        if (m_autoResize) resizeColumnsToContentsDelayed();
+        if (m_autoResize) {
+            resizeColumnsToContentsDelayed();
+        }
     }
 }
 
 void SKGTreeView::setSelectionModel(QItemSelectionModel* iSelectionModel)
 {
-    if (this->selectionModel()) disconnect(this->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+    if (this->selectionModel()) {
+        disconnect(this->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+    }
     QTreeView::setSelectionModel(iSelectionModel);
-    if (iSelectionModel) connect(iSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+    if (iSelectionModel) {
+        connect(iSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+    }
 }
 
 void SKGTreeView::onSelectionChanged()
@@ -554,8 +627,9 @@ void SKGTreeView::switchAutoResize()
 {
     m_autoResize = m_actAutoResize->isChecked();
     header()->setResizeMode(m_autoResize ? QHeaderView::Fixed : QHeaderView::Interactive);
-    if (m_autoResize) resizeColumnsToContentsDelayed();
-    else {
+    if (m_autoResize) {
+        resizeColumnsToContentsDelayed();
+    } else {
         m_timerDelayedResize.stop();
         m_autoResizeDone = false;
     }
@@ -563,19 +637,27 @@ void SKGTreeView::switchAutoResize()
 
 void SKGTreeView::groupByChanged(QAction* iAction)
 {
-    if (m_model && m_model->isRefreshBlocked()) return;
+    if (m_model && m_model->isRefreshBlocked()) {
+        return;
+    }
 
     if (iAction && m_model) {
         m_groupby = iAction->data().toString();;
         QString att = m_groupby;
-        if (att == "#" && m_proxyModel) att = m_model->getAttribute(m_proxyModel->sortColumn());
+        if (att == "#" && m_proxyModel) {
+            att = m_model->getAttribute(m_proxyModel->sortColumn());
+        }
         m_model->setGroupBy(att);
         m_model->refresh();
 
         bool treeMode = !m_model->getParentChildAttribute().isEmpty();
         setRootIsDecorated(treeMode && m_groupby.isEmpty());
-        if (m_actExpandAll) m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
-        if (m_actCollapseAll) m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+        if (m_actExpandAll) {
+            m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
+        }
+        if (m_actCollapseAll) {
+            m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
+        }
     }
 }
 
@@ -601,7 +683,9 @@ void SKGTreeView::showHideColumn()
         hHeader->setSectionHidden(idx, hidden);
 
         m_model->setSupportedAttributes(getCurrentSchema());
-        if (!hidden) resizeColumnToContents(idx);
+        if (!hidden) {
+            resizeColumnToContents(idx);
+        }
 
         m_model->dataModified();
     }
@@ -613,7 +697,9 @@ void SKGTreeView::resetColumnsOrder()
     int nbcol = hHeader->count();
     for (int i = 0; i < nbcol; ++i) {
         int idx = hHeader->visualIndex(i);
-        if (idx != i) hHeader->moveSection(idx, i);
+        if (idx != i) {
+            hHeader->moveSection(idx, i);
+        }
     }
 }
 
@@ -622,7 +708,9 @@ void SKGTreeView::changeSchema()
     QStringList list;
 
     QAction* send = static_cast<QAction*>(this->sender());
-    if (send)  list = SKGServices::splitCSVLine(send->data().toString(), ';');
+    if (send) {
+        list = SKGServices::splitCSVLine(send->data().toString(), ';');
+    }
 
     if (m_model) {
         // Reset column oder
@@ -679,7 +767,7 @@ int SKGTreeView::getNbSelectedObjects()
 
 void SKGTreeView::saveSelection()
 {
-    SKGTRACEIN(10, "SKGTreeView::saveSelection");
+    SKGTRACEINFUNC(10);
 
     m_selection.clear();
 
@@ -697,7 +785,7 @@ void SKGTreeView::saveSelection()
 
 void SKGTreeView::selectObject(const QString& iUniqueID)
 {
-    SKGTRACEIN(10, "SKGTreeView::selectObject");
+    SKGTRACEINFUNC(10);
     QStringList tmp;
     tmp.push_back(iUniqueID);
     selectObjects(tmp, true);
@@ -705,7 +793,7 @@ void SKGTreeView::selectObject(const QString& iUniqueID)
 
 void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirstOne)
 {
-    SKGTRACEIN(10, "SKGTreeView::selectObjects");
+    SKGTRACEINFUNC(10);
     SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << endl;
     int nbset = 0;
     QItemSelectionModel* selModel = selectionModel();
@@ -774,7 +862,7 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
 
 void SKGTreeView::resetSelection()
 {
-    SKGTRACEIN(10, "SKGTreeView::resetSelection");
+    SKGTRACEINFUNC(10);
 
     selectObjects(m_selection);
 }
@@ -786,14 +874,16 @@ void SKGTreeView::scroolOnSelection()
     if (selModel) {
         if (m_model) {
             QModelIndexList indexes = selModel->selectedRows();
-            if (indexes.count()) scrollTo(indexes.at(0));
+            if (indexes.count()) {
+                scrollTo(indexes.at(0));
+            }
         }
     }
 }
 
 void SKGTreeView::onExpand(const QModelIndex& index)
 {
-    SKGTRACEIN(10, "SKGTreeView::onExpand");
+    SKGTRACEINFUNC(10);
     if (index.isValid() && m_model) {
         QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
 
@@ -802,20 +892,24 @@ void SKGTreeView::onExpand(const QModelIndex& index)
         m_expandedNodes.push_back(id);
     }
 
-    if (m_autoResize) resizeColumnsToContentsDelayed();
+    if (m_autoResize) {
+        resizeColumnsToContentsDelayed();
+    }
 }
 
 void SKGTreeView::expandAll()
 {
-    SKGTRACEIN(10, "SKGTreeView::onExpandAll");
+    SKGTRACEINFUNC(10);
     QTreeView::expandAll();
 
-    if (m_autoResize) resizeColumnsToContentsDelayed();
+    if (m_autoResize) {
+        resizeColumnsToContentsDelayed();
+    }
 }
 
 void SKGTreeView::onCollapse(const QModelIndex& index)
 {
-    SKGTRACEIN(10, "SKGTreeView::onCollapse");
+    SKGTRACEINFUNC(10);
     if (index.isValid() && m_model) {
         QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
 
@@ -825,12 +919,14 @@ void SKGTreeView::onCollapse(const QModelIndex& index)
         m_expandedNodes.removeOne(id);
     }
 
-    if (m_autoResize) resizeColumnsToContentsDelayed();
+    if (m_autoResize) {
+        resizeColumnsToContentsDelayed();
+    }
 }
 
 void SKGTreeView::onClick(const QModelIndex& index)
 {
-    SKGTRACEIN(10, "SKGTreeView::onClick");
+    SKGTRACEINFUNC(10);
     if (index.isValid() && m_actExpandAll && m_actExpandAll->isVisible()) {
         this->setExpanded(index, !this->isExpanded(index));
     }
@@ -842,7 +938,9 @@ void SKGTreeView::copy()
     if (selection) {
         QModelIndexList indexes = selection->selectedIndexes();
 
-        if (indexes.size() < 1) return;
+        if (indexes.size() < 1) {
+            return;
+        }
 
         qSort(indexes.begin(), indexes.end());
 
@@ -854,13 +952,17 @@ void SKGTreeView::copy()
         QString selected_text;
         foreach(const QModelIndex & current, indexes) {
             selected_text.append(model()->data(previous).toString());
-            if (!header_done) header_text.append(model()->headerData(previous.column(), Qt::Horizontal).toString());
+            if (!header_done) {
+                header_text.append(model()->headerData(previous.column(), Qt::Horizontal).toString());
+            }
             if (current.row() != previous.row()) {
                 selected_text.append(QLatin1Char('\n'));
                 header_done = true;
             } else {
                 selected_text.append(QLatin1Char(';'));
-                if (!header_done) header_text.append(QLatin1Char(';'));
+                if (!header_done) {
+                    header_text.append(QLatin1Char(';'));
+                }
             }
             previous = current;
         }
@@ -884,7 +986,9 @@ void SKGTreeView::setZoomPosition(int iZoomPosition)
         this->setIconSize(QSize(newIconSize, newIconSize));
         header()->setIconSize(QSize(newIconSize, newIconSize));
 
-        if (m_autoResize) resizeColumnsToContentsDelayed();
+        if (m_autoResize) {
+            resizeColumnsToContentsDelayed();
+        }
 
         Q_EMIT zoomChanged(newZoomPos);
     }
@@ -913,7 +1017,9 @@ bool SKGTreeView::eventFilter(QObject* object, QEvent* iEvent)
         if (kevent) {
             if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
-                if (iEvent) iEvent->accept();
+                if (iEvent) {
+                    iEvent->accept();
+                }
                 return true;  // stop the process
             }
         }
@@ -943,8 +1049,8 @@ void SKGTreeView::setTextResizable(bool resizable)
 KTextBrowser* SKGTreeView::getTextBrowser() const
 {
     KTextBrowser* output = new KTextBrowser();
-    QTextCursor cursor = output->textCursor();
-    cursor.beginEditBlock();
+    QTextCursor tcursor = output->textCursor();
+    tcursor.beginEditBlock();
 
     // Create table format
     QTextTableFormat tableFormat;
@@ -959,22 +1065,22 @@ KTextBrowser* SKGTreeView::getTextBrowser() const
     int nbRows = table.count();
     int nbCol = table.at(0).count();
 
-    QTextTable* tableau = cursor.insertTable(nbRows, nbCol, tableFormat);
+    QTextTable* tableau = tcursor.insertTable(nbRows, nbCol, tableFormat);
 
-    //Create frame
-    QTextFrame* frame = cursor.currentFrame();
+    // Create frame
+    QTextFrame* frame = tcursor.currentFrame();
     QTextFrameFormat frameFormat = frame->frameFormat();
     frameFormat.setBorder(0);
     frame->setFrameFormat(frameFormat);
 
     // Create header table format
     QTextCharFormat headerFormat;
-    headerFormat.setFontPointSize(15);
+    headerFormat.setFontPointSize(6);
     headerFormat.setFontWeight(QFont::Bold);
 
     // Create text format
     QTextCharFormat textFormat;
-    textFormat.setFontPointSize(12);
+    textFormat.setFontPointSize(6);
 
     // Create header
     for (int r = 0; r < nbRows; ++r) {
@@ -986,12 +1092,11 @@ KTextBrowser* SKGTreeView::getTextBrowser() const
     }
 
     // End
-    cursor.endEditBlock();
+    tcursor.endEditBlock();
 
     return output;
 }
 
-
 SKGStringListList SKGTreeView::getTable(const QModelIndex& iIndex) const
 {
     // Build table
@@ -1039,14 +1144,15 @@ SKGStringListList SKGTreeView::getTable(const QModelIndex& iIndex) const
 SKGError SKGTreeView::exportInFile(const QString& iFileName)
 {
     SKGError err;
-    _SKGTRACEIN(10, "SKGTreeView::exportInFile");
+    _SKGTRACEINFUNC(10);
     QString codec = QTextCodec::codecForLocale()->name();
     QString extension = QFileInfo(iFileName).suffix().toUpper();
     if (extension == "CSV") {
         // Write file
         KSaveFile file(iFileName);
-        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
-        else {
+        if (!file.open()) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
+        } else {
             QTextStream out(&file);
             out.setCodec(codec.toAscii().constData());
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_CSV);
@@ -1094,8 +1200,9 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
     } else if (extension == "HTML") {
         // Write file
         KSaveFile file(iFileName);
-        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
-        else {
+        if (!file.open()) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
+        } else {
             QTextStream out(&file);
             out.setCodec(codec.toAscii().constData());
             KTextBrowser* tb = getTextBrowser();
@@ -1123,8 +1230,9 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
     } else {
         // Write file
         KSaveFile file(iFileName);
-        if (!file.open()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
-        else {
+        if (!file.open()) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Save file '%1' failed" , iFileName));
+        } else {
             QTextStream out(&file);
             out.setCodec(codec.toAscii().constData());
             QStringList dump = SKGServices::tableToDump(getTable(), SKGServices::DUMP_TEXT);
@@ -1145,7 +1253,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
 
 void SKGTreeView::onExport()
 {
-    _SKGTRACEIN(10, "SKGTreeView::onExport");
+    _SKGTRACEINFUNC(10);
     QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "text/csv text/plain text/html application/vnd.oasis.opendocument.text  image/svg+xml application/pdf" , this);
     if (!fileName.isEmpty()) {
         SKGError err = exportInFile(fileName);
@@ -1159,7 +1267,9 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
     if (iModel != this->model()) {
         m_model = static_cast<SKGObjectModelBase*>(iModel);
         m_proxyModel = qobject_cast<QSortFilterProxyModel*> (iModel);
-        if (m_proxyModel) m_model = static_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
+        if (m_proxyModel) {
+            m_model = static_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
+        }
 
         if (m_model) {
             connect(m_model, SIGNAL(afterReset()), this, SLOT(setupHeaderMenu()));
