@@ -65,12 +65,15 @@ QList< SKGServices::SKGSearchCriteria > SKGServices::stringToSearchCriterias(con
         bool isWordStartingByLess = word.startsWith(QLatin1String("-"));
         if (isWordStartingByPlus || isWordStartingByLess) {
             QChar nextChar;
-            if (word.count() > 1) nextChar = word[1];
+            if (word.count() > 1) {
+                nextChar = word[1];
+            }
             if (nextChar < '0' || nextChar > '9') {
                 word = word.right(word.length() - 1);
                 if (Q_LIKELY(i != 0)) {
-                    if (criteria.mode == '-') output.push_back(criteria);
-                    else {
+                    if (criteria.mode == '-') {
+                        output.push_back(criteria);
+                    } else {
                         output.push_front(criteria);
                         atLeastOnePlus = true;
                     }
@@ -81,8 +84,9 @@ QList< SKGServices::SKGSearchCriteria > SKGServices::stringToSearchCriterias(con
         }
         criteria.words.push_back(word);
     }
-    if (criteria.mode == '-') output.push_back(criteria);
-    else {
+    if (criteria.mode == '-') {
+        output.push_back(criteria);
+    } else {
         output.push_front(criteria);
         atLeastOnePlus = true;
     }
@@ -112,7 +116,9 @@ QString SKGServices::intToString(qlonglong iNumber)
 
 qlonglong SKGServices::stringToInt(const QString& iNumber)
 {
-    if (Q_UNLIKELY(iNumber.isEmpty())) return 0;
+    if (Q_UNLIKELY(iNumber.isEmpty())) {
+        return 0;
+    }
 
     bool ok;
     qlonglong output = iNumber.toLongLong(&ok);
@@ -158,7 +164,9 @@ QString SKGServices::stringsToCsv(const QStringList& iList, const QChar& iSepara
     int nb = iList.count();
     for (int i = 0; i < nb; ++i) {
         output.append(SKGServices::stringToCsv(iList.at(i)));
-        if (Q_LIKELY(i < nb - 1)) output.append(iSeparator);
+        if (Q_LIKELY(i < nb - 1)) {
+            output.append(iSeparator);
+        }
     }
 
     return output;
@@ -175,8 +183,9 @@ QString SKGServices::stringToCsv(const QString& iNumber)
 
 double SKGServices::stringToDouble(const QString& iNumber)
 {
-    if (Q_UNLIKELY(iNumber.isEmpty() || iNumber == "nan")) return 0;
-    else if (Q_UNLIKELY(iNumber == "inf")) {
+    if (Q_UNLIKELY(iNumber.isEmpty() || iNumber == "nan")) {
+        return 0;
+    } else if (Q_UNLIKELY(iNumber == "inf")) {
         return 1e300;
     } else if (Q_UNLIKELY(iNumber == "-inf")) {
         return -1e300;
@@ -187,7 +196,9 @@ double SKGServices::stringToDouble(const QString& iNumber)
         // Use script engine
         QScriptEngine myEngine;
         QScriptValue result = myEngine.evaluate(number);
-        if (result.isNumber()) return result.toNumber();
+        if (result.isNumber()) {
+            return result.toNumber();
+        }
     }
 
     bool ok;
@@ -195,12 +206,16 @@ double SKGServices::stringToDouble(const QString& iNumber)
     if (Q_LIKELY(!ok)) {
         QString tmp = number;
         tmp.replace(',', '.');
-        if (tmp.count('.') > 1) tmp.remove(tmp.indexOf('.'), 1);
+        if (tmp.count('.') > 1) {
+            tmp.remove(tmp.indexOf('.'), 1);
+        }
         output = tmp.toDouble(&ok);
         if (Q_LIKELY(!ok)) {
             QString tmp2 = number;
             tmp2.replace('.', ',');
-            if (tmp2.count(',') > 1) tmp2.remove(tmp2.indexOf(','), 1);
+            if (tmp2.count(',') > 1) {
+                tmp2.remove(tmp2.indexOf(','), 1);
+            }
             output = tmp2.toDouble(&ok);
             if (!ok) {
                 QString tmp3 = number;
@@ -222,17 +237,51 @@ QString SKGServices::doubleToString(double iNumber)
     return output;
 }
 
+QString SKGServices::dateToPeriod(const QDate& iDate, const QString& iPeriod)
+{
+    QString period;
+    if (iPeriod == "D") {
+        // Day
+        period = iDate.toString("yyyy-MM-dd");
+    } else if (iPeriod == "W") {
+        // Week
+        period = iDate.toString("yyyy-W") %  SKGServices::intToString(iDate.weekNumber());
+    } else if (iPeriod == "M") {
+        // Month
+        period = iDate.toString("yyyy-MM");
+    } else if (iPeriod == "Q") {
+        // Quarter
+        period = iDate.toString("yyyy-Q") % (iDate.month() <= 3 ? '1' : (iDate.month() <= 6 ? '2' : (iDate.month() <= 9 ? '3' : '4')));
+    } else if (iPeriod == "S") {
+        // Semester
+        period = iDate.toString("yyyy-S") % (iDate.month() <= 6 ? '1' : '2');;
+    } else if (iPeriod == "Y") {
+        // Year
+        period = iDate.toString("yyyy");
+    }
+    return period;
+}
+
 QString SKGServices::timeToString(const QDateTime& iDateTime)
 {
     QDateTime d = iDateTime;
-    if (Q_UNLIKELY(!d.isValid())) d = QDateTime::currentDateTime();
+    if (Q_UNLIKELY(!d.isValid())) {
+        d = QDateTime::currentDateTime();
+    }
     return d.toString("yyyy-MM-dd HH:mm:ss");
 }
 
+QString SKGServices::dateToSqlString(const QDate& iDateTime)
+{
+    return dateToSqlString(QDateTime(iDateTime));
+}
+
 QString SKGServices::dateToSqlString(const QDateTime& iDateTime)
 {
     QDateTime d = iDateTime;
-    if (Q_UNLIKELY(!d.isValid())) d = QDateTime::currentDateTime();
+    if (Q_UNLIKELY(!d.isValid())) {
+        d = QDateTime::currentDateTime();
+    }
     return d.toString("yyyy-MM-dd");
 }
 
@@ -243,10 +292,14 @@ int SKGServices::nbWorkingDays(const QDate& iFrom, const QDate& iTo)
     QDate max = (iFrom < iTo ? iTo : iFrom);
 
     while (min != max) {
-        if (min.dayOfWeek() <= 5) ++nb;
+        if (min.dayOfWeek() <= 5) {
+            ++nb;
+        }
         min = min.addDays(1);
     }
-    if (nb == 0) nb = 1;
+    if (nb == 0) {
+        nb = 1;
+    }
     return nb;
 }
 
@@ -273,8 +326,9 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
         QChar c = iString.at(pos);
         if (isInBlock) {
             if (c == cote) {
-                if (pos < nb - 1 && iString.at(pos + 1) == cote) ++pos;
-                else {
+                if (pos < nb - 1 && iString.at(pos + 1) == cote) {
+                    ++pos;
+                } else {
                     items.push_back(item);
                     item = "";
                     isInBlock = false;
@@ -284,13 +338,19 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
                     // 320112 ^^^^
 
                     ++pos;  // To ignore next separator
-                    if (pos < nb) realSeparator = iString.at(pos);  // To get the real separator
+                    if (pos < nb) {
+                        realSeparator = iString.at(pos);    // To get the real separator
+                    }
                 }
             }
 
-            if (isInBlock) item += c;
+            if (isInBlock) {
+                item += c;
+            }
         } else  if ((c == '\"' || c == '\'') && item.count() == 0 &&  iCoteDefineBlock) {
-            if (cote == ' ') cote = c;  // Set the real cote char
+            if (cote == ' ') {
+                cote = c;    // Set the real cote char
+            }
             isInBlock = true;
         } else  if (QString(c) == realSeparator) {
             items.push_back(item);
@@ -305,18 +365,24 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
         }
     }
 
-    if (!item.isEmpty() || (nb > 0 && iString.at(nb - 1) == realSeparator)) items.push_back(item);
+    if (!item.isEmpty() || (nb > 0 && iString.at(nb - 1) == realSeparator)) {
+        items.push_back(item);
+    }
 
-    if (oRealSeparator) *oRealSeparator = realSeparator;
+    if (oRealSeparator) {
+        *oRealSeparator = realSeparator;
+    }
 
-    if (isInBlock) items.clear();
+    if (isInBlock) {
+        items.clear();
+    }
 
     return items;
 }
 
 QString SKGServices::getDateFormat(const QStringList& iDates)
 {
-    SKGTRACEIN(2, "SKGServices::getDateFormat");
+    SKGTRACEINFUNC(2);
     bool f_YYYY_MM_DD = true;
     bool f_YYYYMMDD = true;
     bool f_DDMMYYYY = true;
@@ -325,6 +391,9 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     bool f_DD_MM_YY = true;
     bool f_MM_DD_YYYY = true;
     bool f_DD_MM_YYYY = true;
+    bool f_DDMMMYYYY = true;
+    bool f_DD_MMM_YY = true;
+    bool f_DD_MMM_YYYY = true;
 
     // Build regexp
     QRegExp rx("(.+)-(.+)-(.+)");
@@ -333,6 +402,9 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     int nb = iDates.count();
     for (int i = 0; i < nb; ++i) {
         QString val = iDates.at(i).trimmed();
+        if (val.count() > 10) {
+            val = SKGServices::splitCSVLine(val, ' ')[0];
+        }
         if (!val.isEmpty()) {
             val = val.replace(' ', '0');
             val = val.replace('\\', '-');
@@ -357,6 +429,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
                 f_DD_MM_YY = false;
                 f_MM_DD_YYYY = false;
                 f_DD_MM_YYYY = false;
+                f_DD_MMM_YY = false;
+                f_DD_MMM_YYYY = false;
 
                 if (val.length() == 8) {
                     int left2 = SKGServices::stringToInt(val.left(2));
@@ -384,11 +458,23 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
                     if (right2 > 31) {
                         f_YYYYMMDD = false;
                     }
+
+                    f_DDMMMYYYY = false;
+                } else if (val.length() == 9) {
+                    f_MMDDYYYY = false;
+                    f_DDMMYYYY = false;
+                    f_YYYYMMDD = false;
+                } else {
+                    f_MMDDYYYY = false;
+                    f_DDMMYYYY = false;
+                    f_YYYYMMDD = false;
+                    f_DDMMMYYYY = false;
                 }
             } else {
                 f_YYYYMMDD = false;
                 f_DDMMYYYY = false;
                 f_MMDDYYYY = false;
+                f_DDMMMYYYY = false;
 
                 QString v1 = rx.cap(1);
                 QString v2 = rx.cap(2);
@@ -404,6 +490,19 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
                     f_DD_MM_YYYY = false;
                 }
 
+                if (v2.length() > 2) {
+                    f_MM_DD_YY = false;
+                    f_MM_DD_YYYY = false;
+                    f_DD_MM_YY = false;
+                    f_DD_MM_YYYY = false;
+                    f_YYYY_MM_DD = false;
+                }
+
+                if (v2.length() != 3) {
+                    f_DD_MMM_YYYY = false;
+                    f_DD_MMM_YY = false;
+                }
+
                 if (SKGServices::stringToInt(v1) > 31 || SKGServices::stringToInt(v2) > 31) {
                     f_MM_DD_YY = false;
                     f_MM_DD_YYYY = false;
@@ -436,8 +535,9 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
         }
     }
 
-    if (f_YYYYMMDD) return "YYYYMMDD";
-    else if (f_MMDDYYYY) {
+    if (f_YYYYMMDD) {
+        return "YYYYMMDD";
+    } else if (f_MMDDYYYY) {
         return "MMDDYYYY";
     } else if (f_DDMMYYYY) {
         return "DDMMYYYY";
@@ -445,7 +545,9 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
         KLocale* loc = KGlobal::locale();
         if (loc) {
             QString sFormat = loc->dateFormatShort();
-            if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YY";
+            if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) {
+                return "MM-DD-YY";
+            }
         }
         return "DD-MM-YY";
     } else if (f_MM_DD_YY) {
@@ -456,7 +558,9 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
         KLocale* loc = KGlobal::locale();
         if (loc) {
             QString sFormat = loc->dateFormatShort();
-            if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) return "MM-DD-YYYY";
+            if (sFormat.startsWith(QLatin1String("%m")) || sFormat.startsWith(QLatin1String("%n"))) {
+                return "MM-DD-YYYY";
+            }
         }
         return "DD-MM-YYYY";
     } else if (f_MM_DD_YYYY) {
@@ -465,6 +569,12 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
         return "DD-MM-YYYY";
     } else if (f_YYYY_MM_DD) {
         return "YYYY-MM-DD";
+    } else if (f_DDMMMYYYY) {
+        return "DDMMMYYYY";
+    } else if (f_DD_MMM_YY) {
+        return "DD-MMM-YY";
+    } else if (f_DD_MMM_YYYY) {
+        return "DD-MMM-YYYY";
     }
 
     return "";
@@ -473,7 +583,11 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
 QString SKGServices::dateToSqlString(const QString& iDate, const QString& iFormat)
 {
     QString input = iDate;
+    if (input.count() > 10) {
+        input = SKGServices::splitCSVLine(input, ' ')[0];
+    }
 
+    QString format = "yyyy-MM-dd";
     QString YYYY = "0000";
     QString MM = "00";
     QString DD = "00";
@@ -481,19 +595,22 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
         YYYY = input.mid(0, 4);
         MM = input.mid(4, 2);
         DD = input.mid(6, 2);
-    }
-    if (iFormat == "DDMMYYYY" || iFormat == "DDMMYY") {
+    } else if (iFormat == "DDMMYYYY" || iFormat == "DDMMYY") {
         YYYY = input.mid(4, 4);
         MM = input.mid(2, 2);
         DD = input.mid(0, 2);
-    }
-    if (iFormat == "MMDDYYYY" || iFormat == "MMDDYY") {
+    } else if (iFormat == "DDMMMYYYY" || iFormat == "DDMMMYY") {
+        YYYY = input.mid(5, 4);
+        MM = input.mid(2, 3);
+        DD = input.mid(0, 2);
+        format = "yyyy-MMM-dd";
+    } else if (iFormat == "MMDDYYYY" || iFormat == "MMDDYY") {
         YYYY = input.mid(4, 4);
         MM = input.mid(0, 2);
         DD = input.mid(2, 2);
 
     } else {
-        QString val = iDate;
+        QString val = input;
         val = val.replace(' ', '0');
         val = val.replace('\\', '-');
         val = val.replace('/', '-');
@@ -528,28 +645,115 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
                 DD = v1;
                 MM = v2;
                 YYYY = v3;
+            } else if (iFormat == "DD/MMM/YY" || iFormat == "DD-MMM-YY" || iFormat == "DD/MMM/YYYY" || iFormat == "DD-MMM-YYYY") {
+                DD = v1;
+                MM = v2;
+                YYYY = v3;
+                format = "yyyy-MMM-dd";
             }
         }
     }
 
-    if (MM.length() == 1) MM = '0' % MM;
-    if (DD.length() == 1) DD = '0' % DD;
-    if (YYYY.length() == 1) YYYY = '0' % YYYY;
+    if (MM.length() == 1) {
+        MM = '0' % MM;
+    }
+    if (DD.length() == 1) {
+        DD = '0' % DD;
+    }
+    if (YYYY.length() == 1) {
+        YYYY = '0' % YYYY;
+    }
     if (YYYY.length() == 2) {
-        if (stringToInt(YYYY) > 70) YYYY = "19" % YYYY;
-        else {
+        if (stringToInt(YYYY) > 70) {
+            YYYY = "19" % YYYY;
+        } else {
             YYYY = "20" % YYYY;
         }
     }
 
     QString date = YYYY % '-' % MM % '-' % DD;
     date.replace(' ', '0');
-    return dateToSqlString(QDateTime::fromString(date, "yyyy-MM-dd"));
+    return dateToSqlString(QDateTime::fromString(date, format));
+}
+
+QString SKGServices::getPeriodWhereClause(const QString& iPeriod, const QString& iDateAttribute)
+{
+    QString output;
+    if (iPeriod.length() == 4) {
+        // 2014
+        output = "STRFTIME('%Y'," + SKGServices::stringToSqlString(iDateAttribute) + ")='" + SKGServices::stringToSqlString(iPeriod) + '\'';
+    } else if (iPeriod.length() >= 7) {
+        if (iPeriod[5] == 'S') {
+            // 2014-S1
+            output = "STRFTIME('%Y'," + SKGServices::stringToSqlString(iDateAttribute) + ")||'-S'||(CASE WHEN STRFTIME('%m'," + SKGServices::stringToSqlString(iDateAttribute) + ")<='06' THEN '1' ELSE '2' END)='" + SKGServices::stringToSqlString(iPeriod) + '\'';
+        } else if (iPeriod[5] == 'Q') {
+            // 2014-Q1
+            output = "STRFTIME('%Y'," + SKGServices::stringToSqlString(iDateAttribute) + ")||'-Q'||(CASE WHEN STRFTIME('%m'," + SKGServices::stringToSqlString(iDateAttribute) + ")<='03' THEN '1' WHEN STRFTIME('%m'," + SKGServices::stringToSqlString(iDateAttribute) + ")<='06' THEN '2' WHEN STRFTIME('%m'," + SKGServices::stringToSqlString(iDateAttribute) + ")<='09' THEN '3' ELSE '4' END)='" + SKGServices::stringToSqlString(iPeriod) + '\'';
+        } else {
+            // 2014-07
+            output = "STRFTIME('%Y-%m'," + SKGServices::stringToSqlString(iDateAttribute) + ")='" + SKGServices::stringToSqlString(iPeriod) + '\'';
+        }
+    }
+    return output;
+}
+
+QDate SKGServices::periodToDate(const QString& iPeriod)
+{
+    QDate output;
+    if (iPeriod.length() == 4) {
+        // 2014
+        output = QDate::fromString(iPeriod, "yyyy").addYears(1).addDays(-1);
+    } else if (iPeriod.length() >= 7) {
+        if (iPeriod[5] == 'S') {
+            // 2014-S1
+            output = QDate::fromString(iPeriod, "yyyy-SM");
+            output = output.addMonths(output.month() * 6 - output.month());  // convert semester in month
+            output = output.addMonths(1).addDays(-1);
+        } else if (iPeriod[5] == 'Q') {
+            // 2014-Q1
+            output = QDate::fromString(iPeriod, "yyyy-QM");
+            output = output.addMonths(output.month() * 3 - output.month());  // convert quater in month
+            output = output.addMonths(1).addDays(-1);
+        } else {
+            // 2014-07
+            output = QDate::fromString(iPeriod, "yyyy-MM").addMonths(1).addDays(-1);
+        }
+    }
+    return output;
+}
+
+QString SKGServices::getPerviousPeriod(const QString& iPeriod)
+{
+    QString output;
+    if (iPeriod.length() == 4) {
+        // 2014
+        QDate date = QDate::fromString(iPeriod, "yyyy").addDays(-1);
+        output = date.toString("yyyy");
+    } else if (iPeriod.length() >= 7) {
+        if (iPeriod[5] == 'S') {
+            // 2014-S1
+            QDate date2 = QDate::fromString(iPeriod, "yyyy-SM");
+            date2 = date2.addMonths(date2.month() * 6 - date2.month());  // convert semester in month
+            date2 = date2.addMonths(-6);
+            output = date2.toString("yyyy-S") % (date2.month() <= 6 ? '1' : '2');
+        } else if (iPeriod[5] == 'Q') {
+            // 2014-Q1
+            QDate date2 = QDate::fromString(iPeriod, "yyyy-QM");
+            date2 = date2.addMonths(date2.month() * 3 - date2.month());  // convert quater in month
+            date2 = date2.addMonths(-3);
+            output = date2.toString("yyyy-Q") % (date2.month() <= 3 ? '1' : (date2.month() <= 6 ? '2' : (date2.month() <= 9 ? '3' : '4')));
+        } else {
+            // 2014-07
+            QDate date2 = QDate::fromString(iPeriod, "yyyy-MM").addDays(-1);
+            output = date2.toString("yyyy-MM");
+        }
+    }
+    return output;
 }
 
 QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGServices::DumpMode iMode)
 {
-    SKGTRACEIN(10, "SKGServices::tableToDump");
+    SKGTRACEINFUNC(10);
     // initialisation
     QStringList oResult;
 
@@ -573,7 +777,9 @@ QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGService
             int nb2 = line.size();
             for (int j = 0; j < nb2; ++j) {
                 QString s = line.at(j);
-                if (s.length() > maxSizes[j]) maxSizes[j] = s.length();
+                if (s.length() > maxSizes[j]) {
+                    maxSizes[j] = s.length();
+                }
             }
         }
     }
@@ -593,7 +799,9 @@ QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGService
             s.remove('\n');
 
             if (iMode == DUMP_CSV) {
-                if (j > 0) lineFormated += ';';
+                if (j > 0) {
+                    lineFormated += ';';
+                }
                 lineFormated += stringToCsv(s);
             } else {
                 s = s.leftJustified(maxSizes[j], ' ');
@@ -619,7 +827,9 @@ QString SKGServices::getRealTable(const QString& iTable)
         output = output.mid(2, output.length() - 2);
 
         int pos = output.indexOf("_");
-        if (pos != -1) output = output.left(pos);
+        if (pos != -1) {
+            output = output.left(pos);
+        }
     }
 
     return output;
@@ -628,14 +838,15 @@ QString SKGServices::getRealTable(const QString& iTable)
 SKGError SKGServices::downloadToStream(const KUrl& iSourceUrl, QByteArray& oStream)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGServices::downloadToStream", err);
+    SKGTRACEINFUNCRC(10, err);
     QString tmpFile;
     err = download(iSourceUrl, tmpFile);
     IFOK(err) {
         // Open file
         QFile file(tmpFile);
-        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
-        else {
+        if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
+            err.setReturnCode(ERR_FAIL).setMessage(i18nc("An information message", "Open file '%1' failed", tmpFile));
+        } else {
             oStream = file.readAll();
 
             // close file
@@ -649,7 +860,7 @@ SKGError SKGServices::downloadToStream(const KUrl& iSourceUrl, QByteArray& oStre
 SKGError SKGServices::download(const KUrl& iSourceUrl, QString& oTemporaryFile)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGServices::download", err);
+    SKGTRACEINFUNCRC(10, err);
     QTemporaryFile tmpFile;
     tmpFile.setAutoRemove(false);
     if (tmpFile.open()) {
@@ -662,11 +873,13 @@ SKGError SKGServices::download(const KUrl& iSourceUrl, QString& oTemporaryFile)
 SKGError SKGServices::upload(const KUrl& iSourceUrl, const KUrl& iDescUrl)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGServices::upload", err);
+    SKGTRACEINFUNCRC(10, err);
     if (iDescUrl != iSourceUrl) {
         KIO::Job* getJob = KIO::file_copy(iSourceUrl, iDescUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
         // getJob->ui()->setWindow(window);
-        if (!KIO::NetAccess::synchronousRun(getJob, 0)) err.setReturnCode(ERR_ABORT).setMessage(getJob->errorString());
+        if (!KIO::NetAccess::synchronousRun(getJob, 0)) {
+            err.setReturnCode(ERR_ABORT).setMessage(getJob->errorString());
+        }
     }
     return err;
 }
@@ -674,7 +887,7 @@ SKGError SKGServices::upload(const KUrl& iSourceUrl, const KUrl& iDescUrl)
 SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFileTarget, const QString& iPassword, bool iEncrypt, const QString& iHeaderFile)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGServices::cryptFile", err);
+    SKGTRACEINFUNCRC(10, err);
     SKGTRACEL(10) << "Input parameter [iFileSource]=[" << iFileSource << ']' << endl;
     SKGTRACEL(10) << "Input parameter [iFileTarget]=[" << iFileTarget << ']' << endl;
     SKGTRACEL(10) << "Input parameter [iPassword]  =[" << iPassword << ']' << endl;
@@ -689,11 +902,6 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
         // Create a random key - you'd probably use one from another
         // source in a real application
         QCA::SymmetricKey key(QByteArray("skrooge"));
-
-        // Create a random initialisation vector - you need this
-        // value to decrypt the resulting cipher text, but it
-        // need not be kept secret (unlike the key).
-        QCA::InitializationVector iv(iPassword.toAscii());
         QCA::Cipher* cipher = NULL;
 
         // Read document
@@ -711,30 +919,35 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                         iEncrypt ? QCA::Encode : QCA::Decode,
                         key, iv);
 
-
-            QByteArray h = (iHeaderFile % (!cipher ? "_DECRYPTED-" : "_ENCRYPTED-")).toLatin1();
             // BUG 249955 vvv
             if (!cipher && isFileEncrypted) {
                 err = SKGError(ERR_ENCRYPTION, i18nc("Error message about encrypting a file", "Encryption failed"));
             }
             // BUG 249955 ^^^
-            if (!iEncrypt && h.count() && input.startsWith(h)) {
-                input = input.right(input.length() - h.length());
-            }
 
-            // we use the cipher object to encrypt the argument we passed in
-            // the result of that is returned - note that if there is less than
-            // 16 bytes (1 block), then nothing will be returned - it is buffered
-            // update() can be called as many times as required.
+            // Suppress header
+            SKGTRACEL(10) << "input=[" << input.left(50) << "...]" << endl;
+            if (!iHeaderFile.isEmpty() && input.startsWith(iHeaderFile.toLatin1())) {
+                input = input.right(input.length() - iHeaderFile.length() - 11);
+            }
+            SKGTRACEL(10) << "input without header=[" << input.left(50) << "...]" << endl;
+
             QCA::SecureArray u;
             if (!err && cipher) {
-                u = cipher->update(input);
+                // Process encryption or decryption
+                u = cipher->process(input);
 
                 // We need to check if that update() call worked.
                 if (!cipher->ok()) {
                     err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
+                } else {
+                    // Check if decryption is OK
+                    if (!iEncrypt && u.toByteArray().left(15) != "SQLite format 3") {
+                        err = SKGError(ERR_ENCRYPTION, i18nc("Error message", "Wrong password"));
+                    }
                 }
             }
+            SKGTRACEL(10) << "output=[" << u.toByteArray().left(50) << "...]" << endl;
 
             // output the results of that stage
             IFOK(err) {
@@ -743,7 +956,8 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                     err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
                 } else {
                     // Write header
-                    if (iEncrypt && h.count()) {
+                    if (iEncrypt && !iHeaderFile.isEmpty()) {
+                        QByteArray h = (iHeaderFile % (cipher ? "_ENCRYPTED-" : "_DECRYPTED-")).toLatin1();
                         fileOutput.write(h);
                     }
 
@@ -752,24 +966,13 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                         fileOutput.write(input);
                     } else {
                         fileOutput.write(u.toByteArray());
-
-                        // Because we are using PKCS7 padding, we need to output the final (padded) block
-                        // Note that we should always call final() even with no padding, to clean up
-                        QCA::SecureArray f = cipher->final();
-
-                        // Check if the final() call worked
-                        if (!cipher->ok()) {
-                            err = SKGError(ERR_UNEXPECTED, i18nc("Error message about encrypting a file", "Encryption failed"));
-                        }
-
-                        // and output the resulting block. The ciphertext is the results of update()
-                        // and the result of final()
-                        fileOutput.write(f.toByteArray());
                     }
 
                     // Close the file
                     if (!fileOutput.finalize()) {
-                        err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
+                        IFOK(err) {
+                            err = SKGError(ERR_WRITEACCESS, i18nc("Error message: writing a file failed", "Write file '%1' failed", iFileTarget));
+                        }
                     }
                     fileOutput.close();
                 }
@@ -785,7 +988,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
 SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& oDocument)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGServices::copySqliteDatabaseToXml", err);
+    SKGTRACEINFUNCRC(10, err);
     if (iDb) {
         oDocument = QDomDocument("SKGML");
         QDomElement document = oDocument.createElement("document");
@@ -827,7 +1030,7 @@ SKGError SKGServices::copySqliteDatabaseToXml(QSqlDatabase* iDb, QDomDocument& o
 SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iMemoryDb, bool iFromFileToMemory)
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGServices::copySqliteDatabase", err);
+    SKGTRACEINFUNCRC(10, err);
     if (iFileDb && iMemoryDb) {
         SKGTRACEL(20) << "Input parameter [iFileDb]=[" << iFileDb->databaseName() << ']' << endl;
         SKGTRACEL(20) << "Input parameter [iMemoryDb]=[" << iMemoryDb->databaseName() << ']' << endl;
@@ -838,7 +1041,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         SKGStringListList listTables;
         int nb = 0;
         IFOK(err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTABLES", err);
+            SKGTRACEINFUNCRC(10, err);
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql, tbl_name FROM sqlite_master WHERE type='table' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
                     listTables);
@@ -851,13 +1054,13 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
         }
         // Attach db
         IFOK(err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-ATTACH", err);
+            SKGTRACEINFUNCRC(10, err);
             err = SKGServices::executeSqliteOrder(iMemoryDb, "ATTACH DATABASE '" % dbFileName % "' as source");
         }
 
         // Copy records
         IFOK(err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPY", err);
+            SKGTRACEINFUNCRC(10, err);
             err = SKGServices::executeSqliteOrder(iMemoryDb, "BEGIN");
             IFOK(err) {
                 for (int i = 1; !err && i < nb; ++i) {  // Forget header
@@ -874,7 +1077,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
 
         // Detach
         {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-DETACH", err);
+            SKGTRACEINFUNCRC(10, err);
             SKGError err2 = SKGServices::executeSqliteOrder(iMemoryDb, "DETACH DATABASE source");
             if (!err && err2) {
                 err = err2;
@@ -895,7 +1098,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
 
         // Copy the indexes
         IFOK(err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYINDEX", err);
+            SKGTRACEINFUNCRC(10, err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql FROM sqlite_master WHERE type='index' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
@@ -910,7 +1113,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
 
         // Copy the views
         IFOK(err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYVIEW", err);
+            SKGTRACEINFUNCRC(10, err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql FROM sqlite_master WHERE type='view' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
@@ -925,7 +1128,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
 
         // Copy the triggers, must be done after the views
         IFOK(err) {
-            SKGTRACEINRC(10, "SKGServices::copySqliteDatabase-COPYTRIGGER", err);
+            SKGTRACEINFUNCRC(10, err);
             SKGStringListList listSqlOrder;
             err = SKGServices::executeSelectSqliteOrder((iFromFileToMemory ? iFileDb : iMemoryDb),
                     "SELECT sql FROM sqlite_master WHERE type='trigger' AND sql NOT NULL and name NOT LIKE 'sqlite_%'",
@@ -952,7 +1155,7 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
 SKGError SKGServices::executeSqliteOrders(QSqlDatabase* iDb, const QStringList& iSqlOrders)
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGServices::executeSqliteOrder(QSqlDatabase)", err);
+    _SKGTRACEINFUNCRC(10, err);
     int nb = iSqlOrders.count();
     for (int i = 0; !err && i < nb; ++i) {
         err = SKGServices::executeSqliteOrder(iDb, iSqlOrders.at(i));
@@ -963,7 +1166,7 @@ SKGError SKGServices::executeSqliteOrders(QSqlDatabase* iDb, const QStringList&
 SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, const QMap<QString, QVariant>& iBind, int* iLastId)
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGServices::executeSqliteOrder(QSqlDatabase)", err);
+    _SKGTRACEINFUNCRC(10, err);
     SKGTRACEL(20) << "Input parameter [iSqlOrder]=[" << iSqlOrder << ']' << endl;
 
     if (iDb == NULL) {
@@ -973,7 +1176,9 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
         query.setForwardOnly(true);
 
         double elapse = 0;
-        if (SKGServices::SKGSqlTraces != -1)  elapse = SKGServices::getMicroTime();
+        if (SKGServices::SKGSqlTraces != -1) {
+            elapse = SKGServices::getMicroTime();
+        }
 
         // Prepare sql order
         bool prep = query.prepare(iSqlOrder);
@@ -995,9 +1200,13 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
             err = SKGError(SQLLITEERROR + sqlError.number(), iSqlOrder);
             err.addError(SQLLITEERROR + sqlError.number(), sqlError.text());
 
-            if (sqlError.number() == 19 && iSqlOrder.startsWith(QLatin1String("INSERT "))) err.addError(ERR_FAIL, i18nc("Error message", "Creation failed. The object already exists."));
+            if (sqlError.number() == 19 && iSqlOrder.startsWith(QLatin1String("INSERT "))) {
+                err.addError(ERR_FAIL, i18nc("Error message", "Creation failed. The object already exists."));
+            }
         } else {
-            if (iLastId) *iLastId = query.lastInsertId().toInt();
+            if (iLastId) {
+                *iLastId = query.lastInsertId().toInt();
+            }
         }
         if (SKGServices::SKGSqlTraces != -1) {
             elapse = SKGServices::getMicroTime() - elapse;
@@ -1017,7 +1226,7 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
 SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QTextStream* oStream, SKGServices::DumpMode iMode)
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(QSqlDatabase)", err);
+    _SKGTRACEINFUNCRC(10, err);
     SKGTRACEL(20) << "Input parameter [iSqlOrder]=[" << iSqlOrder << ']' << endl;
 
     // initialisation
@@ -1027,8 +1236,9 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
         // dump
         int nb = oResult.size();
         for (int i = 0; i < nb; ++i) {
-            if (oStream == NULL)  SKGTRACESUITE << oResult.at(i) << endl;
-            else {
+            if (oStream == NULL) {
+                SKGTRACESUITE << oResult.at(i) << endl;
+            } else {
                 *oStream << oResult.at(i) << endl;
             }
         }
@@ -1039,7 +1249,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
 SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QString& oResult, SKGServices::DumpMode iMode)
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(QSqlDatabase)", err);
+    _SKGTRACEINFUNCRC(10, err);
     // initialisation
     oResult = "";
 
@@ -1058,7 +1268,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
 SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QStringList& oResult, SKGServices::DumpMode iMode)
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(QSqlDatabase)", err);
+    _SKGTRACEINFUNCRC(10, err);
 
     // Execution of sql order
     SKGStringListList oResultTmp;
@@ -1067,19 +1277,30 @@ SKGError SKGServices::dumpSelectSqliteOrder(QSqlDatabase* iDb, const QString& iS
     return err;
 }
 
+SKGError SKGServices::executeSingleSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QString& oResult)
+{
+    SKGStringListList result;
+    SKGError err = executeSelectSqliteOrder(iDb, iSqlOrder, result);
+    oResult = result.value(1).value(0);
+    return err;
+}
+
 SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, SKGStringListList& oResult)
 {
     SKGError err;
-    _SKGTRACEINRC(10, "SKGServices::executeSelectSqliteOrder(QSqlDatabase)", err);
+    _SKGTRACEINFUNCRC(10, err);
     // initialisation
     oResult.clear();
 
-    if (iDb == NULL) err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
-    else {
+    if (iDb == NULL) {
+        err = SKGError(ERR_POINTER, i18nc("Error message", "No database defined"));
+    } else {
         QSqlQuery query(QString(), *iDb);
         query.setForwardOnly(true);
         double elapse = 0;
-        if (SKGServices::SKGSqlTraces != -1)  elapse = SKGServices::getMicroTime();
+        if (SKGServices::SKGSqlTraces != -1) {
+            elapse = SKGServices::getMicroTime();
+        }
 
         if (!query.exec(iSqlOrder)) {
             QSqlError sqlError = query.lastError();
@@ -1183,7 +1404,7 @@ double SKGServices::getMicroTime()
 
 SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
 {
-    SKGTRACEIN(10, "SKGServices::getBase100Table");
+    SKGTRACEINFUNC(10);
 
     // Build history
     SKGStringListList output;
@@ -1209,7 +1430,9 @@ SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
                 valInitial = val;
                 val = 100.0;
             } else {
-                if (valInitial != 0.0)val = 100.0 * val / valInitial;
+                if (valInitial != 0.0) {
+                    val = 100.0 * val / valInitial;
+                }
             }
             newLine.push_back(SKGServices::doubleToString(val));
         }
@@ -1221,7 +1444,7 @@ SKGStringListList SKGServices::getBase100Table(const SKGStringListList& iTable)
 
 SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable, bool iOfColumns, bool iAbsolute)
 {
-    SKGTRACEIN(10, "SKGServices::getPercentTable");
+    SKGTRACEINFUNC(10);
 
     // Build history
     SKGStringListList output;
@@ -1281,7 +1504,7 @@ SKGStringListList SKGServices::getPercentTable(const SKGStringListList& iTable,
 
 SKGStringListList SKGServices::getHistorizedTable(const SKGStringListList& iTable)
 {
-    SKGTRACEIN(10, "SKGServices::getHistorizedTable");
+    SKGTRACEINFUNC(10);
 
     // Build history
     SKGStringListList output;
